Informations for the CMSIS-Pack to setup the Flexible Safety RTOS using different compiler
===========================================================================================

## Table of Contents

 * [Setup Flexible Safety RTOS CMSIS using GCC & Keil IDE](#chapter_gcc-keil)
 * [Setup Flexible Safety RTOS CMSIS using IAR IDE](#chapter_iar)


## Setup Flexible Safety RTOS CMSIS using GCC & Keil IDE <a name="chapter_gcc-keil"></a>

The following steps are needed to creat project with Flexible Safety RTOS using Keil-uVision V5.18a  

 1. Open the Keil uvision and Create uVision project by following this path: `Project`->`New uVision Project...`  
    ![Creating uVision Project!](images/Create_uVision_Proj.JPG "Create uVision Project")

 2. In opened window (`Create New Project`) give the project name and press `Save`  
    ![Give the Project name!](images/Projectname.jpg "Project name")
 
 3. In `Select Device for Target` window select the device which has Cortex-M4F  
    ![Select the device which has Cortex-M4F as a core!](images/Select_Device.JPG "Select Cortex-M4F device")

 4. Before selecting the different CMSIS_PACK from opened `Manage Run-Time Environment` window, you must have to set the compiler as per your application requirement in `Manage Project Items` window  
    To open this window follow this path: `Project`->`Manage`->`Project Items`  
    ![Open the Project Items window to select the compiler!](images/ManageCompiler.jpg "Project Items for Compiler selection")

 5. In opened `Manage Project Items` window go to `Folders/Extensions` window and select the compiler as per your requirement and press `OK`  
    ![Procedure to select the compiler in `Manage Project Items` window!](images/Select_Compiler.JPG "Project Items for Compiler selection")

 6. Now open the `Manage Run-Time Environment` window by following this path: `Project`->`Manage`->`Run-Time Environment`  
    In opened `Manage Run-Time Environment` window select the CMSIS `Flexible Safety RTOS` and Press `OK`  
    ![Select the CMSIS in `Manage Run-Time Environment` window!](images/Select_CMSIS.JPG "Select CMSIS")

 7. Now in Project view you will see the `RTOS` CMSIS and its files as per selected compiler  
    ![See the Project view with selected CMSIS `RTOS`!](images/ProjectView.JPG "Project View")

 8. You have to provide correct linker file to the project once you have selected the Flexible Safety RTOS for that follow this path: `Project`->`Options for Target...`  
    In opened `Options for Target` window select the Linker Option and provide this path for "GCC": .\RTE\RTOS\cortex-m4f.lds and for "ARM" provide this path: .\RTE\RTOS\cortex-m4f.sct  
    ![Provide linker file path!](images/Select_Linker.JPG "Linker selection")
    
 9. After adding this file to linker path, open this file by selecting `Edit...` and change the memory addresses (RAM and ROM) as per your hardware specification.
 
 10. You can also add the template files to your project for creating the application. For that follow this path: Right click on `"Source Group 1"`->`Add New Items to Group "Source Group 1"`  
    ![Template files for creating the application!](images/TemplateFiles.JPG "Template files")

 11. In opened window you can select the User Code Template option and there you will find the template files for selected CMSIS `RTOS`  
     ![Template files selection!](images/Select_Templates.JPG "Template files selection from CMSIS 'RTOS' ")

## Setup Flexible Safety RTOS CMSIS using IAR IDE <a name="chapter_iar"></a>

The following steps are needed to creat project with Flexible Safety RTOS using IAR Embedded Workbench IDE V8.32.1.18631

 1. Open the IAR workbench and create new workspace by following this path: `File`->`New Workspace`  
    Then Create new project for that follow this path: `Project`->`Create New Project`  
    ![Creating IAR Project!](images/Create_Project_IAR.JPG "Create IAR CMSIS Project")

 2. In opened `Create New Project` window select `Empty CMSISPack project` option and press `OK`  
    ![Selecting Empty CMSISPack project!](images/CMSISProject.JPG "Empty CMSISPack project")

 3. Now you have to save the workspace in your working directory and press `Save`  
    ![Save worksapce!](images/SaveWorkspace.JPG "Save workspace")
 
 4. After saving workspace you have to save the project Files and press `Save`. When you press the save button it will open another window `IarIdePm`  
    because you can not create project file in same folder where workspace is saved so that when you select `Yes` it will generate one folder and save the project file there.  
    ![Save project file!](images/SaveProjectfile.JPG "Save project file")  
    ![Select yes to create project file in another folder!](images/IarIdePm.JPG "Project file in another folder")

 5. In opened `Select Device` window select the device which has Cortex-M4F  
    ![Select the device which has Cortex-M4F as a core!](images/Select_Device_IAR.JPG "Select Cortex-M4F device")

 6. Now open the `CMSIS-Manager` window by following this path: `Project`->`CMSIS-Manager`  
    In opened `CMSIS-Manager` window select the CMSIS `Flexible Safety RTOS` and Press `OK`  
    ![Select the CMSIS in "CMSIS-Manager" window!](images/Select_CMSIS_IAR.JPG "Select CMSIS")

 7. Now in Project view you will see the `RTOS` CMSIS and its files as per selected compiler  
    ![See the Project view with selected CMSIS "RTOS"!](images/ProjectView_IAR.JPG "Project View")
 
 8. You have to provide correct linker file to the project once you have selected the Flexible Safety RTOS for that follow this path: Right click on `MyProject`->`Options`  
    In opened `Options for node "MyProject" ` window select the Linker Option and select the `Override default` option and provide path: $PROJ_DIR$\RTE\RTOS\cortex-m4f.icf  
    ![open the Option window to provide linker file!](images/LinkerOption_IAR.JPG "Project Option")  
    ![Provide linker file path!](images/Select_Linker_IAR.JPG "Linker Selection")

 9. After adding this file to linker path, open this file and change the memory addresses (RAM and ROM) as per your hardware specification.

 10. You can also add the template files to your project for creating the application. For that open the CMSIS-Manager window and follow this path: `CMSIS Manager`->`Create files for CMSIS Template`  
    ![Template files for creating the application!](images/CMSIS_Template_IAR.JPG "Template files")

 11. It will open one window and there select `Browse` option. After that another window will open and there select your project  
     ![Template files selection!](images/TemplateSelection1.JPG "Template files selection from CMSIS 'RTOS' ")  
     ![Template files selection!](images/TemplateSelection2.JPG "Template files selection from CMSIS 'RTOS' ")

 12. Now select the Template files which you want to add from CMSIS packet and provide the location to save that files in your project directory.  
     ![Template files selection!](images/TemplateSelection3.JPG "Template files selection from CMSIS 'RTOS' ")  
     ![Template files selection!](images/TemplateSelection4.JPG "Template files selection from CMSIS 'RTOS' ")

 13. Now go back to your working environment window and add their the template files which you have added to the project director. For that follow this path: Right click on `MyProject`->`Add`->`Add Files`  
     In opened window select the template files which you have added using CMSIS-Manager  
     ![Add Template files from your project directory!](images/AddTemplatefiles.JPG "Add Template files")
