/***********************************************************************************************************
*
*                                              Linker Command File
*
* CPU  : User Hardware
* Board: NUCLEO-F446RE
*
************************************************************************************************************/
OUTPUT_FORMAT("elf32-littlearm")
OUTPUT_ARCH(arm)
ENTRY(_start)

/* TODO Update the core_intvec, core_rom, core_ram address as per Hardware specifications. */
/* Here, Defined adresses are an example for hardware STM32F446 */
MEMORY
{
    core_intvec(rx) : ORIGIN = 0x08000000,   LENGTH = 0x00000200   /*   Intvec location           */
    core_rom   (rx) : ORIGIN = 0x08000200,   LENGTH = 0x0007FFFF   /*   512k Demo Code            */

    core_ram_1 (rw) : ORIGIN = 0x20000000,   LENGTH = 0x0001C000   /*    112k Demo Data           */
    core_ram_2 (rw) : ORIGIN = 0x20020000,   LENGTH = 0x00004000   /*     16k unused Data         */
    core_ram_3 (rw) : ORIGIN = 0x10000000,   LENGTH = 0x00010000   /*     64k unused Data         */
}

stack_size = 0x200;

SECTIONS {
    .intvec : {
        KEEP(*(.intvec))
		KEEP(*(.isr_vector))
    } > core_intvec

    .text : {
        CREATE_OBJECT_SYMBOLS
        *(.text)
        *(.text.*)
        *(.gnu.linkonce.t.*)
        *(.plt)
        *(.gnu.warning)
        *(.glue_7)
        *(.glue_7t)

        . = ALIGN(4);
        *(.rodata)
        *(.rodata*)
        *(.gnu.linkonce.r.*)

        *(.init)
        *(.fini)

        PROVIDE_HIDDEN(__preinit_array_start = .);
        KEEP(*(.preinit_array))
        PROVIDE_HIDDEN(__preinit_array_end = .);
        PROVIDE_HIDDEN(__init_array_start = .);
        KEEP(*(SORT(.init_array.*)))
        KEEP(*(.init_array))
        PROVIDE_HIDDEN(__init_array_end = .);
        PROVIDE_HIDDEN(__fini_array_start = .);
        KEEP(*(.fini_array))
        KEEP(*(SORT(.fini_array.*)))
        PROVIDE_HIDDEN(__fini_array_end = .);

        . = ALIGN(4);
        __data_rom_start = .;

    } > core_rom

    /* .ARM.exidx is sorted, so has to go in its own output section.  */
    __exidx_start = .;
    .ARM.exidx : {
        *(.ARM.exidx* .gnu.linkonce.armexidx.*)
    } > core_ram_1
    __exidx_end = .;
    _etext = .;

    /*--------------------------------------------------------------------------------------------*
     *  Section 00:
     *  (1) reserved for uC/OS-MPU system
     *  (2) don't touch the marked section.
     *--------------------------------------------------------------------------------------------*/
    /*-- START OF MARKED SECTION --*/
    .sec00.data : AT(__data_rom_start) ALIGN(0x400) { __sec00_load = LOADADDR(.sec00.data);
        __sec00_start = .;
            *(.sec00_init)
            *sec00*.o(.data)
            *os_core.o(.data)
            *os_flag.o(.data)
            *os_mbox.o(.data)
            *os_mem.o(.data)
            *os_mutex.o(.data)
            *os_q.o(.data)
            *os_sem.o(.data)
            *os_task.o(.data)
            *os_time.o(.data)
            *os_tmr.o(.data)
            *os_cpu*.o(.data)
            *os_cpu.o(.data)
            *sp_api.o(.data)
            *sp_core.o(.data)
            *sp_mon.o(.data)
            *sp_osapi.o(.data)
            *sp_cpu*.o(.data)
            *sp_cpu.o(.data)
        . = ALIGN(4); __sec00_bss = .;
    } > core_ram_1

    .sec00.bss __sec00_bss (NOLOAD) : {
            *(.sec00)
            *sec00*.o(.bss COMMON)
            *os_core.o(.bss COMMON)
            *os_flag.o(.bss COMMON)
            *os_mbox.o(.bss COMMON)
            *os_mem.o(.bss COMMON)
            *os_mutex.o(.bss COMMON)
            *os_q.o(.bss COMMON)
            *os_sem.o(.bss COMMON)
            *os_task.o(.bss COMMON)
            *os_time.o(.bss COMMON)
            *os_tmr.o(.bss COMMON)
            *os_cpu*.o(.bss COMMON)
            *os_cpu.o(.bss COMMON)
            *sp_api.o(.bss COMMON)
            *sp_core.o(.bss COMMON)
            *sp_mon.o(.bss COMMON)
            *sp_osapi.o(.bss COMMON)
            *sp_cpu*.o(.bss COMMON)
            *sp_cpu.o(.bss COMMON)
        . = ALIGN(4); __sec00_end = .;
    } > core_ram_1
    /*-- END OF MARKED SECTION --*/

    /*--------------------------------------------------------------------------------------------*
     *  Section 01:
     *--------------------------------------------------------------------------------------------*/
    .sec01.data : AT (LOADADDR(.sec00.data) + SIZEOF(.sec00.data)) ALIGN(0x400) { __sec01_load = LOADADDR(.sec01.data);
        __sec01_start = .;
            *(.sec01_init)
            *sec01*.o(.data)
        . = ALIGN(4); __sec01_bss = .;
    } > core_ram_1

    .sec01.bss __sec01_bss (NOLOAD) : {
            *(.sec01)
            *sec01*.o(.bss COMMON)
        . = ALIGN(4); __sec01_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 02:
     *--------------------------------------------------------------------------------------------*/
    .sec02.data : AT (LOADADDR(.sec01.data) + SIZEOF(.sec01.data)) ALIGN(0x400) { __sec02_load = LOADADDR(.sec02.data);
        __sec02_start = .;
            *(.sec02_init)
            *sec02*.o(.data)
        . = ALIGN(4); __sec02_bss = .;
    } > core_ram_1

    .sec02.bss __sec02_bss (NOLOAD) : {
            *(.sec02)
            *sec02*.o(.bss COMMON)
        . = ALIGN(4); __sec02_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 03:
     *--------------------------------------------------------------------------------------------*/
    .sec03.data : AT (LOADADDR(.sec02.data) + SIZEOF(.sec02.data)) ALIGN(0x400) { __sec03_load = LOADADDR(.sec03.data);
        __sec03_start = .;
            *(.sec03_init)
            *sec03*.o(.data)
        . = ALIGN(4); __sec03_bss = .;
    } > core_ram_1

    .sec03.bss __sec03_bss (NOLOAD) : {
            *(.sec03)
            *sec03*.o(.bss COMMON)
        . = ALIGN(4); __sec03_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 04:
     *--------------------------------------------------------------------------------------------*/
    .sec04.data : AT (LOADADDR(.sec03.data) + SIZEOF(.sec03.data)) ALIGN(0x400) { __sec04_load = LOADADDR(.sec04.data);
        __sec04_start = .;
            *(.sec04_init)
            *sec04*.o(.data)
        . = ALIGN(4); __sec04_bss = .;
    } > core_ram_1

    .sec04.bss __sec04_bss (NOLOAD) : {
            *(.sec04)
            *sec04*.o(.bss COMMON)
        . = ALIGN(4); __sec04_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 05:
     *--------------------------------------------------------------------------------------------*/
    .sec05.data : AT (LOADADDR(.sec04.data) + SIZEOF(.sec04.data)) ALIGN(0x400) { __sec05_load = LOADADDR(.sec05.data);
        __sec05_start = .;
            *(.sec05_init)
            *sec05*.o(.data)
        . = ALIGN(4); __sec05_bss = .;
    } > core_ram_1

    .sec05.bss __sec05_bss (NOLOAD) : {
            *(.sec05)
            *sec05*.o(.bss COMMON)
        . = ALIGN(4); __sec05_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 06:
     *--------------------------------------------------------------------------------------------*/
    .sec06.data : AT (LOADADDR(.sec05.data) + SIZEOF(.sec05.data)) ALIGN(0x400) { __sec06_load = LOADADDR(.sec06.data);
        __sec06_start = .;
            *(.sec06_init)
            *sec06*.o(.data)
        . = ALIGN(4); __sec06_bss = .;
    } > core_ram_1

    .sec06.bss __sec06_bss (NOLOAD) : {
            *(.sec06)
            *sec06*.o(.bss COMMON)
        . = ALIGN(4); __sec06_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 07:
     *--------------------------------------------------------------------------------------------*/
    .sec07.data : AT (LOADADDR(.sec06.data) + SIZEOF(.sec06.data)) ALIGN(0x400) { __sec07_load = LOADADDR(.sec07.data);
        __sec07_start = .;
            *(.sec07_init)
            *sec07*.o(.data)
        . = ALIGN(4); __sec07_bss = .;
    } > core_ram_1

    .sec07.bss __sec07_bss (NOLOAD) : {
            *(.sec07)
            *sec07*.o(.bss COMMON)
        . = ALIGN(4); __sec07_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 08:
     *--------------------------------------------------------------------------------------------*/
    .sec08.data : AT (LOADADDR(.sec07.data) + SIZEOF(.sec07.data)) ALIGN(0x400) { __sec08_load = LOADADDR(.sec08.data);
        __sec08_start = .;
            *(.sec08_init)
            *sec08*.o(.data)
        . = ALIGN(4); __sec08_bss = .;
    } > core_ram_1

    .sec08.bss __sec08_bss (NOLOAD) : {
            *(.sec08)
            *sec08*.o(.bss COMMON)
        . = ALIGN(4); __sec08_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 09:
     *--------------------------------------------------------------------------------------------*/
    .sec09.data : AT (LOADADDR(.sec08.data) + SIZEOF(.sec08.data)) ALIGN(0x400) { __sec09_load = LOADADDR(.sec09.data);
        __sec09_start = .;
            *(.sec09_init)
            *sec09*.o(.data)
        . = ALIGN(4); __sec09_bss = .;
    } > core_ram_1

    .sec09.bss __sec09_bss (NOLOAD) : {
            *(.sec09)
            *sec09*.o(.bss COMMON)
        . = ALIGN(4); __sec09_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 0A:
     *--------------------------------------------------------------------------------------------*/
    .sec0A.data : AT (LOADADDR(.sec09.data) + SIZEOF(.sec09.data)) ALIGN(0x400) { __sec0A_load = LOADADDR(.sec0A.data);
        __sec0A_start = .;
            *(.sec0A_init)
            *sec0A*.o(.data)
        . = ALIGN(4); __sec0A_bss = .;
    } > core_ram_1

    .sec0A.bss __sec0A_bss (NOLOAD) : {
            *(.sec0A)
            *sec0A*.o(.bss COMMON)
        . = ALIGN(4); __sec0A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 0B:
     *--------------------------------------------------------------------------------------------*/
    .sec0B.data : AT (LOADADDR(.sec0A.data) + SIZEOF(.sec0A.data)) ALIGN(0x400) { __sec0B_load = LOADADDR(.sec0B.data);
        __sec0B_start = .;
            *(.sec0B_init)
            *sec0B*.o(.data)
        . = ALIGN(4); __sec0B_bss = .;
    } > core_ram_1

    .sec0B.bss __sec0B_bss (NOLOAD) : {
            *(.sec0B)
            *sec0B*.o(.bss COMMON)
        . = ALIGN(4); __sec0B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 0C:
     *--------------------------------------------------------------------------------------------*/
    .sec0C.data : AT (LOADADDR(.sec0B.data) + SIZEOF(.sec0B.data)) ALIGN(0x400) { __sec0C_load = LOADADDR(.sec0C.data);
        __sec0C_start = .;
            *(.sec0C_init)
            *sec0C*.o(.data)
        . = ALIGN(4); __sec0C_bss = .;
    } > core_ram_1

    .sec0C.bss __sec0C_bss (NOLOAD) : {
            *(.sec0C)
            *sec0C*.o(.bss COMMON)
        . = ALIGN(4); __sec0C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 0D:
     *--------------------------------------------------------------------------------------------*/
    .sec0D.data : AT (LOADADDR(.sec0C.data) + SIZEOF(.sec0C.data)) ALIGN(0x400) { __sec0D_load = LOADADDR(.sec0D.data);
        __sec0D_start = .;
            *(.sec0D_init)
            *sec0D*.o(.data)
        . = ALIGN(4); __sec0D_bss = .;
    } > core_ram_1

    .sec0D.bss __sec0D_bss (NOLOAD) : {
            *(.sec0D)
            *sec0D*.o(.bss COMMON)
        . = ALIGN(4); __sec0D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 0E:
     *--------------------------------------------------------------------------------------------*/
    .sec0E.data : AT (LOADADDR(.sec0D.data) + SIZEOF(.sec0D.data)) ALIGN(0x400) { __sec0E_load = LOADADDR(.sec0E.data);
        __sec0E_start = .;
            *(.sec0E_init)
            *sec0E*.o(.data)
        . = ALIGN(4); __sec0E_bss = .;
    } > core_ram_1

    .sec0E.bss __sec0E_bss (NOLOAD) : {
            *(.sec0E)
            *sec0E*.o(.bss COMMON)
        . = ALIGN(4); __sec0E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 0F:
     *--------------------------------------------------------------------------------------------*/
    .sec0F.data : AT (LOADADDR(.sec0E.data) + SIZEOF(.sec0E.data)) ALIGN(0x400) { __sec0F_load = LOADADDR(.sec0F.data);
        __sec0F_start = .;
            *(.sec0F_init)
            *sec0F*.o(.data)
        . = ALIGN(4); __sec0F_bss = .;
    } > core_ram_1

    .sec0F.bss __sec0F_bss (NOLOAD) : {
            *(.sec0F)
            *sec0F*.o(.bss COMMON)
        . = ALIGN(4); __sec0F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 10:
     *--------------------------------------------------------------------------------------------*/
    .sec10.data : AT (LOADADDR(.sec0F.data) + SIZEOF(.sec0F.data)) ALIGN(0x400) { __sec10_load = LOADADDR(.sec10.data);
        __sec10_start = .;
            *(.sec10_init)
            *sec10*.o(.data)
        . = ALIGN(4); __sec10_bss = .;
    } > core_ram_1

    .sec10.bss __sec10_bss (NOLOAD) : {
            *(.sec10)
            *sec10*.o(.bss COMMON)
        . = ALIGN(4); __sec10_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 11:
     *--------------------------------------------------------------------------------------------*/
    .sec11.data : AT (LOADADDR(.sec10.data) + SIZEOF(.sec10.data)) ALIGN(0x400) { __sec11_load = LOADADDR(.sec11.data);
        __sec11_start = .;
            *(.sec11_init)
            *sec11*.o(.data)
        . = ALIGN(4); __sec11_bss = .;
    } > core_ram_1

    .sec11.bss __sec11_bss (NOLOAD) : {
            *(.sec11)
            *sec11*.o(.bss COMMON)
        . = ALIGN(4); __sec11_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 12:
     *--------------------------------------------------------------------------------------------*/
    .sec12.data : AT (LOADADDR(.sec11.data) + SIZEOF(.sec11.data)) ALIGN(0x400) { __sec12_load = LOADADDR(.sec12.data);
        __sec12_start = .;
            *(.sec12_init)
            *sec12*.o(.data)
        . = ALIGN(4); __sec12_bss = .;
    } > core_ram_1

    .sec12.bss __sec12_bss (NOLOAD) : {
            *(.sec12)
            *sec12*.o(.bss COMMON)
        . = ALIGN(4); __sec12_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 13:
     *--------------------------------------------------------------------------------------------*/
    .sec13.data : AT (LOADADDR(.sec12.data) + SIZEOF(.sec12.data)) ALIGN(0x400) { __sec13_load = LOADADDR(.sec13.data);
        __sec13_start = .;
            *(.sec13_init)
            *sec13*.o(.data)
        . = ALIGN(4); __sec13_bss = .;
    } > core_ram_1

    .sec13.bss __sec13_bss (NOLOAD) : {
            *(.sec13)
            *sec13*.o(.bss COMMON)
        . = ALIGN(4); __sec13_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 14:
     *--------------------------------------------------------------------------------------------*/
    .sec14.data : AT (LOADADDR(.sec13.data) + SIZEOF(.sec13.data)) ALIGN(0x400) { __sec14_load = LOADADDR(.sec14.data);
        __sec14_start = .;
            *(.sec14_init)
            *sec14*.o(.data)
        . = ALIGN(4); __sec14_bss = .;
    } > core_ram_1

    .sec14.bss __sec14_bss (NOLOAD) : {
            *(.sec14)
            *sec14*.o(.bss COMMON)
        . = ALIGN(4); __sec14_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 15:
     *--------------------------------------------------------------------------------------------*/
    .sec15.data : AT (LOADADDR(.sec14.data) + SIZEOF(.sec14.data)) ALIGN(0x400) { __sec15_load = LOADADDR(.sec15.data);
        __sec15_start = .;
            *(.sec15_init)
            *sec15*.o(.data)
        . = ALIGN(4); __sec15_bss = .;
    } > core_ram_1

    .sec15.bss __sec15_bss (NOLOAD) : {
            *(.sec15)
            *sec15*.o(.bss COMMON)
        . = ALIGN(4); __sec15_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 16:
     *--------------------------------------------------------------------------------------------*/
    .sec16.data : AT (LOADADDR(.sec15.data) + SIZEOF(.sec15.data)) ALIGN(0x400) { __sec16_load = LOADADDR(.sec16.data);
        __sec16_start = .;
            *(.sec16_init)
            *sec16*.o(.data)
        . = ALIGN(4); __sec16_bss = .;
    } > core_ram_1

    .sec16.bss __sec16_bss (NOLOAD) : {
            *(.sec16)
            *sec16*.o(.bss COMMON)
        . = ALIGN(4); __sec16_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 17:
     *--------------------------------------------------------------------------------------------*/
    .sec17.data : AT (LOADADDR(.sec16.data) + SIZEOF(.sec16.data)) ALIGN(0x400) { __sec17_load = LOADADDR(.sec17.data);
        __sec17_start = .;
            *(.sec17_init)
            *sec17*.o(.data)
        . = ALIGN(4); __sec17_bss = .;
    } > core_ram_1

    .sec17.bss __sec17_bss (NOLOAD) : {
            *(.sec17)
            *sec17*.o(.bss COMMON)
        . = ALIGN(4); __sec17_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 18:
     *--------------------------------------------------------------------------------------------*/
    .sec18.data : AT (LOADADDR(.sec17.data) + SIZEOF(.sec17.data)) ALIGN(0x400) { __sec18_load = LOADADDR(.sec18.data);
        __sec18_start = .;
            *(.sec18_init)
            *sec18*.o(.data)
        . = ALIGN(4); __sec18_bss = .;
    } > core_ram_1

    .sec18.bss __sec18_bss (NOLOAD) : {
            *(.sec18)
            *sec18*.o(.bss COMMON)
        . = ALIGN(4); __sec18_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 19:
     *--------------------------------------------------------------------------------------------*/
    .sec19.data : AT (LOADADDR(.sec18.data) + SIZEOF(.sec18.data)) ALIGN(0x400) { __sec19_load = LOADADDR(.sec19.data);
        __sec19_start = .;
            *(.sec19_init)
            *sec19*.o(.data)
        . = ALIGN(4); __sec19_bss = .;
    } > core_ram_1

    .sec19.bss __sec19_bss (NOLOAD) : {
            *(.sec19)
            *sec19*.o(.bss COMMON)
        . = ALIGN(4); __sec19_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 1A:
     *--------------------------------------------------------------------------------------------*/
    .sec1A.data : AT (LOADADDR(.sec19.data) + SIZEOF(.sec19.data)) ALIGN(0x400) { __sec1A_load = LOADADDR(.sec1A.data);
        __sec1A_start = .;
            *(.sec1A_init)
            *sec1A*.o(.data)
        . = ALIGN(4); __sec1A_bss = .;
    } > core_ram_1

    .sec1A.bss __sec1A_bss (NOLOAD) : {
            *(.sec1A)
            *sec1A*.o(.bss COMMON)
        . = ALIGN(4); __sec1A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 1B:
     *--------------------------------------------------------------------------------------------*/
    .sec1B.data : AT (LOADADDR(.sec1A.data) + SIZEOF(.sec1A.data)) ALIGN(0x400) { __sec1B_load = LOADADDR(.sec1B.data);
        __sec1B_start = .;
            *(.sec1B_init)
            *sec1B*.o(.data)
        . = ALIGN(4); __sec1B_bss = .;
    } > core_ram_1

    .sec1B.bss __sec1B_bss (NOLOAD) : {
            *(.sec1B)
            *sec1B*.o(.bss COMMON)
        . = ALIGN(4); __sec1B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 1C:
     *--------------------------------------------------------------------------------------------*/
    .sec1C.data : AT (LOADADDR(.sec1B.data) + SIZEOF(.sec1B.data)) ALIGN(0x400) { __sec1C_load = LOADADDR(.sec1C.data);
        __sec1C_start = .;
            *(.sec1C_init)
            *sec1C*.o(.data)
        . = ALIGN(4); __sec1C_bss = .;
    } > core_ram_1

    .sec1C.bss __sec1C_bss (NOLOAD) : {
            *(.sec1C)
            *sec1C*.o(.bss COMMON)
        . = ALIGN(4); __sec1C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 1D:
     *--------------------------------------------------------------------------------------------*/
    .sec1D.data : AT (LOADADDR(.sec1C.data) + SIZEOF(.sec1C.data)) ALIGN(0x400) { __sec1D_load = LOADADDR(.sec1D.data);
        __sec1D_start = .;
            *(.sec1D_init)
            *sec1D*.o(.data)
        . = ALIGN(4); __sec1D_bss = .;
    } > core_ram_1

    .sec1D.bss __sec1D_bss (NOLOAD) : {
            *(.sec1D)
            *sec1D*.o(.bss COMMON)
        . = ALIGN(4); __sec1D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 1E:
     *--------------------------------------------------------------------------------------------*/
    .sec1E.data : AT (LOADADDR(.sec1D.data) + SIZEOF(.sec1D.data)) ALIGN(0x400) { __sec1E_load = LOADADDR(.sec1E.data);
        __sec1E_start = .;
            *(.sec1E_init)
            *sec1E*.o(.data)
        . = ALIGN(4); __sec1E_bss = .;
    } > core_ram_1

    .sec1E.bss __sec1E_bss (NOLOAD) : {
            *(.sec1E)
            *sec1E*.o(.bss COMMON)
        . = ALIGN(4); __sec1E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 1F:
     *--------------------------------------------------------------------------------------------*/
    .sec1F.data : AT (LOADADDR(.sec1E.data) + SIZEOF(.sec1E.data)) ALIGN(0x400) { __sec1F_load = LOADADDR(.sec1F.data);
        __sec1F_start = .;
            *(.sec1F_init)
            *sec1F*.o(.data)
        . = ALIGN(4); __sec1F_bss = .;
    } > core_ram_1

    .sec1F.bss __sec1F_bss (NOLOAD) : {
            *(.sec1F)
            *sec1F*.o(.bss COMMON)
        . = ALIGN(4); __sec1F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 20:
     *--------------------------------------------------------------------------------------------*/
    .sec20.data : AT (LOADADDR(.sec1F.data) + SIZEOF(.sec1F.data)) ALIGN(0x400) { __sec20_load = LOADADDR(.sec20.data);
        __sec20_start = .;
            *(.sec20_init)
            *sec20*.o(.data)
        . = ALIGN(4); __sec20_bss = .;
    } > core_ram_1

    .sec20.bss __sec20_bss (NOLOAD) : {
            *(.sec20)
            *sec20*.o(.bss COMMON)
        . = ALIGN(4); __sec20_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 21:
     *--------------------------------------------------------------------------------------------*/
    .sec21.data : AT (LOADADDR(.sec20.data) + SIZEOF(.sec20.data)) ALIGN(0x400) { __sec21_load = LOADADDR(.sec21.data);
        __sec21_start = .;
            *(.sec21_init)
            *sec21*.o(.data)
        . = ALIGN(4); __sec21_bss = .;
    } > core_ram_1

    .sec21.bss __sec21_bss (NOLOAD) : {
            *(.sec21)
            *sec21*.o(.bss COMMON)
        . = ALIGN(4); __sec21_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 22:
     *--------------------------------------------------------------------------------------------*/
    .sec22.data : AT (LOADADDR(.sec21.data) + SIZEOF(.sec21.data)) ALIGN(0x400) { __sec22_load = LOADADDR(.sec22.data);
        __sec22_start = .;
            *(.sec22_init)
            *sec22*.o(.data)
        . = ALIGN(4); __sec22_bss = .;
    } > core_ram_1

    .sec22.bss __sec22_bss (NOLOAD) : {
            *(.sec22)
            *sec22*.o(.bss COMMON)
        . = ALIGN(4); __sec22_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 23:
     *--------------------------------------------------------------------------------------------*/
    .sec23.data : AT (LOADADDR(.sec22.data) + SIZEOF(.sec22.data)) ALIGN(0x400) { __sec23_load = LOADADDR(.sec23.data);
        __sec23_start = .;
            *(.sec23_init)
            *sec23*.o(.data)
        . = ALIGN(4); __sec23_bss = .;
    } > core_ram_1

    .sec23.bss __sec23_bss (NOLOAD) : {
            *(.sec23)
            *sec23*.o(.bss COMMON)
        . = ALIGN(4); __sec23_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 24:
     *--------------------------------------------------------------------------------------------*/
    .sec24.data : AT (LOADADDR(.sec23.data) + SIZEOF(.sec23.data)) ALIGN(0x400) { __sec24_load = LOADADDR(.sec24.data);
        __sec24_start = .;
            *(.sec24_init)
            *sec24*.o(.data)
        . = ALIGN(4); __sec24_bss = .;
    } > core_ram_1

    .sec24.bss __sec24_bss (NOLOAD) : {
            *(.sec24)
            *sec24*.o(.bss COMMON)
        . = ALIGN(4); __sec24_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 25:
     *--------------------------------------------------------------------------------------------*/
    .sec25.data : AT (LOADADDR(.sec24.data) + SIZEOF(.sec24.data)) ALIGN(0x400) { __sec25_load = LOADADDR(.sec25.data);
        __sec25_start = .;
            *(.sec25_init)
            *sec25*.o(.data)
        . = ALIGN(4); __sec25_bss = .;
    } > core_ram_1

    .sec25.bss __sec25_bss (NOLOAD) : {
            *(.sec25)
            *sec25*.o(.bss COMMON)
        . = ALIGN(4); __sec25_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 26:
     *--------------------------------------------------------------------------------------------*/
    .sec26.data : AT (LOADADDR(.sec25.data) + SIZEOF(.sec25.data)) ALIGN(0x400) { __sec26_load = LOADADDR(.sec26.data);
        __sec26_start = .;
            *(.sec26_init)
            *sec26*.o(.data)
        . = ALIGN(4); __sec26_bss = .;
    } > core_ram_1

    .sec26.bss __sec26_bss (NOLOAD) : {
            *(.sec26)
            *sec26*.o(.bss COMMON)
        . = ALIGN(4); __sec26_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 27:
     *--------------------------------------------------------------------------------------------*/
    .sec27.data : AT (LOADADDR(.sec26.data) + SIZEOF(.sec26.data)) ALIGN(0x400) { __sec27_load = LOADADDR(.sec27.data);
        __sec27_start = .;
            *(.sec27_init)
            *sec27*.o(.data)
        . = ALIGN(4); __sec27_bss = .;
    } > core_ram_1

    .sec27.bss __sec27_bss (NOLOAD) : {
            *(.sec27)
            *sec27*.o(.bss COMMON)
        . = ALIGN(4); __sec27_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 28:
     *--------------------------------------------------------------------------------------------*/
    .sec28.data : AT (LOADADDR(.sec27.data) + SIZEOF(.sec27.data)) ALIGN(0x400) { __sec28_load = LOADADDR(.sec28.data);
        __sec28_start = .;
            *(.sec28_init)
            *sec28*.o(.data)
        . = ALIGN(4); __sec28_bss = .;
    } > core_ram_1

    .sec28.bss __sec28_bss (NOLOAD) : {
            *(.sec28)
            *sec28*.o(.bss COMMON)
        . = ALIGN(4); __sec28_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 29:
     *--------------------------------------------------------------------------------------------*/
    .sec29.data : AT (LOADADDR(.sec28.data) + SIZEOF(.sec28.data)) ALIGN(0x400) { __sec29_load = LOADADDR(.sec29.data);
        __sec29_start = .;
            *(.sec29_init)
            *sec29*.o(.data)
        . = ALIGN(4); __sec29_bss = .;
    } > core_ram_1

    .sec29.bss __sec29_bss (NOLOAD) : {
            *(.sec29)
            *sec29*.o(.bss COMMON)
        . = ALIGN(4); __sec29_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 2A:
     *--------------------------------------------------------------------------------------------*/
    .sec2A.data : AT (LOADADDR(.sec29.data) + SIZEOF(.sec29.data)) ALIGN(0x400) { __sec2A_load = LOADADDR(.sec2A.data);
        __sec2A_start = .;
            *(.sec2A_init)
            *sec2A*.o(.data)
        . = ALIGN(4); __sec2A_bss = .;
    } > core_ram_1

    .sec2A.bss __sec2A_bss (NOLOAD) : {
            *(.sec2A)
            *sec2A*.o(.bss COMMON)
        . = ALIGN(4); __sec2A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 2B:
     *--------------------------------------------------------------------------------------------*/
    .sec2B.data : AT (LOADADDR(.sec2A.data) + SIZEOF(.sec2A.data)) ALIGN(0x400) { __sec2B_load = LOADADDR(.sec2B.data);
        __sec2B_start = .;
            *(.sec2B_init)
            *sec2B*.o(.data)
        . = ALIGN(4); __sec2B_bss = .;
    } > core_ram_1

    .sec2B.bss __sec2B_bss (NOLOAD) : {
            *(.sec2B)
            *sec2B*.o(.bss COMMON)
        . = ALIGN(4); __sec2B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 2C:
     *--------------------------------------------------------------------------------------------*/
    .sec2C.data : AT (LOADADDR(.sec2B.data) + SIZEOF(.sec2B.data)) ALIGN(0x400) { __sec2C_load = LOADADDR(.sec2C.data);
        __sec2C_start = .;
            *(.sec2C_init)
            *sec2C*.o(.data)
        . = ALIGN(4); __sec2C_bss = .;
    } > core_ram_1

    .sec2C.bss __sec2C_bss (NOLOAD) : {
            *(.sec2C)
            *sec2C*.o(.bss COMMON)
        . = ALIGN(4); __sec2C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 2D:
     *--------------------------------------------------------------------------------------------*/
    .sec2D.data : AT (LOADADDR(.sec2C.data) + SIZEOF(.sec2C.data)) ALIGN(0x400) { __sec2D_load = LOADADDR(.sec2D.data);
        __sec2D_start = .;
            *(.sec2D_init)
            *sec2D*.o(.data)
        . = ALIGN(4); __sec2D_bss = .;
    } > core_ram_1

    .sec2D.bss __sec2D_bss (NOLOAD) : {
            *(.sec2D)
            *sec2D*.o(.bss COMMON)
        . = ALIGN(4); __sec2D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 2E:
     *--------------------------------------------------------------------------------------------*/
    .sec2E.data : AT (LOADADDR(.sec2D.data) + SIZEOF(.sec2D.data)) ALIGN(0x400) { __sec2E_load = LOADADDR(.sec2E.data);
        __sec2E_start = .;
            *(.sec2E_init)
            *sec2E*.o(.data)
        . = ALIGN(4); __sec2E_bss = .;
    } > core_ram_1

    .sec2E.bss __sec2E_bss (NOLOAD) : {
            *(.sec2E)
            *sec2E*.o(.bss COMMON)
        . = ALIGN(4); __sec2E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 2F:
     *--------------------------------------------------------------------------------------------*/
    .sec2F.data : AT (LOADADDR(.sec2E.data) + SIZEOF(.sec2E.data)) ALIGN(0x400) { __sec2F_load = LOADADDR(.sec2F.data);
        __sec2F_start = .;
            *(.sec2F_init)
            *sec2F*.o(.data)
        . = ALIGN(4); __sec2F_bss = .;
    } > core_ram_1

    .sec2F.bss __sec2F_bss (NOLOAD) : {
            *(.sec2F)
            *sec2F*.o(.bss COMMON)
        . = ALIGN(4); __sec2F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 30:
     *--------------------------------------------------------------------------------------------*/
    .sec30.data : AT (LOADADDR(.sec2F.data) + SIZEOF(.sec2F.data)) ALIGN(0x400) { __sec30_load = LOADADDR(.sec30.data);
        __sec30_start = .;
            *(.sec30_init)
            *sec30*.o(.data)
        . = ALIGN(4); __sec30_bss = .;
    } > core_ram_1

    .sec30.bss __sec30_bss (NOLOAD) : {
            *(.sec30)
            *sec30*.o(.bss COMMON)
        . = ALIGN(4); __sec30_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 31:
     *--------------------------------------------------------------------------------------------*/
    .sec31.data : AT (LOADADDR(.sec30.data) + SIZEOF(.sec30.data)) ALIGN(0x400) { __sec31_load = LOADADDR(.sec31.data);
        __sec31_start = .;
            *(.sec31_init)
            *sec31*.o(.data)
        . = ALIGN(4); __sec31_bss = .;
    } > core_ram_1

    .sec31.bss __sec31_bss (NOLOAD) : {
            *(.sec31)
            *sec31*.o(.bss COMMON)
        . = ALIGN(4); __sec31_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 32:
     *--------------------------------------------------------------------------------------------*/
    .sec32.data : AT (LOADADDR(.sec31.data) + SIZEOF(.sec31.data)) ALIGN(0x400) { __sec32_load = LOADADDR(.sec32.data);
        __sec32_start = .;
            *(.sec32_init)
            *sec32*.o(.data)
        . = ALIGN(4); __sec32_bss = .;
    } > core_ram_1

    .sec32.bss __sec32_bss (NOLOAD) : {
            *(.sec32)
            *sec32*.o(.bss COMMON)
        . = ALIGN(4); __sec32_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 33:
     *--------------------------------------------------------------------------------------------*/
    .sec33.data : AT (LOADADDR(.sec32.data) + SIZEOF(.sec32.data)) ALIGN(0x400) { __sec33_load = LOADADDR(.sec33.data);
        __sec33_start = .;
            *(.sec33_init)
            *sec33*.o(.data)
        . = ALIGN(4); __sec33_bss = .;
    } > core_ram_1

    .sec33.bss __sec33_bss (NOLOAD) : {
            *(.sec33)
            *sec33*.o(.bss COMMON)
        . = ALIGN(4); __sec33_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 34:
     *--------------------------------------------------------------------------------------------*/
    .sec34.data : AT (LOADADDR(.sec33.data) + SIZEOF(.sec33.data)) ALIGN(0x400) { __sec34_load = LOADADDR(.sec34.data);
        __sec34_start = .;
            *(.sec34_init)
            *sec34*.o(.data)
        . = ALIGN(4); __sec34_bss = .;
    } > core_ram_1

    .sec34.bss __sec34_bss (NOLOAD) : {
            *(.sec34)
            *sec34*.o(.bss COMMON)
        . = ALIGN(4); __sec34_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 35:
     *--------------------------------------------------------------------------------------------*/
    .sec35.data : AT (LOADADDR(.sec34.data) + SIZEOF(.sec34.data)) ALIGN(0x400) { __sec35_load = LOADADDR(.sec35.data);
        __sec35_start = .;
            *(.sec35_init)
            *sec35*.o(.data)
        . = ALIGN(4); __sec35_bss = .;
    } > core_ram_1

    .sec35.bss __sec35_bss (NOLOAD) : {
            *(.sec35)
            *sec35*.o(.bss COMMON)
        . = ALIGN(4); __sec35_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 36:
     *--------------------------------------------------------------------------------------------*/
    .sec36.data : AT (LOADADDR(.sec35.data) + SIZEOF(.sec35.data)) ALIGN(0x400) { __sec36_load = LOADADDR(.sec36.data);
        __sec36_start = .;
            *(.sec36_init)
            *sec36*.o(.data)
        . = ALIGN(4); __sec36_bss = .;
    } > core_ram_1

    .sec36.bss __sec36_bss (NOLOAD) : {
            *(.sec36)
            *sec36*.o(.bss COMMON)
        . = ALIGN(4); __sec36_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 37:
     *--------------------------------------------------------------------------------------------*/
    .sec37.data : AT (LOADADDR(.sec36.data) + SIZEOF(.sec36.data)) ALIGN(0x400) { __sec37_load = LOADADDR(.sec37.data);
        __sec37_start = .;
            *(.sec37_init)
            *sec37*.o(.data)
        . = ALIGN(4); __sec37_bss = .;
    } > core_ram_1

    .sec37.bss __sec37_bss (NOLOAD) : {
            *(.sec37)
            *sec37*.o(.bss COMMON)
        . = ALIGN(4); __sec37_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 38:
     *--------------------------------------------------------------------------------------------*/
    .sec38.data : AT (LOADADDR(.sec37.data) + SIZEOF(.sec37.data)) ALIGN(0x400) { __sec38_load = LOADADDR(.sec38.data);
        __sec38_start = .;
            *(.sec38_init)
            *sec38*.o(.data)
        . = ALIGN(4); __sec38_bss = .;
    } > core_ram_1

    .sec38.bss __sec38_bss (NOLOAD) : {
            *(.sec38)
            *sec38*.o(.bss COMMON)
        . = ALIGN(4); __sec38_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 39:
     *--------------------------------------------------------------------------------------------*/
    .sec39.data : AT (LOADADDR(.sec38.data) + SIZEOF(.sec38.data)) ALIGN(0x400) { __sec39_load = LOADADDR(.sec39.data);
        __sec39_start = .;
            *(.sec39_init)
            *sec39*.o(.data)
        . = ALIGN(4); __sec39_bss = .;
    } > core_ram_1

    .sec39.bss __sec39_bss (NOLOAD) : {
            *(.sec39)
            *sec39*.o(.bss COMMON)
        . = ALIGN(4); __sec39_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 3A:
     *--------------------------------------------------------------------------------------------*/
    .sec3A.data : AT (LOADADDR(.sec39.data) + SIZEOF(.sec39.data)) ALIGN(0x400) { __sec3A_load = LOADADDR(.sec3A.data);
        __sec3A_start = .;
            *(.sec3A_init)
            *sec3A*.o(.data)
        . = ALIGN(4); __sec3A_bss = .;
    } > core_ram_1

    .sec3A.bss __sec3A_bss (NOLOAD) : {
            *(.sec3A)
            *sec3A*.o(.bss COMMON)
        . = ALIGN(4); __sec3A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 3B:
     *--------------------------------------------------------------------------------------------*/
    .sec3B.data : AT (LOADADDR(.sec3A.data) + SIZEOF(.sec3A.data)) ALIGN(0x400) { __sec3B_load = LOADADDR(.sec3B.data);
        __sec3B_start = .;
            *(.sec3B_init)
            *sec3B*.o(.data)
        . = ALIGN(4); __sec3B_bss = .;
    } > core_ram_1

    .sec3B.bss __sec3B_bss (NOLOAD) : {
            *(.sec3B)
            *sec3B*.o(.bss COMMON)
        . = ALIGN(4); __sec3B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 3C:
     *--------------------------------------------------------------------------------------------*/
    .sec3C.data : AT (LOADADDR(.sec3B.data) + SIZEOF(.sec3B.data))ALIGN(0x400)  { __sec3C_load = LOADADDR(.sec3C.data);
        __sec3C_start = .;
            *(.sec3C_init)
            *sec3C*.o(.data)
        . = ALIGN(4); __sec3C_bss = .;
    } > core_ram_1

    .sec3C.bss __sec3C_bss (NOLOAD) : {
            *(.sec3C)
            *sec3C*.o(.bss COMMON)
        . = ALIGN(4); __sec3C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 3D:
     *--------------------------------------------------------------------------------------------*/
    .sec3D.data : AT (LOADADDR(.sec3C.data) + SIZEOF(.sec3C.data)) ALIGN(0x400) { __sec3D_load = LOADADDR(.sec3D.data);
        __sec3D_start = .;
            *(.sec3D_init)
            *sec3D*.o(.data)
        . = ALIGN(4); __sec3D_bss = .;
    } > core_ram_1

    .sec3D.bss __sec3D_bss (NOLOAD) : {
            *(.sec3D)
            *sec3D*.o(.bss COMMON)
        . = ALIGN(4); __sec3D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 3E:
     *--------------------------------------------------------------------------------------------*/
    .sec3E.data : AT (LOADADDR(.sec3D.data) + SIZEOF(.sec3D.data)) ALIGN(0x400) { __sec3E_load = LOADADDR(.sec3E.data);
        __sec3E_start = .;
            *(.sec3E_init)
            *sec3E*.o(.data)
        . = ALIGN(4); __sec3E_bss = .;
    } > core_ram_1

    .sec3E.bss __sec3E_bss (NOLOAD) : {
            *(.sec3E)
            *sec3E*.o(.bss COMMON)
        . = ALIGN(4); __sec3E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 3F:
     *--------------------------------------------------------------------------------------------*/
    .sec3F.data : AT (LOADADDR(.sec3E.data) + SIZEOF(.sec3E.data)) ALIGN(0x400) { __sec3F_load = LOADADDR(.sec3F.data);
        __sec3F_start = .;
            *(.sec3F_init)
            *sec3F*.o(.data)
        . = ALIGN(4); __sec3F_bss = .;
    } > core_ram_1

    .sec3F.bss __sec3F_bss (NOLOAD) : {
            *(.sec3F)
            *sec3F*.o(.bss COMMON)
        . = ALIGN(4); __sec3F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 40:
     *--------------------------------------------------------------------------------------------*/
    .sec40.data : AT (LOADADDR(.sec3F.data) + SIZEOF(.sec3F.data)) ALIGN(0x400) { __sec40_load = LOADADDR(.sec40.data);
        __sec40_start = .;
            *(.sec40_init)
            *sec40*.o(.data)
        . = ALIGN(4); __sec40_bss = .;
    } > core_ram_1

    .sec40.bss __sec40_bss (NOLOAD) : {
            *(.sec40)
            *sec40*.o(.bss COMMON)
        . = ALIGN(4); __sec40_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 41:
     *--------------------------------------------------------------------------------------------*/
    .sec41.data : AT (LOADADDR(.sec40.data) + SIZEOF(.sec40.data)) ALIGN(0x400) { __sec41_load = LOADADDR(.sec41.data);
        __sec41_start = .;
            *(.sec41_init)
            *sec41*.o(.data)
        . = ALIGN(4); __sec41_bss = .;
    } > core_ram_1

    .sec41.bss __sec41_bss (NOLOAD) : {
            *(.sec41)
            *sec41*.o(.bss COMMON)
        . = ALIGN(4); __sec41_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 42:
     *--------------------------------------------------------------------------------------------*/
    .sec42.data : AT (LOADADDR(.sec41.data) + SIZEOF(.sec41.data)) ALIGN(0x400) { __sec42_load = LOADADDR(.sec42.data);
        __sec42_start = .;
            *(.sec42_init)
            *sec42*.o(.data)
        . = ALIGN(4); __sec42_bss = .;
    } > core_ram_1

    .sec42.bss __sec42_bss (NOLOAD) : {
            *(.sec42)
            *sec42*.o(.bss COMMON)
        . = ALIGN(4); __sec42_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 43:
     *--------------------------------------------------------------------------------------------*/
    .sec43.data : AT (LOADADDR(.sec42.data) + SIZEOF(.sec42.data)) ALIGN(0x400) { __sec43_load = LOADADDR(.sec43.data);
        __sec43_start = .;
            *(.sec43_init)
            *sec43*.o(.data)
        . = ALIGN(4); __sec43_bss = .;
    } > core_ram_1

    .sec43.bss __sec43_bss (NOLOAD) : {
            *(.sec43)
            *sec43*.o(.bss COMMON)
        . = ALIGN(4); __sec43_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 44:
     *--------------------------------------------------------------------------------------------*/
    .sec44.data : AT (LOADADDR(.sec43.data) + SIZEOF(.sec43.data)) ALIGN(0x400) { __sec44_load = LOADADDR(.sec44.data);
        __sec44_start = .;
            *(.sec44_init)
            *sec44*.o(.data)
        . = ALIGN(4); __sec44_bss = .;
    } > core_ram_1

    .sec44.bss __sec44_bss (NOLOAD) : {
            *(.sec44)
            *sec44*.o(.bss COMMON)
        . = ALIGN(4); __sec44_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 45:
     *--------------------------------------------------------------------------------------------*/
    .sec45.data : AT (LOADADDR(.sec44.data) + SIZEOF(.sec44.data)) ALIGN(0x400) { __sec45_load = LOADADDR(.sec45.data);
        __sec45_start = .;
            *(.sec45_init)
            *sec45*.o(.data)
        . = ALIGN(4); __sec45_bss = .;
    } > core_ram_1

    .sec45.bss __sec45_bss (NOLOAD) : {
            *(.sec45)
            *sec45*.o(.bss COMMON)
        . = ALIGN(4); __sec45_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 46:
     *--------------------------------------------------------------------------------------------*/
    .sec46.data : AT (LOADADDR(.sec45.data) + SIZEOF(.sec45.data)) ALIGN(0x400) { __sec46_load = LOADADDR(.sec46.data);
        __sec46_start = .;
            *(.sec46_init)
            *sec46*.o(.data)
        . = ALIGN(4); __sec46_bss = .;
    } > core_ram_1

    .sec46.bss __sec46_bss (NOLOAD) : {
            *(.sec46)
            *sec46*.o(.bss COMMON)
        . = ALIGN(4); __sec46_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 47:
     *--------------------------------------------------------------------------------------------*/
    .sec47.data : AT (LOADADDR(.sec46.data) + SIZEOF(.sec46.data)) ALIGN(0x400) { __sec47_load = LOADADDR(.sec47.data);
        __sec47_start = .;
            *(.sec47_init)
            *sec47*.o(.data)
        . = ALIGN(4); __sec47_bss = .;
    } > core_ram_1

    .sec47.bss __sec47_bss (NOLOAD) : {
            *(.sec47)
            *sec47*.o(.bss COMMON)
        . = ALIGN(4); __sec47_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 48:
     *--------------------------------------------------------------------------------------------*/
    .sec48.data : AT (LOADADDR(.sec47.data) + SIZEOF(.sec47.data)) ALIGN(0x400) { __sec48_load = LOADADDR(.sec48.data);
        __sec48_start = .;
            *(.sec48_init)
            *sec48*.o(.data)
        . = ALIGN(4); __sec48_bss = .;
    } > core_ram_1

    .sec48.bss __sec48_bss (NOLOAD) : {
            *(.sec48)
            *sec48*.o(.bss COMMON)
        . = ALIGN(4); __sec48_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 49:
     *--------------------------------------------------------------------------------------------*/
    .sec49.data : AT (LOADADDR(.sec48.data) + SIZEOF(.sec48.data)) ALIGN(0x400) { __sec49_load = LOADADDR(.sec49.data);
        __sec49_start = .;
            *(.sec49_init)
            *sec49*.o(.data)
        . = ALIGN(4); __sec49_bss = .;
    } > core_ram_1

    .sec49.bss __sec49_bss (NOLOAD) : {
            *(.sec49)
            *sec49*.o(.bss COMMON)
        . = ALIGN(4); __sec49_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 4A:
     *--------------------------------------------------------------------------------------------*/
    .sec4A.data : AT (LOADADDR(.sec49.data) + SIZEOF(.sec49.data)) ALIGN(0x400) { __sec4A_load = LOADADDR(.sec4A.data);
        __sec4A_start = .;
            *(.sec4A_init)
            *sec4A*.o(.data)
        . = ALIGN(4); __sec4A_bss = .;
    } > core_ram_1

    .sec4A.bss __sec4A_bss (NOLOAD) : {
            *(.sec4A)
            *sec4A*.o(.bss COMMON)
        . = ALIGN(4); __sec4A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 4B:
     *--------------------------------------------------------------------------------------------*/
    .sec4B.data : AT (LOADADDR(.sec4A.data) + SIZEOF(.sec4A.data)) ALIGN(0x400) { __sec4B_load = LOADADDR(.sec4B.data);
        __sec4B_start = .;
            *(.sec4B_init)
            *sec4B*.o(.data)
        . = ALIGN(4); __sec4B_bss = .;
    } > core_ram_1

    .sec4B.bss __sec4B_bss (NOLOAD) : {
            *(.sec4B)
            *sec4B*.o(.bss COMMON)
        . = ALIGN(4); __sec4B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 4C:
     *--------------------------------------------------------------------------------------------*/
    .sec4C.data : AT (LOADADDR(.sec4B.data) + SIZEOF(.sec4B.data)) ALIGN(0x400) { __sec4C_load = LOADADDR(.sec4C.data);
        __sec4C_start = .;
            *(.sec4C_init)
            *sec4C*.o(.data)
        . = ALIGN(4); __sec4C_bss = .;
    } > core_ram_1

    .sec4C.bss __sec4C_bss (NOLOAD) : {
            *(.sec4C)
            *sec4C*.o(.bss COMMON)
        . = ALIGN(4); __sec4C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 4D:
     *--------------------------------------------------------------------------------------------*/
    .sec4D.data : AT (LOADADDR(.sec4C.data) + SIZEOF(.sec4C.data)) ALIGN(0x400) { __sec4D_load = LOADADDR(.sec4D.data);
        __sec4D_start = .;
            *(.sec4D_init)
            *sec4D*.o(.data)
        . = ALIGN(4); __sec4D_bss = .;
    } > core_ram_1

    .sec4D.bss __sec4D_bss (NOLOAD) : {
            *(.sec4D)
            *sec4D*.o(.bss COMMON)
        . = ALIGN(4); __sec4D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 4E:
     *--------------------------------------------------------------------------------------------*/
    .sec4E.data : AT (LOADADDR(.sec4D.data) + SIZEOF(.sec4D.data)) ALIGN(0x400) { __sec4E_load = LOADADDR(.sec4E.data);
        __sec4E_start = .;
            *(.sec4E_init)
            *sec4E*.o(.data)
        . = ALIGN(4); __sec4E_bss = .;
    } > core_ram_1

    .sec4E.bss __sec4E_bss (NOLOAD) : {
            *(.sec4E)
            *sec4E*.o(.bss COMMON)
        . = ALIGN(4); __sec4E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 4F:
     *--------------------------------------------------------------------------------------------*/
    .sec4F.data : AT (LOADADDR(.sec4E.data) + SIZEOF(.sec4E.data)) ALIGN(0x400) { __sec4F_load = LOADADDR(.sec4F.data);
        __sec4F_start = .;
            *(.sec4F_init)
            *sec4F*.o(.data)
        . = ALIGN(4); __sec4F_bss = .;
    } > core_ram_1

    .sec4F.bss __sec4F_bss (NOLOAD) : {
            *(.sec4F)
            *sec4F*.o(.bss COMMON)
        . = ALIGN(4); __sec4F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 50:
     *--------------------------------------------------------------------------------------------*/
    .sec50.data : AT (LOADADDR(.sec4F.data) + SIZEOF(.sec4F.data)) ALIGN(0x400) { __sec50_load = LOADADDR(.sec50.data);
        __sec50_start = .;
            *(.sec50_init)
            *sec50*.o(.data)
        . = ALIGN(4); __sec50_bss = .;
    } > core_ram_1

    .sec50.bss __sec50_bss (NOLOAD) : {
            *(.sec50)
            *sec50*.o(.bss COMMON)
        . = ALIGN(4); __sec50_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 51:
     *--------------------------------------------------------------------------------------------*/
    .sec51.data : AT (LOADADDR(.sec50.data) + SIZEOF(.sec50.data)) ALIGN(0x400) { __sec51_load = LOADADDR(.sec51.data);
        __sec51_start = .;
            *(.sec51_init)
            *sec51*.o(.data)
        . = ALIGN(4); __sec51_bss = .;
    } > core_ram_1

    .sec51.bss __sec51_bss (NOLOAD) : {
            *(.sec51)
            *sec51*.o(.bss COMMON)
        . = ALIGN(4); __sec51_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 52:
     *--------------------------------------------------------------------------------------------*/
    .sec52.data : AT (LOADADDR(.sec51.data) + SIZEOF(.sec51.data)) ALIGN(0x400) { __sec52_load = LOADADDR(.sec52.data);
        __sec52_start = .;
            *(.sec52_init)
            *sec52*.o(.data)
        . = ALIGN(4); __sec52_bss = .;
    } > core_ram_1

    .sec52.bss __sec52_bss (NOLOAD) : {
            *(.sec52)
            *sec52*.o(.bss COMMON)
        . = ALIGN(4); __sec52_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 53:
     *--------------------------------------------------------------------------------------------*/
    .sec53.data : AT (LOADADDR(.sec52.data) + SIZEOF(.sec52.data)) ALIGN(0x400) { __sec53_load = LOADADDR(.sec53.data);
        __sec53_start = .;
            *(.sec53_init)
            *sec53*.o(.data)
        . = ALIGN(4); __sec53_bss = .;
    } > core_ram_1

    .sec53.bss __sec53_bss (NOLOAD) : {
            *(.sec53)
            *sec53*.o(.bss COMMON)
        . = ALIGN(4); __sec53_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 54:
     *--------------------------------------------------------------------------------------------*/
    .sec54.data : AT (LOADADDR(.sec53.data) + SIZEOF(.sec53.data)) ALIGN(0x400) { __sec54_load = LOADADDR(.sec54.data);
        __sec54_start = .;
            *(.sec54_init)
            *sec54*.o(.data)
        . = ALIGN(4); __sec54_bss = .;
    } > core_ram_1

    .sec54.bss __sec54_bss (NOLOAD) : {
            *(.sec54)
            *sec54*.o(.bss COMMON)
        . = ALIGN(4); __sec54_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 55:
     *--------------------------------------------------------------------------------------------*/
    .sec55.data : AT (LOADADDR(.sec54.data) + SIZEOF(.sec54.data)) ALIGN(0x400) { __sec55_load = LOADADDR(.sec55.data);
        __sec55_start = .;
            *(.sec55_init)
            *sec55*.o(.data)
        . = ALIGN(4); __sec55_bss = .;
    } > core_ram_1

    .sec55.bss __sec55_bss (NOLOAD) : {
            *(.sec55)
            *sec55*.o(.bss COMMON)
        . = ALIGN(4); __sec55_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 56:
     *--------------------------------------------------------------------------------------------*/
    .sec56.data : AT (LOADADDR(.sec55.data) + SIZEOF(.sec55.data)) ALIGN(0x400) { __sec56_load = LOADADDR(.sec56.data);
        __sec56_start = .;
            *(.sec56_init)
            *sec56*.o(.data)
        . = ALIGN(4); __sec56_bss = .;
    } > core_ram_1

    .sec56.bss __sec56_bss (NOLOAD) : {
            *(.sec56)
            *sec56*.o(.bss COMMON)
        . = ALIGN(4); __sec56_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 57:
     *--------------------------------------------------------------------------------------------*/
    .sec57.data : AT (LOADADDR(.sec56.data) + SIZEOF(.sec56.data)) ALIGN(0x400) { __sec57_load = LOADADDR(.sec57.data);
        __sec57_start = .;
            *(.sec57_init)
            *sec57*.o(.data)
        . = ALIGN(4); __sec57_bss = .;
    } > core_ram_1

    .sec57.bss __sec57_bss (NOLOAD) : {
            *(.sec57)
            *sec57*.o(.bss COMMON)
        . = ALIGN(4); __sec57_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 58:
     *--------------------------------------------------------------------------------------------*/
    .sec58.data : AT (LOADADDR(.sec57.data) + SIZEOF(.sec57.data)) ALIGN(0x400) { __sec58_load = LOADADDR(.sec58.data);
        __sec58_start = .;
            *(.sec58_init)
            *sec58*.o(.data)
        . = ALIGN(4); __sec58_bss = .;
    } > core_ram_1

    .sec58.bss __sec58_bss (NOLOAD) : {
            *(.sec58)
            *sec58*.o(.bss COMMON)
        . = ALIGN(4); __sec58_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 59:
     *--------------------------------------------------------------------------------------------*/
    .sec59.data : AT (LOADADDR(.sec58.data) + SIZEOF(.sec58.data)) ALIGN(0x400) { __sec59_load = LOADADDR(.sec59.data);
        __sec59_start = .;
            *(.sec59_init)
            *sec59*.o(.data)
        . = ALIGN(4); __sec59_bss = .;
    } > core_ram_1

    .sec59.bss __sec59_bss (NOLOAD) : {
            *(.sec59)
            *sec59*.o(.bss COMMON)
        . = ALIGN(4); __sec59_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 5A:
     *--------------------------------------------------------------------------------------------*/
    .sec5A.data : AT (LOADADDR(.sec59.data) + SIZEOF(.sec59.data)) ALIGN(0x400) { __sec5A_load = LOADADDR(.sec5A.data);
        __sec5A_start = .;
            *(.sec5A_init)
            *sec5A*.o(.data)
        . = ALIGN(4); __sec5A_bss = .;
    } > core_ram_1

    .sec5A.bss __sec5A_bss (NOLOAD) : {
            *(.sec5A)
            *sec5A*.o(.bss COMMON)
        . = ALIGN(4); __sec5A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 5B:
     *--------------------------------------------------------------------------------------------*/
    .sec5B.data : AT (LOADADDR(.sec5A.data) + SIZEOF(.sec5A.data)) ALIGN(0x400) { __sec5B_load = LOADADDR(.sec5B.data);
        __sec5B_start = .;
            *(.sec5B_init)
            *sec5B*.o(.data)
        . = ALIGN(4); __sec5B_bss = .;
    } > core_ram_1

    .sec5B.bss __sec5B_bss (NOLOAD) : {
            *(.sec5B)
            *sec5B*.o(.bss COMMON)
        . = ALIGN(4); __sec5B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 5C:
     *--------------------------------------------------------------------------------------------*/
    .sec5C.data : AT (LOADADDR(.sec5B.data) + SIZEOF(.sec5B.data)) ALIGN(0x400) { __sec5C_load = LOADADDR(.sec5C.data);
        __sec5C_start = .;
            *(.sec5C_init)
            *sec5C*.o(.data)
        . = ALIGN(4); __sec5C_bss = .;
    } > core_ram_1

    .sec5C.bss __sec5C_bss (NOLOAD) : {
            *(.sec5C)
            *sec5C*.o(.bss COMMON)
        . = ALIGN(4); __sec5C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 5D:
     *--------------------------------------------------------------------------------------------*/
    .sec5D.data : AT (LOADADDR(.sec5C.data) + SIZEOF(.sec5C.data)) ALIGN(0x400) { __sec5D_load = LOADADDR(.sec5D.data);
        __sec5D_start = .;
            *(.sec5D_init)
            *sec5D*.o(.data)
        . = ALIGN(4); __sec5D_bss = .;
    } > core_ram_1

    .sec5D.bss __sec5D_bss (NOLOAD) : {
            *(.sec5D)
            *sec5D*.o(.bss COMMON)
        . = ALIGN(4); __sec5D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 5E:
     *--------------------------------------------------------------------------------------------*/
    .sec5E.data : AT (LOADADDR(.sec5D.data) + SIZEOF(.sec5D.data)) ALIGN(0x400) { __sec5E_load = LOADADDR(.sec5E.data);
        __sec5E_start = .;
            *(.sec5E_init)
            *sec5E*.o(.data)
        . = ALIGN(4); __sec5E_bss = .;
    } > core_ram_1

    .sec5E.bss __sec5E_bss (NOLOAD) : {
            *(.sec5E)
            *sec5E*.o(.bss COMMON)
        . = ALIGN(4); __sec5E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 5F:
     *--------------------------------------------------------------------------------------------*/
    .sec5F.data : AT (LOADADDR(.sec5E.data) + SIZEOF(.sec5E.data)) ALIGN(0x400) { __sec5F_load = LOADADDR(.sec5F.data);
        __sec5F_start = .;
            *(.sec5F_init)
            *sec5F*.o(.data)
        . = ALIGN(4); __sec5F_bss = .;
    } > core_ram_1

    .sec5F.bss __sec5F_bss (NOLOAD) : {
            *(.sec5F)
            *sec5F*.o(.bss COMMON)
        . = ALIGN(4); __sec5F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 60:
     *--------------------------------------------------------------------------------------------*/
    .sec60.data : AT (LOADADDR(.sec5F.data) + SIZEOF(.sec5F.data)) ALIGN(0x400) { __sec60_load = LOADADDR(.sec60.data);
        __sec60_start = .;
            *(.sec60_init)
            *sec60*.o(.data)
        . = ALIGN(4); __sec60_bss = .;
    } > core_ram_1

    .sec60.bss __sec60_bss (NOLOAD) : {
            *(.sec60)
            *sec60*.o(.bss COMMON)
        . = ALIGN(4); __sec60_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 61:
     *--------------------------------------------------------------------------------------------*/
    .sec61.data : AT (LOADADDR(.sec60.data) + SIZEOF(.sec60.data)) ALIGN(0x400) { __sec61_load = LOADADDR(.sec61.data);
        __sec61_start = .;
            *(.sec61_init)
            *sec61*.o(.data)
        . = ALIGN(4); __sec61_bss = .;
    } > core_ram_1

    .sec61.bss __sec61_bss (NOLOAD) : {
            *(.sec61)
            *sec61*.o(.bss COMMON)
        . = ALIGN(4); __sec61_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 62:
     *--------------------------------------------------------------------------------------------*/
    .sec62.data : AT (LOADADDR(.sec61.data) + SIZEOF(.sec61.data)) ALIGN(0x400) { __sec62_load = LOADADDR(.sec62.data);
        __sec62_start = .;
            *(.sec62_init)
            *sec62*.o(.data)
        . = ALIGN(4); __sec62_bss = .;
    } > core_ram_1

    .sec62.bss __sec62_bss (NOLOAD) : {
            *(.sec62)
            *sec62*.o(.bss COMMON)
        . = ALIGN(4); __sec62_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 63:
     *--------------------------------------------------------------------------------------------*/
    .sec63.data : AT (LOADADDR(.sec62.data) + SIZEOF(.sec62.data)) ALIGN(0x400) { __sec63_load = LOADADDR(.sec63.data);
        __sec63_start = .;
            *(.sec63_init)
            *sec63*.o(.data)
        . = ALIGN(4); __sec63_bss = .;
    } > core_ram_1

    .sec63.bss __sec63_bss (NOLOAD) : {
            *(.sec63)
            *sec63*.o(.bss COMMON)
        . = ALIGN(4); __sec63_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 64:
     *--------------------------------------------------------------------------------------------*/
    .sec64.data : AT (LOADADDR(.sec63.data) + SIZEOF(.sec63.data)) ALIGN(0x400) { __sec64_load = LOADADDR(.sec64.data);
        __sec64_start = .;
            *(.sec64_init)
            *sec64*.o(.data)
        . = ALIGN(4); __sec64_bss = .;
    } > core_ram_1

    .sec64.bss __sec64_bss (NOLOAD) : {
            *(.sec64)
            *sec64*.o(.bss COMMON)
        . = ALIGN(4); __sec64_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 65:
     *--------------------------------------------------------------------------------------------*/
    .sec65.data : AT (LOADADDR(.sec64.data) + SIZEOF(.sec64.data)) ALIGN(0x400) { __sec65_load = LOADADDR(.sec65.data);
        __sec65_start = .;
            *(.sec65_init)
            *sec65*.o(.data)
        . = ALIGN(4); __sec65_bss = .;
    } > core_ram_1

    .sec65.bss __sec65_bss (NOLOAD) : {
            *(.sec65)
            *sec65*.o(.bss COMMON)
        . = ALIGN(4); __sec65_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 66:
     *--------------------------------------------------------------------------------------------*/
    .sec66.data : AT (LOADADDR(.sec65.data) + SIZEOF(.sec65.data)) ALIGN(0x400) { __sec66_load = LOADADDR(.sec66.data);
        __sec66_start = .;
            *(.sec66_init)
            *sec66*.o(.data)
        . = ALIGN(4); __sec66_bss = .;
    } > core_ram_1

    .sec66.bss __sec66_bss (NOLOAD) : {
            *(.sec66)
            *sec66*.o(.bss COMMON)
        . = ALIGN(4); __sec66_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 67:
     *--------------------------------------------------------------------------------------------*/
    .sec67.data : AT (LOADADDR(.sec66.data) + SIZEOF(.sec66.data)) ALIGN(0x400) { __sec67_load = LOADADDR(.sec67.data);
        __sec67_start = .;
            *(.sec67_init)
            *sec67*.o(.data)
        . = ALIGN(4); __sec67_bss = .;
    } > core_ram_1

    .sec67.bss __sec67_bss (NOLOAD) : {
            *(.sec67)
            *sec67*.o(.bss COMMON)
        . = ALIGN(4); __sec67_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 68:
     *--------------------------------------------------------------------------------------------*/
    .sec68.data : AT (LOADADDR(.sec67.data) + SIZEOF(.sec67.data)) ALIGN(0x400) { __sec68_load = LOADADDR(.sec68.data);
        __sec68_start = .;
            *(.sec68_init)
            *sec68*.o(.data)
        . = ALIGN(4); __sec68_bss = .;
    } > core_ram_1

    .sec68.bss __sec68_bss (NOLOAD) : {
            *(.sec68)
            *sec68*.o(.bss COMMON)
        . = ALIGN(4); __sec68_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 69:
     *--------------------------------------------------------------------------------------------*/
    .sec69.data : AT (LOADADDR(.sec68.data) + SIZEOF(.sec68.data)) ALIGN(0x400) { __sec69_load = LOADADDR(.sec69.data);
        __sec69_start = .;
            *(.sec69_init)
            *sec69*.o(.data)
        . = ALIGN(4); __sec69_bss = .;
    } > core_ram_1

    .sec69.bss __sec69_bss (NOLOAD) : {
            *(.sec69)
            *sec69*.o(.bss COMMON)
        . = ALIGN(4); __sec69_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 6A:
     *--------------------------------------------------------------------------------------------*/
    .sec6A.data : AT (LOADADDR(.sec69.data) + SIZEOF(.sec69.data)) ALIGN(0x400) { __sec6A_load = LOADADDR(.sec6A.data);
        __sec6A_start = .;
            *(.sec6A_init)
            *sec6A*.o(.data)
        . = ALIGN(4); __sec6A_bss = .;
    } > core_ram_1

    .sec6A.bss __sec6A_bss (NOLOAD) : {
            *(.sec6A)
            *sec6A*.o(.bss COMMON)
        . = ALIGN(4); __sec6A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 6B:
     *--------------------------------------------------------------------------------------------*/
    .sec6B.data : AT (LOADADDR(.sec6A.data) + SIZEOF(.sec6A.data)) ALIGN(0x400) { __sec6B_load = LOADADDR(.sec6B.data);
        __sec6B_start = .;
            *(.sec6B_init)
            *sec6B*.o(.data)
        . = ALIGN(4); __sec6B_bss = .;
    } > core_ram_1

    .sec6B.bss __sec6B_bss (NOLOAD) : {
            *(.sec6B)
            *sec6B*.o(.bss COMMON)
        . = ALIGN(4); __sec6B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 6C:
     *--------------------------------------------------------------------------------------------*/
    .sec6C.data : AT (LOADADDR(.sec6B.data) + SIZEOF(.sec6B.data)) ALIGN(0x400) { __sec6C_load = LOADADDR(.sec6C.data);
        __sec6C_start = .;
            *(.sec6C_init)
            *sec6C*.o(.data)
        . = ALIGN(4); __sec6C_bss = .;
    } > core_ram_1

    .sec6C.bss __sec6C_bss (NOLOAD) : {
            *(.sec6C)
            *sec6C*.o(.bss COMMON)
        . = ALIGN(4); __sec6C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 6D:
     *--------------------------------------------------------------------------------------------*/
    .sec6D.data : AT (LOADADDR(.sec6C.data) + SIZEOF(.sec6C.data)) ALIGN(0x400) { __sec6D_load = LOADADDR(.sec6D.data);
        __sec6D_start = .;
            *(.sec6D_init)
            *sec6D*.o(.data)
        . = ALIGN(4); __sec6D_bss = .;
    } > core_ram_1

    .sec6D.bss __sec6D_bss (NOLOAD) : {
            *(.sec6D)
            *sec6D*.o(.bss COMMON)
        . = ALIGN(4); __sec6D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 6E:
     *--------------------------------------------------------------------------------------------*/
    .sec6E.data : AT (LOADADDR(.sec6D.data) + SIZEOF(.sec6D.data)) ALIGN(0x400) { __sec6E_load = LOADADDR(.sec6E.data);
        __sec6E_start = .;
            *(.sec6E_init)
            *sec6E*.o(.data)
        . = ALIGN(4); __sec6E_bss = .;
    } > core_ram_1

    .sec6E.bss __sec6E_bss (NOLOAD) : {
            *(.sec6E)
            *sec6E*.o(.bss COMMON)
        . = ALIGN(4); __sec6E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 6F:
     *--------------------------------------------------------------------------------------------*/
    .sec6F.data : AT (LOADADDR(.sec6E.data) + SIZEOF(.sec6E.data)) ALIGN(0x400) { __sec6F_load = LOADADDR(.sec6F.data);
        __sec6F_start = .;
            *(.sec6F_init)
            *sec6F*.o(.data)
        . = ALIGN(4); __sec6F_bss = .;
    } > core_ram_1

    .sec6F.bss __sec6F_bss (NOLOAD) : {
            *(.sec6F)
            *sec6F*.o(.bss COMMON)
        . = ALIGN(4); __sec6F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 70:
     *--------------------------------------------------------------------------------------------*/
    .sec70.data : AT (LOADADDR(.sec6F.data) + SIZEOF(.sec6F.data)) ALIGN(0x400) { __sec70_load = LOADADDR(.sec70.data);
        __sec70_start = .;
            *(.sec70_init)
            *sec70*.o(.data)
        . = ALIGN(4); __sec70_bss = .;
    } > core_ram_1

    .sec70.bss __sec70_bss (NOLOAD) : {
            *(.sec70)
            *sec70*.o(.bss COMMON)
        . = ALIGN(4); __sec70_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 71:
     *--------------------------------------------------------------------------------------------*/
    .sec71.data : AT (LOADADDR(.sec70.data) + SIZEOF(.sec70.data)) ALIGN(0x400) { __sec71_load = LOADADDR(.sec71.data);
        __sec71_start = .;
            *(.sec71_init)
            *sec71*.o(.data)
        . = ALIGN(4); __sec71_bss = .;
    } > core_ram_1

    .sec71.bss __sec71_bss (NOLOAD) : {
            *(.sec71)
            *sec71*.o(.bss COMMON)
        . = ALIGN(4); __sec71_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 72:
     *--------------------------------------------------------------------------------------------*/
    .sec72.data : AT (LOADADDR(.sec71.data) + SIZEOF(.sec71.data)) ALIGN(0x400) { __sec72_load = LOADADDR(.sec72.data);
        __sec72_start = .;
            *(.sec72_init)
            *sec72*.o(.data)
        . = ALIGN(4); __sec72_bss = .;
    } > core_ram_1

    .sec72.bss __sec72_bss (NOLOAD) : {
            *(.sec72)
            *sec72*.o(.bss COMMON)
        . = ALIGN(4); __sec72_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 73:
     *--------------------------------------------------------------------------------------------*/
    .sec73.data : AT (LOADADDR(.sec72.data) + SIZEOF(.sec72.data)) ALIGN(0x400) { __sec73_load = LOADADDR(.sec73.data);
        __sec73_start = .;
            *(.sec73_init)
            *sec73*.o(.data)
        . = ALIGN(4); __sec73_bss = .;
    } > core_ram_1

    .sec73.bss __sec73_bss (NOLOAD) : {
            *(.sec73)
            *sec73*.o(.bss COMMON)
        . = ALIGN(4); __sec73_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 74:
     *--------------------------------------------------------------------------------------------*/
    .sec74.data : AT (LOADADDR(.sec73.data) + SIZEOF(.sec73.data)) ALIGN(0x400) { __sec74_load = LOADADDR(.sec74.data);
        __sec74_start = .;
            *(.sec74_init)
            *sec74*.o(.data)
        . = ALIGN(4); __sec74_bss = .;
    } > core_ram_1

    .sec74.bss __sec74_bss (NOLOAD) : {
            *(.sec74)
            *sec74*.o(.bss COMMON)
        . = ALIGN(4); __sec74_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 75:
     *--------------------------------------------------------------------------------------------*/
    .sec75.data : AT (LOADADDR(.sec74.data) + SIZEOF(.sec74.data)) ALIGN(0x400) { __sec75_load = LOADADDR(.sec75.data);
        __sec75_start = .;
            *(.sec75_init)
            *sec75*.o(.data)
        . = ALIGN(4); __sec75_bss = .;
    } > core_ram_1

    .sec75.bss __sec75_bss (NOLOAD) : {
            *(.sec75)
            *sec75*.o(.bss COMMON)
        . = ALIGN(4); __sec75_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 76:
     *--------------------------------------------------------------------------------------------*/
    .sec76.data : AT (LOADADDR(.sec75.data) + SIZEOF(.sec75.data)) ALIGN(0x400) { __sec76_load = LOADADDR(.sec76.data);
        __sec76_start = .;
            *(.sec76_init)
            *sec76*.o(.data)
        . = ALIGN(4); __sec76_bss = .;
    } > core_ram_1

    .sec76.bss __sec76_bss (NOLOAD) : {
            *(.sec76)
            *sec76*.o(.bss COMMON)
        . = ALIGN(4); __sec76_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 77:
     *--------------------------------------------------------------------------------------------*/
    .sec77.data : AT (LOADADDR(.sec76.data) + SIZEOF(.sec76.data)) ALIGN(0x400) { __sec77_load = LOADADDR(.sec77.data);
        __sec77_start = .;
            *(.sec77_init)
            *sec77*.o(.data)
        . = ALIGN(4); __sec77_bss = .;
    } > core_ram_1

    .sec77.bss __sec77_bss (NOLOAD) : {
            *(.sec77)
            *sec77*.o(.bss COMMON)
        . = ALIGN(4); __sec77_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 78:
     *--------------------------------------------------------------------------------------------*/
    .sec78.data : AT (LOADADDR(.sec77.data) + SIZEOF(.sec77.data)) ALIGN(0x400) { __sec78_load = LOADADDR(.sec78.data);
        __sec78_start = .;
            *(.sec78_init)
            *sec78*.o(.data)
        . = ALIGN(4); __sec78_bss = .;
    } > core_ram_1

    .sec78.bss __sec78_bss (NOLOAD) : {
            *(.sec78)
            *sec78*.o(.bss COMMON)
        . = ALIGN(4); __sec78_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 79:
     *--------------------------------------------------------------------------------------------*/
    .sec79.data : AT (LOADADDR(.sec78.data) + SIZEOF(.sec78.data)) ALIGN(0x400) { __sec79_load = LOADADDR(.sec79.data);
        __sec79_start = .;
            *(.sec79_init)
            *sec79*.o(.data)
        . = ALIGN(4); __sec79_bss = .;
    } > core_ram_1

    .sec79.bss __sec79_bss (NOLOAD) : {
            *(.sec79)
            *sec79*.o(.bss COMMON)
        . = ALIGN(4); __sec79_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 7A:
     *--------------------------------------------------------------------------------------------*/
    .sec7A.data : AT (LOADADDR(.sec79.data) + SIZEOF(.sec79.data)) ALIGN(0x400) { __sec7A_load = LOADADDR(.sec7A.data);
        __sec7A_start = .;
            *(.sec7A_init)
            *sec7A*.o(.data)
        . = ALIGN(4); __sec7A_bss = .;
    } > core_ram_1

    .sec7A.bss __sec7A_bss (NOLOAD) : {
            *(.sec7A)
            *sec7A*.o(.bss COMMON)
        . = ALIGN(4); __sec7A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 7B:
     *--------------------------------------------------------------------------------------------*/
    .sec7B.data : AT (LOADADDR(.sec7A.data) + SIZEOF(.sec7A.data)) ALIGN(0x400) { __sec7B_load = LOADADDR(.sec7B.data);
        __sec7B_start = .;
            *(.sec7B_init)
            *sec7B*.o(.data)
        . = ALIGN(4); __sec7B_bss = .;
    } > core_ram_1

    .sec7B.bss __sec7B_bss (NOLOAD) : {
            *(.sec7B)
            *sec7B*.o(.bss COMMON)
        . = ALIGN(4); __sec7B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 7C:
     *--------------------------------------------------------------------------------------------*/
    .sec7C.data : AT (LOADADDR(.sec7B.data) + SIZEOF(.sec7B.data)) ALIGN(0x400) { __sec7C_load = LOADADDR(.sec7C.data);
        __sec7C_start = .;
            *(.sec7C_init)
            *sec7C*.o(.data)
        . = ALIGN(4); __sec7C_bss = .;
    } > core_ram_1

    .sec7C.bss __sec7C_bss (NOLOAD) : {
            *(.sec7C)
            *sec7C*.o(.bss COMMON)
        . = ALIGN(4); __sec7C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 7D:
     *--------------------------------------------------------------------------------------------*/
    .sec7D.data : AT (LOADADDR(.sec7C.data) + SIZEOF(.sec7C.data)) ALIGN(0x400) { __sec7D_load = LOADADDR(.sec7D.data);
        __sec7D_start = .;
            *(.sec7D_init)
            *sec7D*.o(.data)
        . = ALIGN(4); __sec7D_bss = .;
    } > core_ram_1

    .sec7D.bss __sec7D_bss (NOLOAD) : {
            *(.sec7D)
            *sec7D*.o(.bss COMMON)
        . = ALIGN(4); __sec7D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 7E:
     *--------------------------------------------------------------------------------------------*/
    .sec7E.data : AT (LOADADDR(.sec7D.data) + SIZEOF(.sec7D.data)) ALIGN(0x400) { __sec7E_load = LOADADDR(.sec7E.data);
        __sec7E_start = .;
            *(.sec7E_init)
            *sec7E*.o(.data)
        . = ALIGN(4); __sec7E_bss = .;
    } > core_ram_1

    .sec7E.bss __sec7E_bss (NOLOAD) : {
            *(.sec7E)
            *sec7E*.o(.bss COMMON)
        . = ALIGN(4); __sec7E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 7F:
     *--------------------------------------------------------------------------------------------*/
    .sec7F.data : AT (LOADADDR(.sec7E.data) + SIZEOF(.sec7E.data)) ALIGN(0x400) { __sec7F_load = LOADADDR(.sec7F.data);
        __sec7F_start = .;
            *(.sec7F_init)
            *sec7F*.o(.data)
        . = ALIGN(4); __sec7F_bss = .;
    } > core_ram_1

    .sec7F.bss __sec7F_bss (NOLOAD) : {
            *(.sec7F)
            *sec7F*.o(.bss COMMON)
        . = ALIGN(4); __sec7F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 80:
     *--------------------------------------------------------------------------------------------*/
    .sec80.data : AT (LOADADDR(.sec7F.data) + SIZEOF(.sec7F.data)) ALIGN(0x400) { __sec80_load = LOADADDR(.sec80.data);
        __sec80_start = .;
            *(.sec80_init)
            *sec80*.o(.data)
        . = ALIGN(4); __sec80_bss = .;
    } > core_ram_1

    .sec80.bss __sec80_bss (NOLOAD) : {
            *(.sec80)
            *sec80*.o(.bss COMMON)
        . = ALIGN(4); __sec80_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 81:
     *--------------------------------------------------------------------------------------------*/
    .sec81.data : AT (LOADADDR(.sec80.data) + SIZEOF(.sec80.data)) ALIGN(0x400) { __sec81_load = LOADADDR(.sec81.data);
        __sec81_start = .;
            *(.sec81_init)
            *sec81*.o(.data)
        . = ALIGN(4); __sec81_bss = .;
    } > core_ram_1

    .sec81.bss __sec81_bss (NOLOAD) : {
            *(.sec81)
            *sec81*.o(.bss COMMON)
        . = ALIGN(4); __sec81_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 82:
     *--------------------------------------------------------------------------------------------*/
    .sec82.data : AT (LOADADDR(.sec81.data) + SIZEOF(.sec81.data)) ALIGN(0x400) { __sec82_load = LOADADDR(.sec82.data);
        __sec82_start = .;
            *(.sec82_init)
            *sec82*.o(.data)
        . = ALIGN(4); __sec82_bss = .;
    } > core_ram_1

    .sec82.bss __sec82_bss (NOLOAD) : {
            *(.sec82)
            *sec82*.o(.bss COMMON)
        . = ALIGN(4); __sec82_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 83:
     *--------------------------------------------------------------------------------------------*/
    .sec83.data : AT (LOADADDR(.sec82.data) + SIZEOF(.sec82.data)) ALIGN(0x400) { __sec83_load = LOADADDR(.sec83.data);
        __sec83_start = .;
            *(.sec83_init)
            *sec83*.o(.data)
        . = ALIGN(4); __sec83_bss = .;
    } > core_ram_1

    .sec83.bss __sec83_bss (NOLOAD) : {
            *(.sec83)
            *sec83*.o(.bss COMMON)
        . = ALIGN(4); __sec83_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 84:
     *--------------------------------------------------------------------------------------------*/
    .sec84.data : AT (LOADADDR(.sec83.data) + SIZEOF(.sec83.data)) ALIGN(0x400) { __sec84_load = LOADADDR(.sec84.data);
        __sec84_start = .;
            *(.sec84_init)
            *sec84*.o(.data)
        . = ALIGN(4); __sec84_bss = .;
    } > core_ram_1

    .sec84.bss __sec84_bss (NOLOAD) : {
            *(.sec84)
            *sec84*.o(.bss COMMON)
        . = ALIGN(4); __sec84_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 85:
     *--------------------------------------------------------------------------------------------*/
    .sec85.data : AT (LOADADDR(.sec84.data) + SIZEOF(.sec84.data)) ALIGN(0x400) { __sec85_load = LOADADDR(.sec85.data);
        __sec85_start = .;
            *(.sec85_init)
            *sec85*.o(.data)
        . = ALIGN(4); __sec85_bss = .;
    } > core_ram_1

    .sec85.bss __sec85_bss (NOLOAD) : {
            *(.sec85)
            *sec85*.o(.bss COMMON)
        . = ALIGN(4); __sec85_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 86:
     *--------------------------------------------------------------------------------------------*/
    .sec86.data : AT (LOADADDR(.sec85.data) + SIZEOF(.sec85.data)) ALIGN(0x400) { __sec86_load = LOADADDR(.sec86.data);
        __sec86_start = .;
            *(.sec86_init)
            *sec86*.o(.data)
        . = ALIGN(4); __sec86_bss = .;
    } > core_ram_1

    .sec86.bss __sec86_bss (NOLOAD) : {
            *(.sec86)
            *sec86*.o(.bss COMMON)
        . = ALIGN(4); __sec86_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 87:
     *--------------------------------------------------------------------------------------------*/
    .sec87.data : AT (LOADADDR(.sec86.data) + SIZEOF(.sec86.data)) ALIGN(0x400) { __sec87_load = LOADADDR(.sec87.data);
        __sec87_start = .;
            *(.sec87_init)
            *sec87*.o(.data)
        . = ALIGN(4); __sec87_bss = .;
    } > core_ram_1

    .sec87.bss __sec87_bss (NOLOAD) : {
            *(.sec87)
            *sec87*.o(.bss COMMON)
        . = ALIGN(4); __sec87_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 88:
     *--------------------------------------------------------------------------------------------*/
    .sec88.data : AT (LOADADDR(.sec87.data) + SIZEOF(.sec87.data)) ALIGN(0x400) { __sec88_load = LOADADDR(.sec88.data);
        __sec88_start = .;
            *(.sec88_init)
            *sec88*.o(.data)
        . = ALIGN(4); __sec88_bss = .;
    } > core_ram_1

    .sec88.bss __sec88_bss (NOLOAD) : {
            *(.sec88)
            *sec88*.o(.bss COMMON)
        . = ALIGN(4); __sec88_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 89:
     *--------------------------------------------------------------------------------------------*/
    .sec89.data : AT (LOADADDR(.sec88.data) + SIZEOF(.sec88.data)) ALIGN(0x400) { __sec89_load = LOADADDR(.sec89.data);
        __sec89_start = .;
            *(.sec89_init)
            *sec89*.o(.data)
        . = ALIGN(4); __sec89_bss = .;
    } > core_ram_1

    .sec89.bss __sec89_bss (NOLOAD) : {
            *(.sec89)
            *sec89*.o(.bss COMMON)
        . = ALIGN(4); __sec89_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 8A:
     *--------------------------------------------------------------------------------------------*/
    .sec8A.data : AT (LOADADDR(.sec89.data) + SIZEOF(.sec89.data)) ALIGN(0x400) { __sec8A_load = LOADADDR(.sec8A.data);
        __sec8A_start = .;
            *(.sec8A_init)
            *sec8A*.o(.data)
        . = ALIGN(4); __sec8A_bss = .;
    } > core_ram_1

    .sec8A.bss __sec8A_bss (NOLOAD) : {
            *(.sec8A)
            *sec8A*.o(.bss COMMON)
        . = ALIGN(4); __sec8A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 8B:
     *--------------------------------------------------------------------------------------------*/
    .sec8B.data : AT (LOADADDR(.sec8A.data) + SIZEOF(.sec8A.data)) ALIGN(0x400) { __sec8B_load = LOADADDR(.sec8B.data);
        __sec8B_start = .;
            *(.sec8B_init)
            *sec8B*.o(.data)
        . = ALIGN(4); __sec8B_bss = .;
    } > core_ram_1

    .sec8B.bss __sec8B_bss (NOLOAD) : {
            *(.sec8B)
            *sec8B*.o(.bss COMMON)
        . = ALIGN(4); __sec8B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 8C:
     *--------------------------------------------------------------------------------------------*/
    .sec8C.data : AT (LOADADDR(.sec8B.data) + SIZEOF(.sec8B.data)) ALIGN(0x400) { __sec8C_load = LOADADDR(.sec8C.data);
        __sec8C_start = .;
            *(.sec8C_init)
            *sec8C*.o(.data)
        . = ALIGN(4); __sec8C_bss = .;
    } > core_ram_1

    .sec8C.bss __sec8C_bss (NOLOAD) : {
            *(.sec8C)
            *sec8C*.o(.bss COMMON)
        . = ALIGN(4); __sec8C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 8D:
     *--------------------------------------------------------------------------------------------*/
    .sec8D.data : AT (LOADADDR(.sec8C.data) + SIZEOF(.sec8C.data)) ALIGN(0x400) { __sec8D_load = LOADADDR(.sec8D.data);
        __sec8D_start = .;
            *(.sec8D_init)
            *sec8D*.o(.data)
        . = ALIGN(4); __sec8D_bss = .;
    } > core_ram_1

    .sec8D.bss __sec8D_bss (NOLOAD) : {
            *(.sec8D)
            *sec8D*.o(.bss COMMON)
        . = ALIGN(4); __sec8D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 8E:
     *--------------------------------------------------------------------------------------------*/
    .sec8E.data : AT (LOADADDR(.sec8D.data) + SIZEOF(.sec8D.data)) ALIGN(0x400) { __sec8E_load = LOADADDR(.sec8E.data);
        __sec8E_start = .;
            *(.sec8E_init)
            *sec8E*.o(.data)
        . = ALIGN(4); __sec8E_bss = .;
    } > core_ram_1

    .sec8E.bss __sec8E_bss (NOLOAD) : {
            *(.sec8E)
            *sec8E*.o(.bss COMMON)
        . = ALIGN(4); __sec8E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 8F:
     *--------------------------------------------------------------------------------------------*/
    .sec8F.data : AT (LOADADDR(.sec8E.data) + SIZEOF(.sec8E.data)) ALIGN(0x400) { __sec8F_load = LOADADDR(.sec8F.data);
        __sec8F_start = .;
            *(.sec8F_init)
            *sec8F*.o(.data)
        . = ALIGN(4); __sec8F_bss = .;
    } > core_ram_1

    .sec8F.bss __sec8F_bss (NOLOAD) : {
            *(.sec8F)
            *sec8F*.o(.bss COMMON)
        . = ALIGN(4); __sec8F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 90:
     *--------------------------------------------------------------------------------------------*/
    .sec90.data : AT (LOADADDR(.sec8F.data) + SIZEOF(.sec8F.data)) ALIGN(0x400) { __sec90_load = LOADADDR(.sec90.data);
        __sec90_start = .;
            *(.sec90_init)
            *sec90*.o(.data)
        . = ALIGN(4); __sec90_bss = .;
    } > core_ram_1

    .sec90.bss __sec90_bss (NOLOAD) : {
            *(.sec90)
            *sec90*.o(.bss COMMON)
        . = ALIGN(4); __sec90_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 91:
     *--------------------------------------------------------------------------------------------*/
    .sec91.data : AT (LOADADDR(.sec90.data) + SIZEOF(.sec90.data)) ALIGN(0x400) { __sec91_load = LOADADDR(.sec91.data);
        __sec91_start = .;
            *(.sec91_init)
            *sec91*.o(.data)
        . = ALIGN(4); __sec91_bss = .;
    } > core_ram_1

    .sec91.bss __sec91_bss (NOLOAD) : {
            *(.sec91)
            *sec91*.o(.bss COMMON)
        . = ALIGN(4); __sec91_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 92:
     *--------------------------------------------------------------------------------------------*/
    .sec92.data : AT (LOADADDR(.sec91.data) + SIZEOF(.sec91.data)) ALIGN(0x400) { __sec92_load = LOADADDR(.sec92.data);
        __sec92_start = .;
            *(.sec92_init)
            *sec92*.o(.data)
        . = ALIGN(4); __sec92_bss = .;
    } > core_ram_1

    .sec92.bss __sec92_bss (NOLOAD) : {
            *(.sec92)
            *sec92*.o(.bss COMMON)
        . = ALIGN(4); __sec92_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 93:
     *--------------------------------------------------------------------------------------------*/
    .sec93.data : AT (LOADADDR(.sec92.data) + SIZEOF(.sec92.data)) ALIGN(0x400) { __sec93_load = LOADADDR(.sec93.data);
        __sec93_start = .;
            *(.sec93_init)
            *sec93*.o(.data)
        . = ALIGN(4); __sec93_bss = .;
    } > core_ram_1

    .sec93.bss __sec93_bss (NOLOAD) : {
            *(.sec93)
            *sec93*.o(.bss COMMON)
        . = ALIGN(4); __sec93_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 94:
     *--------------------------------------------------------------------------------------------*/
    .sec94.data : AT (LOADADDR(.sec93.data) + SIZEOF(.sec93.data)) ALIGN(0x400) { __sec94_load = LOADADDR(.sec94.data);
        __sec94_start = .;
            *(.sec94_init)
            *sec94*.o(.data)
        . = ALIGN(4); __sec94_bss = .;
    } > core_ram_1

    .sec94.bss __sec94_bss (NOLOAD) : {
            *(.sec94)
            *sec94*.o(.bss COMMON)
        . = ALIGN(4); __sec94_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 95:
     *--------------------------------------------------------------------------------------------*/
    .sec95.data : AT (LOADADDR(.sec94.data) + SIZEOF(.sec94.data)) ALIGN(0x400) { __sec95_load = LOADADDR(.sec95.data);
        __sec95_start = .;
            *(.sec95_init)
            *sec95*.o(.data)
        . = ALIGN(4); __sec95_bss = .;
    } > core_ram_1

    .sec95.bss __sec95_bss (NOLOAD) : {
            *(.sec95)
            *sec95*.o(.bss COMMON)
        . = ALIGN(4); __sec95_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 96:
     *--------------------------------------------------------------------------------------------*/
    .sec96.data : AT (LOADADDR(.sec95.data) + SIZEOF(.sec95.data)) ALIGN(0x400) { __sec96_load = LOADADDR(.sec96.data);
        __sec96_start = .;
            *(.sec96_init)
            *sec96*.o(.data)
        . = ALIGN(4); __sec96_bss = .;
    } > core_ram_1

    .sec96.bss __sec96_bss (NOLOAD) : {
            *(.sec96)
            *sec96*.o(.bss COMMON)
        . = ALIGN(4); __sec96_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 97:
     *--------------------------------------------------------------------------------------------*/
    .sec97.data : AT (LOADADDR(.sec96.data) + SIZEOF(.sec96.data)) ALIGN(0x400) { __sec97_load = LOADADDR(.sec97.data);
        __sec97_start = .;
            *(.sec97_init)
            *sec97*.o(.data)
        . = ALIGN(4); __sec97_bss = .;
    } > core_ram_1

    .sec97.bss __sec97_bss (NOLOAD) : {
            *(.sec97)
            *sec97*.o(.bss COMMON)
        . = ALIGN(4); __sec97_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 98:
     *--------------------------------------------------------------------------------------------*/
    .sec98.data : AT (LOADADDR(.sec97.data) + SIZEOF(.sec97.data)) ALIGN(0x400) { __sec98_load = LOADADDR(.sec98.data);
        __sec98_start = .;
            *(.sec98_init)
            *sec98*.o(.data)
        . = ALIGN(4); __sec98_bss = .;
    } > core_ram_1

    .sec98.bss __sec98_bss (NOLOAD) : {
            *(.sec98)
            *sec98*.o(.bss COMMON)
        . = ALIGN(4); __sec98_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 99:
     *--------------------------------------------------------------------------------------------*/
    .sec99.data : AT (LOADADDR(.sec98.data) + SIZEOF(.sec98.data)) ALIGN(0x400) { __sec99_load = LOADADDR(.sec99.data);
        __sec99_start = .;
            *(.sec99_init)
            *sec99*.o(.data)
        . = ALIGN(4); __sec99_bss = .;
    } > core_ram_1

    .sec99.bss __sec99_bss (NOLOAD) : {
            *(.sec99)
            *sec99*.o(.bss COMMON)
        . = ALIGN(4); __sec99_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 9A:
     *--------------------------------------------------------------------------------------------*/
    .sec9A.data : AT (LOADADDR(.sec99.data) + SIZEOF(.sec99.data)) ALIGN(0x400) { __sec9A_load = LOADADDR(.sec9A.data);
        __sec9A_start = .;
            *(.sec9A_init)
            *sec9A*.o(.data)
        . = ALIGN(4); __sec9A_bss = .;
    } > core_ram_1

    .sec9A.bss __sec9A_bss (NOLOAD) : {
            *(.sec9A)
            *sec9A*.o(.bss COMMON)
        . = ALIGN(4); __sec9A_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 9B:
     *--------------------------------------------------------------------------------------------*/
    .sec9B.data : AT (LOADADDR(.sec9A.data) + SIZEOF(.sec9A.data)) ALIGN(0x400) { __sec9B_load = LOADADDR(.sec9B.data);
        __sec9B_start = .;
            *(.sec9B_init)
            *sec9B*.o(.data)
        . = ALIGN(4); __sec9B_bss = .;
    } > core_ram_1

    .sec9B.bss __sec9B_bss (NOLOAD) : {
            *(.sec9B)
            *sec9B*.o(.bss COMMON)
        . = ALIGN(4); __sec9B_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 9C:
     *--------------------------------------------------------------------------------------------*/
    .sec9C.data : AT (LOADADDR(.sec9B.data) + SIZEOF(.sec9B.data)) ALIGN(0x400) { __sec9C_load = LOADADDR(.sec9C.data);
        __sec9C_start = .;
            *(.sec9C_init)
            *sec9C*.o(.data)
        . = ALIGN(4); __sec9C_bss = .;
    } > core_ram_1

    .sec9C.bss __sec9C_bss (NOLOAD) : {
            *(.sec9C)
            *sec9C*.o(.bss COMMON)
        . = ALIGN(4); __sec9C_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 9D:
     *--------------------------------------------------------------------------------------------*/
    .sec9D.data : AT (LOADADDR(.sec9C.data) + SIZEOF(.sec9C.data)) ALIGN(0x400) { __sec9D_load = LOADADDR(.sec9D.data);
        __sec9D_start = .;
            *(.sec9D_init)
            *sec9D*.o(.data)
        . = ALIGN(4); __sec9D_bss = .;
    } > core_ram_1

    .sec9D.bss __sec9D_bss (NOLOAD) : {
            *(.sec9D)
            *sec9D*.o(.bss COMMON)
        . = ALIGN(4); __sec9D_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 9E:
     *--------------------------------------------------------------------------------------------*/
    .sec9E.data : AT (LOADADDR(.sec9D.data) + SIZEOF(.sec9D.data)) ALIGN(0x400) { __sec9E_load = LOADADDR(.sec9E.data);
        __sec9E_start = .;
            *(.sec9E_init)
            *sec9E*.o(.data)
        . = ALIGN(4); __sec9E_bss = .;
    } > core_ram_1

    .sec9E.bss __sec9E_bss (NOLOAD) : {
            *(.sec9E)
            *sec9E*.o(.bss COMMON)
        . = ALIGN(4); __sec9E_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section 9F:
     *--------------------------------------------------------------------------------------------*/
    .sec9F.data : AT (LOADADDR(.sec9E.data) + SIZEOF(.sec9E.data)) ALIGN(0x400) { __sec9F_load = LOADADDR(.sec9F.data);
        __sec9F_start = .;
            *(.sec9F_init)
            *sec9F*.o(.data)
        . = ALIGN(4); __sec9F_bss = .;
    } > core_ram_1

    .sec9F.bss __sec9F_bss (NOLOAD) : {
            *(.sec9F)
            *sec9F*.o(.bss COMMON)
        . = ALIGN(4); __sec9F_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A0:
     *--------------------------------------------------------------------------------------------*/
    .secA0.data : AT (LOADADDR(.sec9F.data) + SIZEOF(.sec9F.data)) ALIGN(0x400) { __secA0_load = LOADADDR(.secA0.data);
        __secA0_start = .;
            *(.secA0_init)
            *secA0*.o(.data)
        . = ALIGN(4); __secA0_bss = .;
    } > core_ram_1

    .secA0.bss __secA0_bss (NOLOAD) : {
            *(.secA0)
            *secA0*.o(.bss COMMON)
        . = ALIGN(4); __secA0_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A1:
     *--------------------------------------------------------------------------------------------*/
    .secA1.data : AT (LOADADDR(.secA0.data) + SIZEOF(.secA0.data)) ALIGN(0x400) { __secA1_load = LOADADDR(.secA1.data);
        __secA1_start = .;
            *(.secA1_init)
            *secA1*.o(.data)
        . = ALIGN(4); __secA1_bss = .;
    } > core_ram_1

    .secA1.bss __secA1_bss (NOLOAD) : {
            *(.secA1)
            *secA1*.o(.bss COMMON)
        . = ALIGN(4); __secA1_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A2:
     *--------------------------------------------------------------------------------------------*/
    .secA2.data : AT (LOADADDR(.secA1.data) + SIZEOF(.secA1.data)) ALIGN(0x400) { __secA2_load = LOADADDR(.secA2.data);
        __secA2_start = .;
            *(.secA2_init)
            *secA2*.o(.data)
        . = ALIGN(4); __secA2_bss = .;
    } > core_ram_1

    .secA2.bss __secA2_bss (NOLOAD) : {
            *(.secA2)
            *secA2*.o(.bss COMMON)
        . = ALIGN(4); __secA2_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A3:
     *--------------------------------------------------------------------------------------------*/
    .secA3.data : AT (LOADADDR(.secA2.data) + SIZEOF(.secA2.data)) ALIGN(0x400) { __secA3_load = LOADADDR(.secA3.data);
        __secA3_start = .;
            *(.secA3_init)
            *secA3*.o(.data)
        . = ALIGN(4); __secA3_bss = .;
    } > core_ram_1

    .secA3.bss __secA3_bss (NOLOAD) : {
            *(.secA3)
            *secA3*.o(.bss COMMON)
        . = ALIGN(4); __secA3_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A4:
     *--------------------------------------------------------------------------------------------*/
    .secA4.data : AT (LOADADDR(.secA3.data) + SIZEOF(.secA3.data)) ALIGN(0x400) { __secA4_load = LOADADDR(.secA4.data);
        __secA4_start = .;
            *(.secA4_init)
            *secA4*.o(.data)
        . = ALIGN(4); __secA4_bss = .;
    } > core_ram_1

    .secA4.bss __secA4_bss (NOLOAD) : {
            *(.secA4)
            *secA4*.o(.bss COMMON)
        . = ALIGN(4); __secA4_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A5:
     *--------------------------------------------------------------------------------------------*/
    .secA5.data : AT (LOADADDR(.secA4.data) + SIZEOF(.secA4.data)) ALIGN(0x400) { __secA5_load = LOADADDR(.secA5.data);
        __secA5_start = .;
            *(.secA5_init)
            *secA5*.o(.data)
        . = ALIGN(4); __secA5_bss = .;
    } > core_ram_1

    .secA5.bss __secA5_bss (NOLOAD) : {
            *(.secA5)
            *secA5*.o(.bss COMMON)
        . = ALIGN(4); __secA5_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A6:
     *--------------------------------------------------------------------------------------------*/
    .secA6.data : AT (LOADADDR(.secA5.data) + SIZEOF(.secA5.data)) ALIGN(0x400) { __secA6_load = LOADADDR(.secA6.data);
        __secA6_start = .;
            *(.secA6_init)
            *secA6*.o(.data)
        . = ALIGN(4); __secA6_bss = .;
    } > core_ram_1

    .secA6.bss __secA6_bss (NOLOAD) : {
            *(.secA6)
            *secA6*.o(.bss COMMON)
        . = ALIGN(4); __secA6_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A7:
     *--------------------------------------------------------------------------------------------*/
    .secA7.data : AT (LOADADDR(.secA6.data) + SIZEOF(.secA6.data)) ALIGN(0x400) { __secA7_load = LOADADDR(.secA7.data);
        __secA7_start = .;
            *(.secA7_init)
            *secA7*.o(.data)
        . = ALIGN(4); __secA7_bss = .;
    } > core_ram_1

    .secA7.bss __secA7_bss (NOLOAD) : {
            *(.secA7)
            *secA7*.o(.bss COMMON)
        . = ALIGN(4); __secA7_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A8:
     *--------------------------------------------------------------------------------------------*/
    .secA8.data : AT (LOADADDR(.secA7.data) + SIZEOF(.secA7.data)) ALIGN(0x400) { __secA8_load = LOADADDR(.secA8.data);
        __secA8_start = .;
            *(.secA8_init)
            *secA8*.o(.data)
        . = ALIGN(4); __secA8_bss = .;
    } > core_ram_1

    .secA8.bss __secA8_bss (NOLOAD) : {
            *(.secA8)
            *secA8*.o(.bss COMMON)
        . = ALIGN(4); __secA8_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section A9:
     *--------------------------------------------------------------------------------------------*/
    .secA9.data : AT (LOADADDR(.secA8.data) + SIZEOF(.secA8.data)) ALIGN(0x400) { __secA9_load = LOADADDR(.secA9.data);
        __secA9_start = .;
            *(.secA9_init)
            *secA9*.o(.data)
        . = ALIGN(4); __secA9_bss = .;
    } > core_ram_1

    .secA9.bss __secA9_bss (NOLOAD) : {
            *(.secA9)
            *secA9*.o(.bss COMMON)
        . = ALIGN(4); __secA9_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section AA:
     *--------------------------------------------------------------------------------------------*/
    .secAA.data : AT (LOADADDR(.secA9.data) + SIZEOF(.secA9.data)) ALIGN(0x400) { __secAA_load = LOADADDR(.secAA.data);
        __secAA_start = .;
            *(.secAA_init)
            *secAA*.o(.data)
        . = ALIGN(4); __secAA_bss = .;
    } > core_ram_1

    .secAA.bss __secAA_bss (NOLOAD) : {
            *(.secAA)
            *secAA*.o(.bss COMMON)
        . = ALIGN(4); __secAA_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section AB:
     *--------------------------------------------------------------------------------------------*/
    .secAB.data : AT (LOADADDR(.secAA.data) + SIZEOF(.secAA.data)) ALIGN(0x400) { __secAB_load = LOADADDR(.secAB.data);
        __secAB_start = .;
            *(.secAB_init)
            *secAB*.o(.data)
        . = ALIGN(4); __secAB_bss = .;
    } > core_ram_1

    .secAB.bss __secAB_bss (NOLOAD) : {
            *(.secAB)
            *secAB*.o(.bss COMMON)
        . = ALIGN(4); __secAB_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section AC:
     *--------------------------------------------------------------------------------------------*/
    .secAC.data : AT (LOADADDR(.secAB.data) + SIZEOF(.secAB.data)) ALIGN(0x400) { __secAC_load = LOADADDR(.secAC.data);
        __secAC_start = .;
            *(.secAC_init)
            *secAC*.o(.data)
        . = ALIGN(4); __secAC_bss = .;
    } > core_ram_1

    .secAC.bss __secAC_bss (NOLOAD) : {
            *(.secAC)
            *secAC*.o(.bss COMMON)
        . = ALIGN(4); __secAC_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section AD:
     *--------------------------------------------------------------------------------------------*/
    .secAD.data : AT (LOADADDR(.secAC.data) + SIZEOF(.secAC.data)) ALIGN(0x400) { __secAD_load = LOADADDR(.secAD.data);
        __secAD_start = .;
            *(.secAD_init)
            *secAD*.o(.data)
        . = ALIGN(4); __secAD_bss = .;
    } > core_ram_1

    .secAD.bss __secAD_bss (NOLOAD) : {
            *(.secAD)
            *secAD*.o(.bss COMMON)
        . = ALIGN(4); __secAD_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section AE:
     *--------------------------------------------------------------------------------------------*/
    .secAE.data : AT (LOADADDR(.secAD.data) + SIZEOF(.secAD.data)) ALIGN(0x400) { __secAE_load = LOADADDR(.secAE.data);
        __secAE_start = .;
            *(.secAE_init)
            *secAE*.o(.data)
        . = ALIGN(4); __secAE_bss = .;
    } > core_ram_1

    .secAE.bss __secAE_bss (NOLOAD) : {
            *(.secAE)
            *secAE*.o(.bss COMMON)
        . = ALIGN(4); __secAE_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section AF:
     *--------------------------------------------------------------------------------------------*/
    .secAF.data : AT (LOADADDR(.secAE.data) + SIZEOF(.secAE.data)) ALIGN(0x400) { __secAF_load = LOADADDR(.secAF.data);
        __secAF_start = .;
            *(.secAF_init)
            *secAF*.o(.data)
        . = ALIGN(4); __secAF_bss = .;
    } > core_ram_1

    .secAF.bss __secAF_bss (NOLOAD) : {
            *(.secAF)
            *secAF*.o(.bss COMMON)
        . = ALIGN(4); __secAF_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B0:
     *--------------------------------------------------------------------------------------------*/
    .secB0.data : AT (LOADADDR(.secAF.data) + SIZEOF(.secAF.data)) ALIGN(0x400) { __secB0_load = LOADADDR(.secB0.data);
        __secB0_start = .;
            *(.secB0_init)
            *secB0*.o(.data)
        . = ALIGN(4); __secB0_bss = .;
    } > core_ram_1

    .secB0.bss __secB0_bss (NOLOAD) : {
            *(.secB0)
            *secB0*.o(.bss COMMON)
        . = ALIGN(4); __secB0_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B1:
     *--------------------------------------------------------------------------------------------*/
    .secB1.data : AT (LOADADDR(.secB0.data) + SIZEOF(.secB0.data)) ALIGN(0x400) { __secB1_load = LOADADDR(.secB1.data);
        __secB1_start = .;
            *(.secB1_init)
            *secB1*.o(.data)
        . = ALIGN(4); __secB1_bss = .;
    } > core_ram_1

    .secB1.bss __secB1_bss (NOLOAD) : {
            *(.secB1)
            *secB1*.o(.bss COMMON)
        . = ALIGN(4); __secB1_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B2:
     *--------------------------------------------------------------------------------------------*/
    .secB2.data : AT (LOADADDR(.secB1.data) + SIZEOF(.secB1.data)) ALIGN(0x400) { __secB2_load = LOADADDR(.secB2.data);
        __secB2_start = .;
            *(.secB2_init)
            *secB2*.o(.data)
        . = ALIGN(4); __secB2_bss = .;
    } > core_ram_1

    .secB2.bss __secB2_bss (NOLOAD) : {
            *(.secB2)
            *secB2*.o(.bss COMMON)
        . = ALIGN(4); __secB2_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B3:
     *--------------------------------------------------------------------------------------------*/
    .secB3.data : AT (LOADADDR(.secB2.data) + SIZEOF(.secB2.data)) ALIGN(0x400) { __secB3_load = LOADADDR(.secB3.data);
        __secB3_start = .;
            *(.secB3_init)
            *secB3*.o(.data)
        . = ALIGN(4); __secB3_bss = .;
    } > core_ram_1

    .secB3.bss __secB3_bss (NOLOAD) : {
            *(.secB3)
            *secB3*.o(.bss COMMON)
        . = ALIGN(4); __secB3_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B4:
     *--------------------------------------------------------------------------------------------*/
    .secB4.data : AT (LOADADDR(.secB3.data) + SIZEOF(.secB3.data)) ALIGN(0x400) { __secB4_load = LOADADDR(.secB4.data);
        __secB4_start = .;
            *(.secB4_init)
            *secB4*.o(.data)
        . = ALIGN(4); __secB4_bss = .;
    } > core_ram_1

    .secB4.bss __secB4_bss (NOLOAD) : {
            *(.secB4)
            *secB4*.o(.bss COMMON)
        . = ALIGN(4); __secB4_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B5:
     *--------------------------------------------------------------------------------------------*/
    .secB5.data : AT (LOADADDR(.secB4.data) + SIZEOF(.secB4.data)) ALIGN(0x400) { __secB5_load = LOADADDR(.secB5.data);
        __secB5_start = .;
            *(.secB5_init)
            *secB5*.o(.data)
        . = ALIGN(4); __secB5_bss = .;
    } > core_ram_1

    .secB5.bss __secB5_bss (NOLOAD) : {
            *(.secB5)
            *secB5*.o(.bss COMMON)
        . = ALIGN(4); __secB5_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B6:
     *--------------------------------------------------------------------------------------------*/
    .secB6.data : AT (LOADADDR(.secB5.data) + SIZEOF(.secB5.data)) ALIGN(0x400) { __secB6_load = LOADADDR(.secB6.data);
        __secB6_start = .;
            *(.secB6_init)
            *secB6*.o(.data)
        . = ALIGN(4); __secB6_bss = .;
    } > core_ram_1

    .secB6.bss __secB6_bss (NOLOAD) : {
            *(.secB6)
            *secB6*.o(.bss COMMON)
        . = ALIGN(4); __secB6_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B7:
     *--------------------------------------------------------------------------------------------*/
    .secB7.data : AT (LOADADDR(.secB6.data) + SIZEOF(.secB6.data)) ALIGN(0x400) { __secB7_load = LOADADDR(.secB7.data);
        __secB7_start = .;
            *(.secB7_init)
            *secB7*.o(.data)
        . = ALIGN(4); __secB7_bss = .;
    } > core_ram_1

    .secB7.bss __secB7_bss (NOLOAD) : {
            *(.secB7)
            *secB7*.o(.bss COMMON)
        . = ALIGN(4); __secB7_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B8:
     *--------------------------------------------------------------------------------------------*/
    .secB8.data : AT (LOADADDR(.secB7.data) + SIZEOF(.secB7.data)) ALIGN(0x400) { __secB8_load = LOADADDR(.secB8.data);
        __secB8_start = .;
            *(.secB8_init)
            *secB8*.o(.data)
        . = ALIGN(4); __secB8_bss = .;
    } > core_ram_1

    .secB8.bss __secB8_bss (NOLOAD) : {
            *(.secB8)
            *secB8*.o(.bss COMMON)
        . = ALIGN(4); __secB8_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section B9:
     *--------------------------------------------------------------------------------------------*/
    .secB9.data : AT (LOADADDR(.secB8.data) + SIZEOF(.secB8.data)) ALIGN(0x400) { __secB9_load = LOADADDR(.secB9.data);
        __secB9_start = .;
            *(.secB9_init)
            *secB9*.o(.data)
        . = ALIGN(4); __secB9_bss = .;
    } > core_ram_1

    .secB9.bss __secB9_bss (NOLOAD) : {
            *(.secB9)
            *secB9*.o(.bss COMMON)
        . = ALIGN(4); __secB9_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section BA:
     *--------------------------------------------------------------------------------------------*/
    .secBA.data : AT (LOADADDR(.secB9.data) + SIZEOF(.secB9.data)) ALIGN(0x400) { __secBA_load = LOADADDR(.secBA.data);
        __secBA_start = .;
            *(.secBA_init)
            *secBA*.o(.data)
        . = ALIGN(4); __secBA_bss = .;
    } > core_ram_1

    .secBA.bss __secBA_bss (NOLOAD) : {
            *(.secBA)
            *secBA*.o(.bss COMMON)
        . = ALIGN(4); __secBA_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section BB:
     *--------------------------------------------------------------------------------------------*/
    .secBB.data : AT (LOADADDR(.secBA.data) + SIZEOF(.secBA.data)) ALIGN(0x400) { __secBB_load = LOADADDR(.secBB.data);
        __secBB_start = .;
            *(.secBB_init)
            *secBB*.o(.data)
        . = ALIGN(4); __secBB_bss = .;
    } > core_ram_1

    .secBB.bss __secBB_bss (NOLOAD) : {
            *(.secBB)
            *secBB*.o(.bss COMMON)
        . = ALIGN(4); __secBB_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section BC:
     *--------------------------------------------------------------------------------------------*/
    .secBC.data : AT (LOADADDR(.secBB.data) + SIZEOF(.secBB.data)) ALIGN(0x400) { __secBC_load = LOADADDR(.secBC.data);
        __secBC_start = .;
            *(.secBC_init)
            *secBC*.o(.data)
        . = ALIGN(4); __secBC_bss = .;
    } > core_ram_1

    .secBC.bss __secBC_bss (NOLOAD) : {
            *(.secBC)
            *secBC*.o(.bss COMMON)
        . = ALIGN(4); __secBC_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section BD:
     *--------------------------------------------------------------------------------------------*/
    .secBD.data : AT (LOADADDR(.secBC.data) + SIZEOF(.secBC.data)) ALIGN(0x400) { __secBD_load = LOADADDR(.secBD.data);
        __secBD_start = .;
            *(.secBD_init)
            *secBD*.o(.data)
        . = ALIGN(4); __secBD_bss = .;
    } > core_ram_1

    .secBD.bss __secBD_bss (NOLOAD) : {
            *(.secBD)
            *secBD*.o(.bss COMMON)
        . = ALIGN(4); __secBD_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section BE:
     *--------------------------------------------------------------------------------------------*/
    .secBE.data : AT (LOADADDR(.secBD.data) + SIZEOF(.secBD.data)) ALIGN(0x400) { __secBE_load = LOADADDR(.secBE.data);
        __secBE_start = .;
            *(.secBE_init)
            *secBE*.o(.data)
        . = ALIGN(4); __secBE_bss = .;
    } > core_ram_1

    .secBE.bss __secBE_bss (NOLOAD) : {
            *(.secBE)
            *secBE*.o(.bss COMMON)
        . = ALIGN(4); __secBE_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section BF:
     *--------------------------------------------------------------------------------------------*/
    .secBF.data : AT (LOADADDR(.secBE.data) + SIZEOF(.secBE.data)) ALIGN(0x400) { __secBF_load = LOADADDR(.secBF.data);
        __secBF_start = .;
            *(.secBF_init)
            *secBF*.o(.data)
        . = ALIGN(4); __secBF_bss = .;
    } > core_ram_1

    .secBF.bss __secBF_bss (NOLOAD) : {
            *(.secBF)
            *secBF*.o(.bss COMMON)
        . = ALIGN(4); __secBF_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C0:
     *--------------------------------------------------------------------------------------------*/
    .secC0.data : AT (LOADADDR(.secBF.data) + SIZEOF(.secBF.data)) ALIGN(0x400) { __secC0_load = LOADADDR(.secC0.data);
        __secC0_start = .;
            *(.secC0_init)
            *secC0*.o(.data)
        . = ALIGN(4); __secC0_bss = .;
    } > core_ram_1

    .secC0.bss __secC0_bss (NOLOAD) : {
            *(.secC0)
            *secC0*.o(.bss COMMON)
        . = ALIGN(4); __secC0_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C1:
     *--------------------------------------------------------------------------------------------*/
    .secC1.data : AT (LOADADDR(.secC0.data) + SIZEOF(.secC0.data)) ALIGN(0x400) { __secC1_load = LOADADDR(.secC1.data);
        __secC1_start = .;
            *(.secC1_init)
            *secC1*.o(.data)
        . = ALIGN(4); __secC1_bss = .;
    } > core_ram_1

    .secC1.bss __secC1_bss (NOLOAD) : {
            *(.secC1)
            *secC1*.o(.bss COMMON)
        . = ALIGN(4); __secC1_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C2:
     *--------------------------------------------------------------------------------------------*/
    .secC2.data : AT (LOADADDR(.secC1.data) + SIZEOF(.secC1.data)) ALIGN(0x400) { __secC2_load = LOADADDR(.secC2.data);
        __secC2_start = .;
            *(.secC2_init)
            *secC2*.o(.data)
        . = ALIGN(4); __secC2_bss = .;
    } > core_ram_1

    .secC2.bss __secC2_bss (NOLOAD) : {
            *(.secC2)
            *secC2*.o(.bss COMMON)
        . = ALIGN(4); __secC2_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C3:
     *--------------------------------------------------------------------------------------------*/
    .secC3.data : AT (LOADADDR(.secC2.data) + SIZEOF(.secC2.data)) ALIGN(0x400) { __secC3_load = LOADADDR(.secC3.data);
        __secC3_start = .;
            *(.secC3_init)
            *secC3*.o(.data)
        . = ALIGN(4); __secC3_bss = .;
    } > core_ram_1

    .secC3.bss __secC3_bss (NOLOAD) : {
            *(.secC3)
            *secC3*.o(.bss COMMON)
        . = ALIGN(4); __secC3_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C4:
     *--------------------------------------------------------------------------------------------*/
    .secC4.data : AT (LOADADDR(.secC3.data) + SIZEOF(.secC3.data)) ALIGN(0x400) { __secC4_load = LOADADDR(.secC4.data);
        __secC4_start = .;
            *(.secC4_init)
            *secC4*.o(.data)
        . = ALIGN(4); __secC4_bss = .;
    } > core_ram_1

    .secC4.bss __secC4_bss (NOLOAD) : {
            *(.secC4)
            *secC4*.o(.bss COMMON)
        . = ALIGN(4); __secC4_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C5:
     *--------------------------------------------------------------------------------------------*/
    .secC5.data : AT (LOADADDR(.secC4.data) + SIZEOF(.secC4.data)) ALIGN(0x400) { __secC5_load = LOADADDR(.secC5.data);
        __secC5_start = .;
            *(.secC5_init)
            *secC5*.o(.data)
        . = ALIGN(4); __secC5_bss = .;
    } > core_ram_1

    .secC5.bss __secC5_bss (NOLOAD) : {
            *(.secC5)
            *secC5*.o(.bss COMMON)
        . = ALIGN(4); __secC5_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C6:
     *--------------------------------------------------------------------------------------------*/
    .secC6.data : AT (LOADADDR(.secC5.data) + SIZEOF(.secC5.data)) ALIGN(0x400) { __secC6_load = LOADADDR(.secC6.data);
        __secC6_start = .;
            *(.secC6_init)
            *secC6*.o(.data)
        . = ALIGN(4); __secC6_bss = .;
    } > core_ram_1

    .secC6.bss __secC6_bss (NOLOAD) : {
            *(.secC6)
            *secC6*.o(.bss COMMON)
        . = ALIGN(4); __secC6_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C7:
     *--------------------------------------------------------------------------------------------*/
    .secC7.data : AT (LOADADDR(.secC6.data) + SIZEOF(.secC6.data)) ALIGN(0x400) { __secC7_load = LOADADDR(.secC7.data);
        __secC7_start = .;
            *(.secC7_init)
            *secC7*.o(.data)
        . = ALIGN(4); __secC7_bss = .;
    } > core_ram_1

    .secC7.bss __secC7_bss (NOLOAD) : {
            *(.secC7)
            *secC7*.o(.bss COMMON)
        . = ALIGN(4); __secC7_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C8:
     *--------------------------------------------------------------------------------------------*/
    .secC8.data : AT (LOADADDR(.secC7.data) + SIZEOF(.secC7.data)) ALIGN(0x400) { __secC8_load = LOADADDR(.secC8.data);
        __secC8_start = .;
            *(.secC8_init)
            *secC8*.o(.data)
        . = ALIGN(4); __secC8_bss = .;
    } > core_ram_1

    .secC8.bss __secC8_bss (NOLOAD) : {
            *(.secC8)
            *secC8*.o(.bss COMMON)
        . = ALIGN(4); __secC8_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section C9:
     *--------------------------------------------------------------------------------------------*/
    .secC9.data : AT (LOADADDR(.secC8.data) + SIZEOF(.secC8.data)) ALIGN(0x400) { __secC9_load = LOADADDR(.secC9.data);
        __secC9_start = .;
            *(.secC9_init)
            *secC9*.o(.data)
        . = ALIGN(4); __secC9_bss = .;
    } > core_ram_1

    .secC9.bss __secC9_bss (NOLOAD) : {
            *(.secC9)
            *secC9*.o(.bss COMMON)
        . = ALIGN(4); __secC9_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section CA:
     *--------------------------------------------------------------------------------------------*/
    .secCA.data : AT (LOADADDR(.secC9.data) + SIZEOF(.secC9.data)) ALIGN(0x400) { __secCA_load = LOADADDR(.secCA.data);
        __secCA_start = .;
            *(.secCA_init)
            *secCA*.o(.data)
        . = ALIGN(4); __secCA_bss = .;
    } > core_ram_1

    .secCA.bss __secCA_bss (NOLOAD) : {
            *(.secCA)
            *secCA*.o(.bss COMMON)
        . = ALIGN(4); __secCA_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section CB:
     *--------------------------------------------------------------------------------------------*/
    .secCB.data : AT (LOADADDR(.secCA.data) + SIZEOF(.secCA.data)) ALIGN(0x400) { __secCB_load = LOADADDR(.secCB.data);
        __secCB_start = .;
            *(.secCB_init)
            *secCB*.o(.data)
        . = ALIGN(4); __secCB_bss = .;
    } > core_ram_1

    .secCB.bss __secCB_bss (NOLOAD) : {
            *(.secCB)
            *secCB*.o(.bss COMMON)
        . = ALIGN(4); __secCB_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section CC:
     *--------------------------------------------------------------------------------------------*/
    .secCC.data : AT (LOADADDR(.secCB.data) + SIZEOF(.secCB.data)) ALIGN(0x400) { __secCC_load = LOADADDR(.secCC.data);
        __secCC_start = .;
            *(.secCC_init)
            *secCC*.o(.data)
        . = ALIGN(4); __secCC_bss = .;
    } > core_ram_1

    .secCC.bss __secCC_bss (NOLOAD) : {
            *(.secCC)
            *secCC*.o(.bss COMMON)
        . = ALIGN(4); __secCC_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section CD:
     *--------------------------------------------------------------------------------------------*/
    .secCD.data : AT (LOADADDR(.secCC.data) + SIZEOF(.secCC.data)) ALIGN(0x400) { __secCD_load = LOADADDR(.secCD.data);
        __secCD_start = .;
            *(.secCD_init)
            *secCD*.o(.data)
        . = ALIGN(4); __secCD_bss = .;
    } > core_ram_1

    .secCD.bss __secCD_bss (NOLOAD) : {
            *(.secCD)
            *secCD*.o(.bss COMMON)
        . = ALIGN(4); __secCD_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section CE:
     *--------------------------------------------------------------------------------------------*/
    .secCE.data : AT (LOADADDR(.secCD.data) + SIZEOF(.secCD.data)) ALIGN(0x400) { __secCE_load = LOADADDR(.secCE.data);
        __secCE_start = .;
            *(.secCE_init)
            *secCE*.o(.data)
        . = ALIGN(4); __secCE_bss = .;
    } > core_ram_1

    .secCE.bss __secCE_bss (NOLOAD) : {
            *(.secCE)
            *secCE*.o(.bss COMMON)
        . = ALIGN(4); __secCE_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section CF:
     *--------------------------------------------------------------------------------------------*/
    .secCF.data : AT (LOADADDR(.secCE.data) + SIZEOF(.secCE.data)) ALIGN(0x400) { __secCF_load = LOADADDR(.secCF.data);
        __secCF_start = .;
            *(.secCF_init)
            *secCF*.o(.data)
        . = ALIGN(4); __secCF_bss = .;
    } > core_ram_1

    .secCF.bss __secCF_bss (NOLOAD) : {
            *(.secCF)
            *secCF*.o(.bss COMMON)
        . = ALIGN(4); __secCF_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D0:
     *--------------------------------------------------------------------------------------------*/
    .secD0.data : AT (LOADADDR(.secCF.data) + SIZEOF(.secCF.data)) ALIGN(0x400) { __secD0_load = LOADADDR(.secD0.data);
        __secD0_start = .;
            *(.secD0_init)
            *secD0*.o(.data)
        . = ALIGN(4); __secD0_bss = .;
    } > core_ram_1

    .secD0.bss __secD0_bss (NOLOAD) : {
            *(.secD0)
            *secD0*.o(.bss COMMON)
        . = ALIGN(4); __secD0_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D1:
     *--------------------------------------------------------------------------------------------*/
    .secD1.data : AT (LOADADDR(.secD0.data) + SIZEOF(.secD0.data)) ALIGN(0x400) { __secD1_load = LOADADDR(.secD1.data);
        __secD1_start = .;
            *(.secD1_init)
            *secD1*.o(.data)
        . = ALIGN(4); __secD1_bss = .;
    } > core_ram_1

    .secD1.bss __secD1_bss (NOLOAD) : {
            *(.secD1)
            *secD1*.o(.bss COMMON)
        . = ALIGN(4); __secD1_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D2:
     *--------------------------------------------------------------------------------------------*/
    .secD2.data : AT (LOADADDR(.secD1.data) + SIZEOF(.secD1.data)) ALIGN(0x400) { __secD2_load = LOADADDR(.secD2.data);
        __secD2_start = .;
            *(.secD2_init)
            *secD2*.o(.data)
        . = ALIGN(4); __secD2_bss = .;
    } > core_ram_1

    .secD2.bss __secD2_bss (NOLOAD) : {
            *(.secD2)
            *secD2*.o(.bss COMMON)
        . = ALIGN(4); __secD2_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D3:
     *--------------------------------------------------------------------------------------------*/
    .secD3.data : AT (LOADADDR(.secD2.data) + SIZEOF(.secD2.data)) ALIGN(0x400) { __secD3_load = LOADADDR(.secD3.data);
        __secD3_start = .;
            *(.secD3_init)
            *secD3*.o(.data)
        . = ALIGN(4); __secD3_bss = .;
    } > core_ram_1

    .secD3.bss __secD3_bss (NOLOAD) : {
            *(.secD3)
            *secD3*.o(.bss COMMON)
        . = ALIGN(4); __secD3_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D4:
     *--------------------------------------------------------------------------------------------*/
    .secD4.data : AT (LOADADDR(.secD3.data) + SIZEOF(.secD3.data)) ALIGN(0x400) { __secD4_load = LOADADDR(.secD4.data);
        __secD4_start = .;
            *(.secD4_init)
            *secD4*.o(.data)
        . = ALIGN(4); __secD4_bss = .;
    } > core_ram_1

    .secD4.bss __secD4_bss (NOLOAD) : {
            *(.secD4)
            *secD4*.o(.bss COMMON)
        . = ALIGN(4); __secD4_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D5:
     *--------------------------------------------------------------------------------------------*/
    .secD5.data : AT (LOADADDR(.secD4.data) + SIZEOF(.secD4.data)) ALIGN(0x400) { __secD5_load = LOADADDR(.secD5.data);
        __secD5_start = .;
            *(.secD5_init)
            *secD5*.o(.data)
        . = ALIGN(4); __secD5_bss = .;
    } > core_ram_1

    .secD5.bss __secD5_bss (NOLOAD) : {
            *(.secD5)
            *secD5*.o(.bss COMMON)
        . = ALIGN(4); __secD5_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D6:
     *--------------------------------------------------------------------------------------------*/
    .secD6.data : AT (LOADADDR(.secD5.data) + SIZEOF(.secD5.data)) ALIGN(0x400) { __secD6_load = LOADADDR(.secD6.data);
        __secD6_start = .;
            *(.secD6_init)
            *secD6*.o(.data)
        . = ALIGN(4); __secD6_bss = .;
    } > core_ram_1

    .secD6.bss __secD6_bss (NOLOAD) : {
            *(.secD6)
            *secD6*.o(.bss COMMON)
        . = ALIGN(4); __secD6_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D7:
     *--------------------------------------------------------------------------------------------*/
    .secD7.data : AT (LOADADDR(.secD6.data) + SIZEOF(.secD6.data)) ALIGN(0x400) { __secD7_load = LOADADDR(.secD7.data);
        __secD7_start = .;
            *(.secD7_init)
            *secD7*.o(.data)
        . = ALIGN(4); __secD7_bss = .;
    } > core_ram_1

    .secD7.bss __secD7_bss (NOLOAD) : {
            *(.secD7)
            *secD7*.o(.bss COMMON)
        . = ALIGN(4); __secD7_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D8:
     *--------------------------------------------------------------------------------------------*/
    .secD8.data : AT (LOADADDR(.secD7.data) + SIZEOF(.secD7.data)) ALIGN(0x400) { __secD8_load = LOADADDR(.secD8.data);
        __secD8_start = .;
            *(.secD8_init)
            *secD8*.o(.data)
        . = ALIGN(4); __secD8_bss = .;
    } > core_ram_1

    .secD8.bss __secD8_bss (NOLOAD) : {
            *(.secD8)
            *secD8*.o(.bss COMMON)
        . = ALIGN(4); __secD8_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section D9:
     *--------------------------------------------------------------------------------------------*/
    .secD9.data : AT (LOADADDR(.secD8.data) + SIZEOF(.secD8.data)) ALIGN(0x400) { __secD9_load = LOADADDR(.secD9.data);
        __secD9_start = .;
            *(.secD9_init)
            *secD9*.o(.data)
        . = ALIGN(4); __secD9_bss = .;
    } > core_ram_1

    .secD9.bss __secD9_bss (NOLOAD) : {
            *(.secD9)
            *secD9*.o(.bss COMMON)
        . = ALIGN(4); __secD9_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section DA:
     *--------------------------------------------------------------------------------------------*/
    .secDA.data : AT (LOADADDR(.secD9.data) + SIZEOF(.secD9.data)) ALIGN(0x400) { __secDA_load = LOADADDR(.secDA.data);
        __secDA_start = .;
            *(.secDA_init)
            *secDA*.o(.data)
        . = ALIGN(4); __secDA_bss = .;
    } > core_ram_1

    .secDA.bss __secDA_bss (NOLOAD) : {
            *(.secDA)
            *secDA*.o(.bss COMMON)
        . = ALIGN(4); __secDA_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section DB:
     *--------------------------------------------------------------------------------------------*/
    .secDB.data : AT (LOADADDR(.secDA.data) + SIZEOF(.secDA.data)) ALIGN(0x400) { __secDB_load = LOADADDR(.secDB.data);
        __secDB_start = .;
            *(.secDB_init)
            *secDB*.o(.data)
        . = ALIGN(4); __secDB_bss = .;
    } > core_ram_1

    .secDB.bss __secDB_bss (NOLOAD) : {
            *(.secDB)
            *secDB*.o(.bss COMMON)
        . = ALIGN(4); __secDB_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section DC:
     *--------------------------------------------------------------------------------------------*/
    .secDC.data : AT (LOADADDR(.secDB.data) + SIZEOF(.secDB.data)) ALIGN(0x400) { __secDC_load = LOADADDR(.secDC.data);
        __secDC_start = .;
            *(.secDC_init)
            *secDC*.o(.data)
        . = ALIGN(4); __secDC_bss = .;
    } > core_ram_1

    .secDC.bss __secDC_bss (NOLOAD) : {
            *(.secDC)
            *secDC*.o(.bss COMMON)
        . = ALIGN(4); __secDC_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section DD:
     *--------------------------------------------------------------------------------------------*/
    .secDD.data : AT (LOADADDR(.secDC.data) + SIZEOF(.secDC.data)) ALIGN(0x400) { __secDD_load = LOADADDR(.secDD.data);
        __secDD_start = .;
            *(.secDD_init)
            *secDD*.o(.data)
        . = ALIGN(4); __secDD_bss = .;
    } > core_ram_1

    .secDD.bss __secDD_bss (NOLOAD) : {
            *(.secDD)
            *secDD*.o(.bss COMMON)
        . = ALIGN(4); __secDD_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section DE:
     *--------------------------------------------------------------------------------------------*/
    .secDE.data : AT (LOADADDR(.secDD.data) + SIZEOF(.secDD.data)) ALIGN(0x400) { __secDE_load = LOADADDR(.secDE.data);
        __secDE_start = .;
            *(.secDE_init)
            *secDE*.o(.data)
        . = ALIGN(4); __secDE_bss = .;
    } > core_ram_1

    .secDE.bss __secDE_bss (NOLOAD) : {
            *(.secDE)
            *secDE*.o(.bss COMMON)
        . = ALIGN(4); __secDE_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section DF:
     *--------------------------------------------------------------------------------------------*/
    .secDF.data : AT (LOADADDR(.secDE.data) + SIZEOF(.secDE.data)) ALIGN(0x400) { __secDF_load = LOADADDR(.secDF.data);
        __secDF_start = .;
            *(.secDF_init)
            *secDF*.o(.data)
        . = ALIGN(4); __secDF_bss = .;
    } > core_ram_1

    .secDF.bss __secDF_bss (NOLOAD) : {
            *(.secDF)
            *secDF*.o(.bss COMMON)
        . = ALIGN(4); __secDF_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E0:
     *--------------------------------------------------------------------------------------------*/
    .secE0.data : AT (LOADADDR(.secDF.data) + SIZEOF(.secDF.data)) ALIGN(0x400) { __secE0_load = LOADADDR(.secE0.data);
        __secE0_start = .;
            *(.secE0_init)
            *secE0*.o(.data)
        . = ALIGN(4); __secE0_bss = .;
    } > core_ram_1

    .secE0.bss __secE0_bss (NOLOAD) : {
            *(.secE0)
            *secE0*.o(.bss COMMON)
        . = ALIGN(4); __secE0_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E1:
     *--------------------------------------------------------------------------------------------*/
    .secE1.data : AT (LOADADDR(.secE0.data) + SIZEOF(.secE0.data)) ALIGN(0x400) { __secE1_load = LOADADDR(.secE1.data);
        __secE1_start = .;
            *(.secE1_init)
            *secE1*.o(.data)
        . = ALIGN(4); __secE1_bss = .;
    } > core_ram_1

    .secE1.bss __secE1_bss (NOLOAD) : {
            *(.secE1)
            *secE1*.o(.bss COMMON)
        . = ALIGN(4); __secE1_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E2:
     *--------------------------------------------------------------------------------------------*/
    .secE2.data : AT (LOADADDR(.secE1.data) + SIZEOF(.secE1.data)) ALIGN(0x400) { __secE2_load = LOADADDR(.secE2.data);
        __secE2_start = .;
            *(.secE2_init)
            *secE2*.o(.data)
        . = ALIGN(4); __secE2_bss = .;
    } > core_ram_1

    .secE2.bss __secE2_bss (NOLOAD) : {
            *(.secE2)
            *secE2*.o(.bss COMMON)
        . = ALIGN(4); __secE2_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E3:
     *--------------------------------------------------------------------------------------------*/
    .secE3.data : AT (LOADADDR(.secE2.data) + SIZEOF(.secE2.data)) ALIGN(0x400) { __secE3_load = LOADADDR(.secE3.data);
        __secE3_start = .;
            *(.secE3_init)
            *secE3*.o(.data)
        . = ALIGN(4); __secE3_bss = .;
    } > core_ram_1

    .secE3.bss __secE3_bss (NOLOAD) : {
            *(.secE3)
            *secE3*.o(.bss COMMON)
        . = ALIGN(4); __secE3_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E4:
     *--------------------------------------------------------------------------------------------*/
    .secE4.data : AT (LOADADDR(.secE3.data) + SIZEOF(.secE3.data)) ALIGN(0x400) { __secE4_load = LOADADDR(.secE4.data);
        __secE4_start = .;
            *(.secE4_init)
            *secE4*.o(.data)
        . = ALIGN(4); __secE4_bss = .;
    } > core_ram_1

    .secE4.bss __secE4_bss (NOLOAD) : {
            *(.secE4)
            *secE4*.o(.bss COMMON)
        . = ALIGN(4); __secE4_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E5:
     *--------------------------------------------------------------------------------------------*/
    .secE5.data : AT (LOADADDR(.secE4.data) + SIZEOF(.secE4.data)) ALIGN(0x400) { __secE5_load = LOADADDR(.secE5.data);
        __secE5_start = .;
            *(.secE5_init)
            *secE5*.o(.data)
        . = ALIGN(4); __secE5_bss = .;
    } > core_ram_1

    .secE5.bss __secE5_bss (NOLOAD) : {
            *(.secE5)
            *secE5*.o(.bss COMMON)
        . = ALIGN(4); __secE5_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E6:
     *--------------------------------------------------------------------------------------------*/
    .secE6.data : AT (LOADADDR(.secE5.data) + SIZEOF(.secE5.data)) ALIGN(0x400) { __secE6_load = LOADADDR(.secE6.data);
        __secE6_start = .;
            *(.secE6_init)
            *secE6*.o(.data)
        . = ALIGN(4); __secE6_bss = .;
    } > core_ram_1

    .secE6.bss __secE6_bss (NOLOAD) : {
            *(.secE6)
            *secE6*.o(.bss COMMON)
        . = ALIGN(4); __secE6_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E7:
     *--------------------------------------------------------------------------------------------*/
    .secE7.data : AT (LOADADDR(.secE6.data) + SIZEOF(.secE6.data)) ALIGN(0x400) { __secE7_load = LOADADDR(.secE7.data);
        __secE7_start = .;
            *(.secE7_init)
            *secE7*.o(.data)
        . = ALIGN(4); __secE7_bss = .;
    } > core_ram_1

    .secE7.bss __secE7_bss (NOLOAD) : {
            *(.secE7)
            *secE7*.o(.bss COMMON)
        . = ALIGN(4); __secE7_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E8:
     *--------------------------------------------------------------------------------------------*/
    .secE8.data : AT (LOADADDR(.secE7.data) + SIZEOF(.secE7.data)) ALIGN(0x400) { __secE8_load = LOADADDR(.secE8.data);
        __secE8_start = .;
            *(.secE8_init)
            *secE8*.o(.data)
        . = ALIGN(4); __secE8_bss = .;
    } > core_ram_1

    .secE8.bss __secE8_bss (NOLOAD) : {
            *(.secE8)
            *secE8*.o(.bss COMMON)
        . = ALIGN(4); __secE8_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section E9:
     *--------------------------------------------------------------------------------------------*/
    .secE9.data : AT (LOADADDR(.secE8.data) + SIZEOF(.secE8.data)) ALIGN(0x400) { __secE9_load = LOADADDR(.secE9.data);
        __secE9_start = .;
            *(.secE9_init)
            *secE9*.o(.data)
        . = ALIGN(4); __secE9_bss = .;
    } > core_ram_1

    .secE9.bss __secE9_bss (NOLOAD) : {
            *(.secE9)
            *secE9*.o(.bss COMMON)
        . = ALIGN(4); __secE9_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section EA:
     *--------------------------------------------------------------------------------------------*/
    .secEA.data : AT (LOADADDR(.secE9.data) + SIZEOF(.secE9.data)) ALIGN(0x400) { __secEA_load = LOADADDR(.secEA.data);
        __secEA_start = .;
            *(.secEA_init)
            *secEA*.o(.data)
        . = ALIGN(4); __secEA_bss = .;
    } > core_ram_1

    .secEA.bss __secEA_bss (NOLOAD) : {
            *(.secEA)
            *secEA*.o(.bss COMMON)
        . = ALIGN(4); __secEA_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section EB:
     *--------------------------------------------------------------------------------------------*/
    .secEB.data : AT (LOADADDR(.secEA.data) + SIZEOF(.secEA.data)) ALIGN(0x400) { __secEB_load = LOADADDR(.secEB.data);
        __secEB_start = .;
            *(.secEB_init)
            *secEB*.o(.data)
        . = ALIGN(4); __secEB_bss = .;
    } > core_ram_1

    .secEB.bss __secEB_bss (NOLOAD) : {
            *(.secEB)
            *secEB*.o(.bss COMMON)
        . = ALIGN(4); __secEB_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section EC:
     *--------------------------------------------------------------------------------------------*/
    .secEC.data : AT (LOADADDR(.secEB.data) + SIZEOF(.secEB.data)) ALIGN(0x400) { __secEC_load = LOADADDR(.secEC.data);
        __secEC_start = .;
            *(.secEC_init)
            *secEC*.o(.data)
        . = ALIGN(4); __secEC_bss = .;
    } > core_ram_1

    .secEC.bss __secEC_bss (NOLOAD) : {
            *(.secEC)
            *secEC*.o(.bss COMMON)
        . = ALIGN(4); __secEC_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section ED:
     *--------------------------------------------------------------------------------------------*/
    .secED.data : AT (LOADADDR(.secEC.data) + SIZEOF(.secEC.data)) ALIGN(0x400) { __secED_load = LOADADDR(.secED.data);
        __secED_start = .;
            *(.secED_init)
            *secED*.o(.data)
        . = ALIGN(4); __secED_bss = .;
    } > core_ram_1

    .secED.bss __secED_bss (NOLOAD) : {
            *(.secED)
            *secED*.o(.bss COMMON)
        . = ALIGN(4); __secED_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section EE:
     *--------------------------------------------------------------------------------------------*/
    .secEE.data : AT (LOADADDR(.secED.data) + SIZEOF(.secED.data)) ALIGN(0x400) { __secEE_load = LOADADDR(.secEE.data);
        __secEE_start = .;
            *(.secEE_init)
            *secEE*.o(.data)
        . = ALIGN(4); __secEE_bss = .;
    } > core_ram_1

    .secEE.bss __secEE_bss (NOLOAD) : {
            *(.secEE)
            *secEE*.o(.bss COMMON)
        . = ALIGN(4); __secEE_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section EF:
     *--------------------------------------------------------------------------------------------*/
    .secEF.data : AT (LOADADDR(.secEE.data) + SIZEOF(.secEE.data)) ALIGN(0x400) { __secEF_load = LOADADDR(.secEF.data);
        __secEF_start = .;
            *(.secEF_init)
            *secEF*.o(.data)
        . = ALIGN(4); __secEF_bss = .;
    } > core_ram_1

    .secEF.bss __secEF_bss (NOLOAD) : {
            *(.secEF)
            *secEF*.o(.bss COMMON)
        . = ALIGN(4); __secEF_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F0:
     *--------------------------------------------------------------------------------------------*/
    .secF0.data : AT (LOADADDR(.secEF.data) + SIZEOF(.secEF.data)) ALIGN(0x400) { __secF0_load = LOADADDR(.secF0.data);
        __secF0_start = .;
            *(.secF0_init)
            *secF0*.o(.data)
        . = ALIGN(4); __secF0_bss = .;
    } > core_ram_1

    .secF0.bss __secF0_bss (NOLOAD) : {
            *(.secF0)
            *secF0*.o(.bss COMMON)
        . = ALIGN(4); __secF0_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F1:
     *--------------------------------------------------------------------------------------------*/
    .secF1.data : AT (LOADADDR(.secF0.data) + SIZEOF(.secF0.data)) ALIGN(0x400) { __secF1_load = LOADADDR(.secF1.data);
        __secF1_start = .;
            *(.secF1_init)
            *secF1*.o(.data)
        . = ALIGN(4); __secF1_bss = .;
    } > core_ram_1

    .secF1.bss __secF1_bss (NOLOAD) : {
            *(.secF1)
            *secF1*.o(.bss COMMON)
        . = ALIGN(4); __secF1_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F2:
     *--------------------------------------------------------------------------------------------*/
    .secF2.data : AT (LOADADDR(.secF1.data) + SIZEOF(.secF1.data)) ALIGN(0x400) { __secF2_load = LOADADDR(.secF2.data);
        __secF2_start = .;
            *(.secF2_init)
            *secF2*.o(.data)
        . = ALIGN(4); __secF2_bss = .;
    } > core_ram_1

    .secF2.bss __secF2_bss (NOLOAD) : {
            *(.secF2)
            *secF2*.o(.bss COMMON)
        . = ALIGN(4); __secF2_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F3:
     *--------------------------------------------------------------------------------------------*/
    .secF3.data : AT (LOADADDR(.secF2.data) + SIZEOF(.secF2.data)) ALIGN(0x400) { __secF3_load = LOADADDR(.secF3.data);
        __secF3_start = .;
            *(.secF3_init)
            *secF3*.o(.data)
        . = ALIGN(4); __secF3_bss = .;
    } > core_ram_1

    .secF3.bss __secF3_bss (NOLOAD) : {
            *(.secF3)
            *secF3*.o(.bss COMMON)
        . = ALIGN(4); __secF3_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F4:
     *--------------------------------------------------------------------------------------------*/
    .secF4.data : AT (LOADADDR(.secF3.data) + SIZEOF(.secF3.data)) ALIGN(0x400) { __secF4_load = LOADADDR(.secF4.data);
        __secF4_start = .;
            *(.secF4_init)
            *secF4*.o(.data)
        . = ALIGN(4); __secF4_bss = .;
    } > core_ram_1

    .secF4.bss __secF4_bss (NOLOAD) : {
            *(.secF4)
            *secF4*.o(.bss COMMON)
        . = ALIGN(4); __secF4_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F5:
     *--------------------------------------------------------------------------------------------*/
    .secF5.data : AT (LOADADDR(.secF4.data) + SIZEOF(.secF4.data)) ALIGN(0x400) { __secF5_load = LOADADDR(.secF5.data);
        __secF5_start = .;
            *(.secF5_init)
            *secF5*.o(.data)
        . = ALIGN(4); __secF5_bss = .;
    } > core_ram_1

    .secF5.bss __secF5_bss (NOLOAD) : {
            *(.secF5)
            *secF5*.o(.bss COMMON)
        . = ALIGN(4); __secF5_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F6:
     *--------------------------------------------------------------------------------------------*/
    .secF6.data : AT (LOADADDR(.secF5.data) + SIZEOF(.secF5.data)) ALIGN(0x400) { __secF6_load = LOADADDR(.secF6.data);
        __secF6_start = .;
            *(.secF6_init)
            *secF6*.o(.data)
        . = ALIGN(4); __secF6_bss = .;
    } > core_ram_1

    .secF6.bss __secF6_bss (NOLOAD) : {
            *(.secF6)
            *secF6*.o(.bss COMMON)
        . = ALIGN(4); __secF6_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F7:
     *--------------------------------------------------------------------------------------------*/
    .secF7.data : AT (LOADADDR(.secF6.data) + SIZEOF(.secF6.data)) ALIGN(0x400) { __secF7_load = LOADADDR(.secF7.data);
        __secF7_start = .;
            *(.secF7_init)
            *secF7*.o(.data)
        . = ALIGN(4); __secF7_bss = .;
    } > core_ram_1

    .secF7.bss __secF7_bss (NOLOAD) : {
            *(.secF7)
            *secF7*.o(.bss COMMON)
        . = ALIGN(4); __secF7_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F8:
     *--------------------------------------------------------------------------------------------*/
    .secF8.data : AT (LOADADDR(.secF7.data) + SIZEOF(.secF7.data)) ALIGN(0x400) { __secF8_load = LOADADDR(.secF8.data);
        __secF8_start = .;
            *(.secF8_init)
            *secF8*.o(.data)
        . = ALIGN(4); __secF8_bss = .;
    } > core_ram_1

    .secF8.bss __secF8_bss (NOLOAD) : {
            *(.secF8)
            *secF8*.o(.bss COMMON)
        . = ALIGN(4); __secF8_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section F9:
     *--------------------------------------------------------------------------------------------*/
    .secF9.data : AT (LOADADDR(.secF8.data) + SIZEOF(.secF8.data)) ALIGN(0x400) { __secF9_load = LOADADDR(.secF9.data);
        __secF9_start = .;
            *(.secF9_init)
            *secF9*.o(.data)
        . = ALIGN(4); __secF9_bss = .;
    } > core_ram_1

    .secF9.bss __secF9_bss (NOLOAD) : {
            *(.secF9)
            *secF9*.o(.bss COMMON)
        . = ALIGN(4); __secF9_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section FA:
     *--------------------------------------------------------------------------------------------*/
    .secFA.data : AT (LOADADDR(.secF9.data) + SIZEOF(.secF9.data)) ALIGN(0x400) { __secFA_load = LOADADDR(.secFA.data);
        __secFA_start = .;
            *(.secFA_init)
            *secFA*.o(.data)
        . = ALIGN(4); __secFA_bss = .;
    } > core_ram_1

    .secFA.bss __secFA_bss (NOLOAD) : {
            *(.secFA)
            *secFA*.o(.bss COMMON)
        . = ALIGN(4); __secFA_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section FB:
     *--------------------------------------------------------------------------------------------*/
    .secFB.data : AT (LOADADDR(.secFA.data) + SIZEOF(.secFA.data)) ALIGN(0x400) { __secFB_load = LOADADDR(.secFB.data);
        __secFB_start = .;
            *(.secFB_init)
            *secFB*.o(.data)
        . = ALIGN(4); __secFB_bss = .;
    } > core_ram_1

    .secFB.bss __secFB_bss (NOLOAD) : {
            *(.secFB)
            *secFB*.o(.bss COMMON)
        . = ALIGN(4); __secFB_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section FC:
     *--------------------------------------------------------------------------------------------*/
    .secFC.data : AT (LOADADDR(.secFB.data) + SIZEOF(.secFB.data)) ALIGN(0x400) { __secFC_load = LOADADDR(.secFC.data);
        __secFC_start = .;
            *(.secFC_init)
            *secFC*.o(.data)
        . = ALIGN(4); __secFC_bss = .;
    } > core_ram_1

    .secFC.bss __secFC_bss (NOLOAD) : {
            *(.secFC)
            *secFC*.o(.bss COMMON)
        . = ALIGN(4); __secFC_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section FD:
     *--------------------------------------------------------------------------------------------*/
    .secFD.data : AT (LOADADDR(.secFC.data) + SIZEOF(.secFC.data)) ALIGN(0x400) { __secFD_load = LOADADDR(.secFD.data);
        __secFD_start = .;
            *(.secFD_init)
            *secFD*.o(.data)
        . = ALIGN(4); __secFD_bss = .;
    } > core_ram_1

    .secFD.bss __secFD_bss (NOLOAD) : {
            *(.secFD)
            *secFD*.o(.bss COMMON)
        . = ALIGN(4); __secFD_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section FE:
     *--------------------------------------------------------------------------------------------*/
    .secFE.data : AT (LOADADDR(.secFD.data) + SIZEOF(.secFD.data)) ALIGN(0x400) { __secFE_load = LOADADDR(.secFE.data);
        __secFE_start = .;
            *(.secFE_init)
            *secFE*.o(.data)
        . = ALIGN(4); __secFE_bss = .;
    } > core_ram_1

    .secFE.bss __secFE_bss (NOLOAD) : {
            *(.secFE)
            *secFE*.o(.bss COMMON)
        . = ALIGN(4); __secFE_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Section FF:
     *--------------------------------------------------------------------------------------------*/
    .secFF.data : AT (LOADADDR(.secFE.data) + SIZEOF(.secFE.data)) ALIGN(0x400) { __secFF_load = LOADADDR(.secFF.data);
        __secFF_start = .;
            *(.secFF_init)
            *secFF*.o(.data)
        . = ALIGN(4); __secFF_bss = .;
    } > core_ram_1

    .secFF.bss __secFF_bss (NOLOAD) : {
            *(.secFF)
            *secFF*.o(.bss COMMON)
        . = ALIGN(4); __secFF_end = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Protected Variables:
     *--------------------------------------------------------------------------------------------*/
    .data : AT (LOADADDR(.secFF.data) + SIZEOF(.secFF.data)) ALIGN(0x400) {
        __data_rom = LOADADDR(.data);
        __data_ram = .;
            /* privileged initialized data */
            *(.data)
            *(.data.*)
            *(.gnu.linkonce.d.*)
            
        . = ALIGN(4);
         __data_end = .; 
        __data_bss = .;
    } > core_ram_1

    .bss __data_bss (NOLOAD) : {
            __bss_start__ = .;
            /* privileged bss */
            *(.shbss)
            *(.bss)
            *(.bss.*)
            *(.gnu.linkonce.b.*)
            *(COMMON)
        . = ALIGN (4);
        	__bss_end__ = .;
    } > core_ram_1

    /*--------------------------------------------------------------------------------------------*
     *  Protected Variables:
     *--------------------------------------------------------------------------------------------*/
    .stack (NOLOAD) : {
        __stack_start__ = . ;
        . += stack_size;

        . = ALIGN(4);
        __stack_top__ = . ;

        . = ALIGN (4);
        __stack_end__ = .;
    } > core_ram_1

     _end = . ;
    __end = . ;
    PROVIDE(end = .);
		
	    _estack = __stack_end__;
		_sidata = __data_rom;
		_sdata  = __data_ram;
		_edata  = __data_end;
		_sbss   = __bss_start__;
		_ebss   = __bss_end__;
}
