/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     Friedrich-Ebert-Str. 20/1           Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file     bsp_board.c
*
* \brief    Implementation of the Configuration Class BSP_BOARD
*
* $Id: //stream_demos/demo_cmsis_pack/demo_cmsis/Files/Examples/SP_QuickStart/NUCLEO-F446RE(STM32F446RETx)/bsp_board.c#1 $
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/

#include "bsp_board.h"

/*
****************************************************************************************************
*                                          GLOBAL VARIABLES
****************************************************************************************************
*/

/*------------------------------------------------------------------------------------------------*/
/*!
* \var       App_LED
* \details   Application hardware LED GPIO & pin table
*/
/*------------------------------------------------------------------------------------------------*/
const LED_T App_LED[HW_LED_MAX] = {
    { GPIOB, GPIO_PIN_0  },                                 
    { GPIOB, GPIO_PIN_7  },
    { GPIOB, GPIO_PIN_14 },
};

/*------------------------------------------------------------------------------------------------*/
/*!
* \var       AppUsart3
* \details   USART3 initialization structure handle variable 
*/
/*------------------------------------------------------------------------------------------------*/
UART_HandleTypeDef AppUsart3;          

/*------------------------------------------------------------------------------------------------*/
/*!
* \var       GpioInitStruct
* \details   GPIO initialization structure handle variable 
*/
/*------------------------------------------------------------------------------------------------*/
GPIO_InitTypeDef   GpioInitStruct;   

/*
****************************************************************************************************
*                                      INTERNAL EXTERN REFERENCES
****************************************************************************************************
*/

/*
****************************************************************************************************
*                                       COMPILER DEPENDENT FUNCTIONS
****************************************************************************************************
*/

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     When CMSIS-device startup file is used for the application this function is required
             to define.
*/
/*------------------------------------------------------------------------------------------------*/
#if defined (__GNUC__)

SP_INIT_DECLARE(00); 
SP_INIT_DECLARE(10); 
SP_INIT_DECLARE(11); 

void _data_init (long load, long start, long end) 
{ 
    long *src; 
    long *dst; 
    
    src = (long *)load; 
    for (dst = (long *)start; dst < (long *)end;) { 
        *(dst++) = *(src++); 
    } 
}

void _zero_init (long start, long end) 
{ 
    long *dst; 
    
    for (dst = (long *)start; dst < (long *)end; ) { 
        *(dst++) = (long)0; 
    } 
} 

void _init(void)
{
   _zero_init(SP_INIT_BSS(00), SP_INIT_END(00)); 
   _zero_init(SP_INIT_BSS(10), SP_INIT_END(10)); 
   _zero_init(SP_INIT_BSS(11), SP_INIT_END(11)); 
    
   _data_init(SP_INIT_LOAD(00), SP_INIT_START(00), SP_INIT_BSS(00)); 
   _data_init(SP_INIT_LOAD(10), SP_INIT_START(10), SP_INIT_BSS(10)); 
   _data_init(SP_INIT_LOAD(11), SP_INIT_START(11), SP_INIT_BSS(11));
}

#endif

/*
****************************************************************************************************
*                                       BSP FUNCTIONS
****************************************************************************************************
*/
/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     BSP Low initialization of HAL, USART and GPIO for LED's
*/
/*------------------------------------------------------------------------------------------------*/

void BSPLowInit(void) 
{
    __disable_irq();                                  /* Disable all interrupts                   */  
    HAL_Init();
    BSPLedInit();
    BSPUsartInit();
    SCB->SHCSR |= SCB_SHCSR_USGFAULTENA_Msk |
                  SCB_SHCSR_BUSFAULTENA_Msk |
                  SCB_SHCSR_MEMFAULTENA_Msk;
}   

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     USART Intialization
*/
/*------------------------------------------------------------------------------------------------*/
void BSPUsartInit(void)
{
                                                      /*------------------------------------------*/
    __HAL_RCC_USART3_CLK_ENABLE();                    /* Enable USART clock                       */
    __HAL_RCC_GPIOD_CLK_ENABLE();                     /* Enable GPIO clock for USART or UART pins */
                                                      /*------------------------------------------*/    
                                                      /* Configure USART Tx as alternate function */
                                                      /*------------------------------------------*/
    GpioInitStruct.Pin       = GPIO_PIN_8;
    GpioInitStruct.Mode      = GPIO_MODE_AF_PP;
    GpioInitStruct.Pull      = GPIO_PULLUP;
    GpioInitStruct.Speed     = GPIO_SPEED_FAST;
    GpioInitStruct.Alternate = GPIO_AF7_USART3;
    HAL_GPIO_Init(GPIOD, &GpioInitStruct);
                                                      /*------------------------------------------*/  
                                                      /* Configure USART Rx as alternate function */
                                                      /*------------------------------------------*/
    GpioInitStruct.Pin       = GPIO_PIN_9;
    GpioInitStruct.Mode      = GPIO_MODE_AF_PP;
    GpioInitStruct.Alternate = GPIO_AF7_USART3;
    HAL_GPIO_Init(GPIOD, &GpioInitStruct);
                                                      /*------------------------------------------*/                
                                                      /* USART configuration                      */
                                                      /*------------------------------------------*/
    AppUsart3.Instance          = USART3;
    AppUsart3.Init.BaudRate     = 115200;
    AppUsart3.Init.WordLength   = UART_WORDLENGTH_8B;
    AppUsart3.Init.StopBits     = UART_STOPBITS_1;
    AppUsart3.Init.Parity       = UART_PARITY_NONE;
    AppUsart3.Init.Mode         = UART_MODE_TX_RX;
    AppUsart3.Init.HwFlowCtl    = UART_HWCONTROL_NONE;
    AppUsart3.Init.OverSampling = UART_OVERSAMPLING_16;
        
    if (HAL_UART_Init(&AppUsart3) != HAL_OK) {
        for(;;) {

        }
    }
}

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     USART send using the HAL functions.
*/
/*------------------------------------------------------------------------------------------------*/

void BSPUsartSend(INT8U *pData, INT16U Size)
{
    HAL_UART_Transmit(&AppUsart3, (uint8_t *)pData, Size, 100);
}

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     Configures LED GPIO.
*/
/*------------------------------------------------------------------------------------------------*/
void BSPLedInit(void)
{ 
                                                      /*------------------------------------------*/
                                                      /* GPIO Ports Clock Enable for LED and USART*/
                                                      /*------------------------------------------*/
    __HAL_RCC_GPIOB_CLK_ENABLE();
    
    GpioInitStruct.Mode  = GPIO_MODE_OUTPUT_PP;
    GpioInitStruct.Pull  = GPIO_PULLDOWN;
    GpioInitStruct.Speed = GPIO_SPEED_LOW;    
      
    GpioInitStruct.Pin   = GPIO_PIN_0 | GPIO_PIN_7 | GPIO_PIN_14;
    HAL_GPIO_Init(GPIOB, &GpioInitStruct);
            
}

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     LED pin toggle using the HAL functions.
*/
/*------------------------------------------------------------------------------------------------*/
void BSPPinTgl (INT32U id)
{
      HAL_GPIO_TogglePin(App_LED[id].gpio, App_LED[id].pin);
}
