/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     August-Braun-Str. 1                 Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file     sp_core.h
*
* \brief    C/OS-MPU - CORE DEFINITIONS
*
* \ingroup  OS_SP
*
* <table class="mdTable" cellpadding="5" cellspacing="0" border="0"><tr><td>
* <h2> Perforce Depot: </h2>
*     $File: //prod_safety/prod_ucos-mpu/_root/env_com/test/source/ucsp/source/sp_core.h $
* $DateTime: 2014/04/09 09:28:55 $
* $Revision: #3 $
*   $Change: 58638 $
* </td></tr></table>
*
*           This header file contains defines and prototypes for the uC/OS-II
*           space protection support.
*
****************************************************************************************************
*/

/*----------------------------------------END OF HEADER-------------------------------------------*/

#ifndef _SP_CORE_H_                                   /*lint -esym(960,20.2) Re-use of identifier */
#define _SP_CORE_H_

#ifdef __cplusplus                                    /* for compatibility with C++ environments  */
extern "C" {
#endif

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/

#include "sp_cpu.h"                                   /* hardware dependent informations          */
#include "ucos_ii.h"                                  /* C/OS-II core definitions                */

/*
****************************************************************************************************
*                                               UUID
****************************************************************************************************
*/

#if !defined(UUID_REMOVE)
#if defined(UUID_HEADER_ALLOC_EN)
/*UUID-S*/
const CHAR UUID_sp_core_h[] = "{fd3e0883-0c80-4dc9-a08f-a27e2d788443}";
/*UUID-E*/
#endif
#endif

/*
****************************************************************************************************
*                                              MACROS
****************************************************************************************************
*/

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    PRIVILEDGED EXECUTION
* \ingroup  OS_SP
*
*           This macro ensures the privileged execution of the given function.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_DO_PRIVIL(func)  { SP_ENTER_PRIVIL_MODE(); \
                              func;                   \
                              SP_EXIT_PRIVIL_MODE();  }

/*
****************************************************************************************************
*                                   INTERNAL FUNCTION PROTOTYPES
****************************************************************************************************
*/

void            SP_Init            (void);

SP_PROCESS_T   *SP_ProcCreate      (void);
SP_PROCESS_T   *SP_ProcCheck       (SP_PROCESS_T *phdl);

SP_SHM_T       *SP_ShmCreate       (void);
SP_SHM_T       *SP_ShmCheck        (SP_SHM_T *shdl);

SP_ERR_T        SP_MemCheck        (INT32U startAddr, INT32U endAddr, SP_MEM_BLOCK_T mem[]);
INT32U          SP_MemGetAlign     (INT32U address);
INT32U          SP_MemAlign        (INT32U address, INT32U align);

SP_ERR_T        SP_ThreadCreate    (OS_TCB *ptcb);
SP_ERR_T        SP_ThreadDelete    (OS_TCB *ptcb);

void            SP_IsrHandler      (void);

/*
****************************************************************************************************
*                                      API FUNCTION PROTOTYPES
****************************************************************************************************
*/

SP_PROCESS_T   *SPProcessCreate    (INT32U startAddr, INT32U endAddr);
SP_ERR_T        SPProcessAssign    (SP_PROCESS_T *phdl, INT8U prio);
SP_ERR_T        SPProcessDelete    (SP_PROCESS_T *phdl);
SP_ERR_T        SPProcessKill      (INT8U prio);

SP_SHM_T       *SPSharedMemCreate  (INT32U startAddr, INT32U endAddr);
SP_ERR_T        SPSharedMemAssign  (SP_SHM_T *shdl, SP_PROCESS_T *phdl);

SP_MON_STK_T   *SPThreadStkMonGet  (INT8U prio);

void            SPAccessFaultEvent (SP_ACCESS_FAULT_T *err);

/*
****************************************************************************************************
*                                  INTERFACE FUNCTION PROTOTYPES
****************************************************************************************************
*/

void            SP_HwInit         (void);

SP_ERR_T        SP_ProcRegCfgAdd  (SP_MEM_BLOCK_T mem[], SP_PROCESS_T *phdl);
void            SP_ProcCfgFree    (SP_PROCESS_T *phdl);
void            SP_ProcSwitch     (SP_PROC_REG_CFG_T *regOld, SP_PROC_REG_CFG_T *regNew);

INT32U          SP_FaultGetIAddr  (void);
INT32U          SP_FaultGetWAddr  (void);

SP_ERR_T        SP_ProcRegCfgChk  (void);
SP_ERR_T        SP_ProcRegSysChk  (void);

/*
****************************************************************************************************
*                                          ERROR SECTION
****************************************************************************************************
*/


#ifdef __cplusplus                                    /* for compatibility with C++ environment   */
}
#endif

#endif  /* #ifndef _SP_CORE_H_ */
