/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     August-Braun-Str. 1                 Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file      sp_mon.h
*
* \brief     C/OS-MPU - MONITOR DEFINITIONS
*
* \ingroup   SP_MON
*
* <table class="mdTable" cellpadding="5" cellspacing="0" border="0"><tr><td>
* <h2> Perforce Depot: </h2>
*     $File: //prod_safety/prod_ucos-mpu/_root/env_com/test/source/ucsp/source/sp_mon.h $
* $DateTime: 2014/04/09 09:28:55 $
* $Revision: #4 $
*   $Change: 58638 $
* </td></tr></table>
*
*            This header file contains defines and prototypes for the uC/OS-II
*            space protection monitoring support.
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

#ifndef _SP_MON_H_                                    /*lint -esym(960,20.2) Re-use of identifier */
#define _SP_MON_H_

#ifdef __cplusplus                                    /* for compatibility with C++ environments  */
extern "C" {
#endif

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/
#include "os_cpu.h"
#include "sp_mon_cfg.h"                               /* Monitoring Configuration Definitions     */

/*
****************************************************************************************************
*                                               UUID
****************************************************************************************************
*/

#if !defined(UUID_REMOVE)
#if defined(UUID_HEADER_ALLOC_EN)
/*UUID-S*/
const CHAR UUID_sp_mon_h[] = "{d29b212c-af28-41e1-aadd-e280de3c3d9d}";
/*UUID-E*/
#endif
#endif

/*
****************************************************************************************************
*                                           DEFINES
****************************************************************************************************
*/
/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     STACK MONITORING OPTION NONE
*
* \ingroup   SP_MON_STK
*
*            This definition can be used as option for the function SPMonStkCreate() if no
*            other option is needed.
*
* \see       SP_MON_STK_OPT_CLR, SP_MON_STK_OPT_PATTERN_START, SP_MON_STK_OPT_PATTERN_LIMIT
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_OPT_NONE                 (INT32U)0x00000000u

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     STACK MONITORING OPTION CLEAR
*
* \ingroup   SP_MON_STK
*
*            This definition can be used as option for the function SPMonStkCreate().
*            If this option is used, the stack will be initialized with the pattern
*            \ref SP_MON_STK_PATTERN in SPMonStkCreate().
*
* \note      This option is only available if the define \ref SP_MON_STK_CLR_EN is not set to 0.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_OPT_CLR                  (INT32U)0x00000001u

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     STACK MONITORING OPTION PATTERN START
*
* \ingroup   SP_MON_STK
*
*            This definition can be used as option for the function SPMonStkCreate().
*            If this option is used, the pattern \ref SP_MON_STK_PATTERN is written
*            \ref SP_MON_STK_PATTERN_NUM times at the start of the stack.
*
* \note      This option is only available if the define \ref SP_MON_STK_PATTERN_EN is not set to 0.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_OPT_PATTERN_START        (INT32U)0x00000002u

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     STACK MONITORING OPTION PATTERN LIMIT
*
* \ingroup   SP_MON_STK
*
*            This definition can be used as option for the function SPMonStkCreate().
*            If this option is used, the pattern \ref SP_MON_STK_PATTERN is written
*            \ref SP_MON_STK_PATTERN_NUM times at the stack limit.
*
* \note      This option is only available if the define \ref SP_MON_STK_PATTERN_EN is not set to 0.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_OPT_PATTERN_LIMIT        (INT32U)0x00000004u

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     INITIALIZED MONITOR STRUCT INDICATOR
*
* \ingroup   SP_MON_STK
*
*            This define is used to indicate an initialized SP_MON_STK_T data structure.
*            The value is the hexadecimal value of the string "SMST"
*            (initial letters of SP_MON_STK_T).
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_INITIALIZED              (INT32U)0x534d5354u


/*
****************************************************************************************************
*                                            DATA TYPES
****************************************************************************************************
*/
/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     MONITORING ERROR CODES
*
* \ingroup   SP_MON
*
*            This enumeration holds the error codes of the uC/OS-MPU monitoring functions.
*
* \note      The uC/OS-II uses internally 8-Bit (INT8U) for error codes. Therefore we must reserve
*            all values within the range 0x01..0xFF are reserved for uC/OS-II. The value 0x00 is
*            globally usable to indicate 'no error'.
* \note      The uC/OS-MPU uses error codes values starting with 0x0100. Therefore the
*            monitoring error values start with 0x0200.
*/
/*------------------------------------------------------------------------------------------------*/
typedef enum SP_MON_ERR_TAG {
    SP_MON_ERR_NONE               = 0,                /*!< No error                               */

    SP_MON_ERR_INVALID_ARG        = 0x200,            /*!< Invalid function argument              */
    SP_MON_ERR_NULL_PTR           = 0x201,            /*!< Null pointer argument                  */
    SP_MON_ERR_ILLEGAL_CREATE     = 0x202,            /*!< Monitor create after safety critical   */
                                                      /*!< operation started                      */
    SP_MON_ERR_INIT               = 0x203,            /*!< Monitor structure not initialized      */
    SP_MON_ERR_STK_PTR            = 0x204,            /*!< Stack Pointer outside of valid range   */
    SP_MON_ERR_STK_PATTERN_START  = 0x205,            /*!< Invalid Pattern at start of stack      */
    SP_MON_ERR_STK_PATTERN_LIMIT  = 0x206,            /*!< Invalid Pattern at limit of stack      */
    SP_MON_ERR_INVALID_CFG        = 0x207             /*!< Invalid Memory Protection Configuration*/
} SP_MON_ERR_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     STACK MONITORING DATA
*
* \ingroup   SP_MON_STK
*
*            This structure contains the stack monitoring data.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_MON_STK_TAG {
    INT32U  Initialized;                              /*!< Initialized structure indicator        */
    OS_STK *Start;                                    /*!< Start addr. of available stack (incl.) */
    OS_STK *Limit;                                    /*!< End address of available stack (incl.) */

#if (SP_MON_STK_PATTERN_EN > 0)
    OS_STK *PatternStart;                             /*!< Address of pattern seq. at stack start */
    OS_STK *PatternLimit;                             /*!< Address of pattern seq. at stack limit */
#endif

#if (SP_MON_STK_PROFILE_EN > 0)
    OS_STK *End;                                      /*!< End address of stack (incl.)           */
    INT32U  Size;                                     /*!< Stacksize in number of OS_STK elements */
#endif

} SP_MON_STK_T;

/*
****************************************************************************************************
*                                      API FUNCTION PROTOTYPES
****************************************************************************************************
*/

SP_MON_ERR_T SPMonStkCreate     (SP_MON_STK_T *monData,
                                 OS_STK *lowAddr,
                                 OS_STK *highAddr,
                                 OS_STK *stkPtr,
                                 INT32U opt);
SP_MON_ERR_T SPMonStkPtrChk     (SP_MON_STK_T *monData,
                                 OS_STK *stkPtr);
#if (SP_MON_STK_PATTERN_EN > 0)
SP_MON_ERR_T SPMonStkPatternChk (SP_MON_STK_T *monData);
#endif
#if (SP_MON_STK_PROFILE_EN > 0)
SP_MON_ERR_T SPMonStkUsgChk     (SP_MON_STK_T *monData, INT32U *used);
#endif

SP_MON_ERR_T  SPMonMpuCfgChk    (void);

/*
****************************************************************************************************
*                                          ERROR SECTION
****************************************************************************************************
*/
#if (SP_MON_STK_PROFILE_EN > 0) && (SP_MON_STK_CLR_EN == 0)
#error "sp_mon_cfg.h, SP_MON_STK_CLR_EN must be enabled if SP_MON_STK_PROFILE_EN is enabled."
#endif

#if (SP_MON_STK_UPP_LIMIT < 10u) || (SP_MON_STK_UPP_LIMIT > 100u)
#error "sp_mon_cfg.h, SP_MON_STK_UPP_LIMIT  must be between 10 and 100."
#endif

#if (SP_MON_STK_PATTERN_EN > 0)
    #if (SP_MON_STK_PATTERN_NUM < 1u) || (SP_MON_STK_PATTERN_NUM > 16u)
    #error "sp_mon_cfg.h, SP_MON_STK_PATTERN_NUM must be between 1 and 16."
    #endif
#endif


#ifdef __cplusplus                                    /* for compatibility with C++ environment   */
}
#endif

#endif  /* #ifndef _SP_MON_H_ */
