/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     August-Braun-Str. 1                 Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file     sp_osapi.h
* \brief    C/OS-MPU - OS API DEFINES
* \ingroup  OS_SP_OSAPI
*
* <table class="mdTable" cellpadding="5" cellspacing="0" border="0"><tr><td>
* <h2> Perforce Depot: </h2>
*     $File: //prod_safety/prod_ucos-mpu/_root/env_com/test/source/ucsp/source/sp_osapi.h $
* $DateTime: 2014/04/09 09:28:55 $
* $Revision: #3 $
*   $Change: 58638 $
* </td></tr></table>
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

/*!
****************************************************************************************************
*
*           This header file contains defines and prototypes for the uC/OS-SP support.
*
*           The following functions are used without a wrapper, because they are
*           called before the user execution mode (process mode) is started:
*            - OSInit()
*            - OSStart()
*            - OSStartHighRdy()
*
*           The following functions are used without a wrapper, because they are only
*           called out of interrupt handlers in priviledged execution mode:
*            - OSIntEnter()
*            - OSIntExit()
*            - OSTimeTick()
*            - OSIntCtxSw()
*
*           The following function is used without a wrapper, because it is only
*           called within OS functions in priviledged execution mode:
*            - OSCtxSw()
*
****************************************************************************************************
*/

#ifndef _SP_OSAPI_H_                                  /*lint -esym(960,20.2) Re-use of identifier */
#define _SP_OSAPI_H_

#ifdef __cplusplus                                    /* for compatibility with C++ environments  */
extern "C" {
#endif

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/

#include "os_cpu.h"
#include "sp_cfg.h"

/*
****************************************************************************************************
*                                               UUID
****************************************************************************************************
*/

#if !defined(UUID_REMOVE)
#if defined(UUID_HEADER_ALLOC_EN)
/*UUID-S*/
const CHAR UUID_sp_osapi_h[] = "{ab4e5cac-3da9-4505-89ea-a5f6ed02e830}";
/*UUID-E*/
#endif
#endif

/*
****************************************************************************************************
*                                       SP OS FUNCTION MACROS
*                                  (Target Independent Functions)
****************************************************************************************************
*/

/*
****************************************************************************************************
*                                           MISCELLANEOUS
****************************************************************************************************
*/

#if OS_EVENT_EN

#if (OS_EVENT_NAME_EN > 0u)
INT8U    OSEventNameGet           (OS_EVENT        *pevent,
                                   INT8U          **pname,
                                   INT8U           *perr);

void     OSEventNameSet            (OS_EVENT        *pevent,
                                    INT8U           *pname,
                                    INT8U           *perr);
#endif

#if (OS_EVENT_MULTI_EN > 0u)
INT16U   OSEventPendMulti          (OS_EVENT       **pevents_pend,
                                    OS_EVENT       **pevents_rdy,
                                    void           **pmsgs_rdy,
                                    INT32U           timeout,
                                    INT8U           *perr);
#endif

#endif

/*
****************************************************************************************************
*                                      EVENT FLAGS MANAGEMENT
****************************************************************************************************
*/

#if (OS_FLAG_EN > 0u) && (OS_MAX_FLAGS > 0u)

#if (OS_FLAG_ACCEPT_EN > 0u)
OS_FLAGS      OSFlagAccept          (OS_FLAG_GRP     *pgrp,
                                     OS_FLAGS         flags,
                                     INT8U            opt,
                                     INT8U           *perr);
#endif

OS_FLAG_GRP  *OSFlagCreate          (OS_FLAGS         flags,
                                     INT8U            *perr);

#if (OS_FLAG_DEL_EN > 0u)
OS_FLAG_GRP  *OSFlagDel             (OS_FLAG_GRP     *pgrp,
                                     INT8U            opt,
                                     INT8U           *perr);
#endif

#if (OS_FLAG_EN > 0u) && (OS_FLAG_NAME_EN > 0u)
INT8U         OSFlagNameGet         (OS_FLAG_GRP     *pgrp,
                                     INT8U          **pname,
                                     INT8U           *perr);

void          OSFlagNameSet         (OS_FLAG_GRP     *pgrp,
                                     INT8U           *pname,
                                     INT8U           *perr);
#endif

OS_FLAGS      OSFlagPend            (OS_FLAG_GRP     *pgrp,
                                     OS_FLAGS         flags,
                                     INT8U            opt,
                                     INT32U           timeout,
                                     INT8U           *perr);

OS_FLAGS      OSFlagPost            (OS_FLAG_GRP     *pgrp,
                                     OS_FLAGS         flags,
                                     INT8U            opt,
                                     INT8U           *perr);

#if (OS_FLAG_QUERY_EN > 0u)
OS_FLAGS      OSFlagQuery           (OS_FLAG_GRP     *pgrp,
                                     INT8U           *perr);
#endif
#endif

/*
****************************************************************************************************
*                                     MESSAGE MAILBOX MANAGEMENT
****************************************************************************************************
*/

#if (OS_MBOX_EN > 0u)

#if (OS_MBOX_ACCEPT_EN > 0u)
void         *OSMboxAccept          (OS_EVENT        *pevent);
#endif

OS_EVENT     *OSMboxCreate          (void            *pmsg);

#if (OS_MBOX_DEL_EN > 0u)
OS_EVENT     *OSMboxDel             (OS_EVENT        *pevent,
                                     INT8U            opt,
                                     INT8U           *perr);
#endif

void         *OSMboxPend            (OS_EVENT        *pevent,
                                     INT32U           timeout,
                                     INT8U           *perr);

#if (OS_MBOX_PEND_ABORT_EN > 0u)
INT8U         OSMboxPendAbort       (OS_EVENT        *pevent,
                                     INT8U            opt,
                                     INT8U           *perr);
#endif

INT8U         OSMboxPostOpt         (OS_EVENT        *pevent,
                                     void            *pmsg,
                                     INT8U            opt);

#if (OS_MBOX_QUERY_EN > 0u)
INT8U         OSMboxQuery           (OS_EVENT        *pevent,
                                     OS_MBOX_DATA    *p_mbox_data);
#endif
#endif

/*
****************************************************************************************************
*                                        MEMORY MANAGEMENT
****************************************************************************************************
*/

#if (OS_MEM_EN > 0u) && (OS_MAX_MEM_PART > 0u)

OS_MEM       *OSMemCreate           (void            *addr,
                                     INT32U           nblks,
                                     INT32U           blksize,
                                     INT8U           *perr);

void         *OSMemGet              (OS_MEM          *pmem,
                                     INT8U           *perr);
#if (OS_MEM_NAME_EN > 0u)
INT8U         OSMemNameGet          (OS_MEM          *pmem,
                                     INT8U          **pname,
                                     INT8U           *perr);

void          OSMemNameSet          (OS_MEM          *pmem,
                                     INT8U           *pname,
                                     INT8U           *perr);
#endif

INT8U         OSMemPut              (OS_MEM          *pmem,
                                     void            *pblk);

#if (OS_MEM_QUERY_EN > 0u)
INT8U         OSMemQuery            (OS_MEM          *pmem,
                                     OS_MEM_DATA     *p_mem_data);
#endif

#endif

/*
****************************************************************************************************
*                                MUTUAL EXCLUSION SEMAPHORE MANAGEMENT
****************************************************************************************************
*/

#if (OS_MUTEX_EN > 0u)

#if (OS_MUTEX_ACCEPT_EN > 0u)
BOOLEAN       OSMutexAccept         (OS_EVENT        *pevent,
                                     INT8U           *perr);
#endif

OS_EVENT     *OSMutexCreate         (INT8U            prio,
                                     INT8U           *perr);

#if (OS_MUTEX_DEL_EN > 0u)
OS_EVENT     *OSMutexDel            (OS_EVENT        *pevent,
                                     INT8U            opt,
                                     INT8U           *perr);
#endif

void          OSMutexPend           (OS_EVENT        *pevent,
                                     INT32U           timeout,
                                     INT8U           *perr);

INT8U         OSMutexPost           (OS_EVENT        *pevent);

#if (OS_MUTEX_QUERY_EN > 0u)
INT8U         OSMutexQuery          (OS_EVENT        *pevent,
                                     OS_MUTEX_DATA   *p_mutex_data);
#endif

#endif

/*$PAGE*/
/*
****************************************************************************************************
*                                      MESSAGE QUEUE MANAGEMENT
****************************************************************************************************
*/

#if (OS_Q_EN > 0u) && (OS_MAX_QS > 0u)

#if (OS_Q_ACCEPT_EN > 0u)
void         *OSQAccept             (OS_EVENT        *pevent,
                                     INT8U           *perr);
#endif

OS_EVENT     *OSQCreate             (void           **start,
                                     INT16U           size);

#if (OS_Q_DEL_EN > 0u)
OS_EVENT     *OSQDel                (OS_EVENT        *pevent,
                                     INT8U            opt,
                                     INT8U           *perr);
#endif

#if (OS_Q_FLUSH_EN > 0u)
INT8U         OSQFlush              (OS_EVENT        *pevent);
#endif

void         *OSQPend               (OS_EVENT        *pevent,
                                     INT32U           timeout,
                                     INT8U           *perr);

#if (OS_Q_PEND_ABORT_EN > 0u)
INT8U         OSQPendAbort          (OS_EVENT        *pevent,
                                     INT8U            opt,
                                     INT8U           *perr);
#endif

INT8U         OSQPostOpt            (OS_EVENT        *pevent,
                                     void            *pmsg,
                                     INT8U            opt);

#if (OS_Q_QUERY_EN > 0u)
INT8U         OSQQuery              (OS_EVENT        *pevent,
                                     OS_Q_DATA       *p_q_data);
#endif

#endif


/*
****************************************************************************************************
*                                       SEMAPHORE MANAGEMENT
****************************************************************************************************
*/
#if (OS_SEM_EN > 0u)

#if (OS_SEM_ACCEPT_EN > 0u)
INT16U        OSSemAccept           (OS_EVENT        *pevent);
#endif

OS_EVENT     *OSSemCreate           (INT16U           cnt);

#if (OS_SEM_DEL_EN > 0u)
OS_EVENT     *OSSemDel              (OS_EVENT        *pevent,
                                     INT8U            opt,
                                     INT8U           *perr);
#endif

void          OSSemPend             (OS_EVENT        *pevent,
                                     INT32U           timeout,
                                     INT8U           *perr);

#if (OS_SEM_PEND_ABORT_EN > 0u)
INT8U         OSSemPendAbort        (OS_EVENT        *pevent,
                                     INT8U            opt,
                                     INT8U           *perr);
#endif

INT8U         OSSemPost             (OS_EVENT        *pevent);

#if (OS_SEM_QUERY_EN > 0u)
INT8U         OSSemQuery            (OS_EVENT        *pevent,
                                     OS_SEM_DATA     *p_sem_data);
#endif

#if (OS_SEM_SET_EN > 0u)
void          OSSemSet              (OS_EVENT        *pevent,
                                     INT16U           cnt,
                                     INT8U           *perr);
#endif

#endif

/*$PAGE*/
/*
****************************************************************************************************
*                                         TASK MANAGEMENT
****************************************************************************************************
*/
#if (OS_TASK_CHANGE_PRIO_EN > 0u)
INT8U         OSTaskChangePrio      (INT8U            oldprio,
                                     INT8U            newprio);
#endif

INT8U         OSTaskCreateExt       (void           (*task)(void *p_arg),
                                     void            *p_arg,
                                     OS_STK          *ptos,
                                     INT8U            prio,
                                     INT16U           id,
                                     OS_STK          *pbos,
                                     INT32U           stk_size,
                                     void            *phdl,
                                     INT16U           opt);

#if (OS_TASK_DEL_EN > 0u)
INT8U         OSTaskDel             (INT8U            prio);
INT8U         OSTaskDelReq          (INT8U            prio);
#endif

#if (OS_TASK_NAME_EN > 0u)
INT8U         OSTaskNameGet         (INT8U            prio,
                                     INT8U          **pname,
                                     INT8U           *perr);

void          OSTaskNameSet         (INT8U            prio,
                                     INT8U           *pname,
                                     INT8U           *perr);
#endif

#if (OS_TASK_SUSPEND_EN > 0u)
INT8U         OSTaskResume          (INT8U            prio);
INT8U         OSTaskSuspend         (INT8U            prio);
#endif

#if (OS_TASK_QUERY_EN > 0u)
INT8U         OSTaskQuery           (INT8U            prio,
                                     OS_TCB          *p_task_data);
#endif

/*$PAGE*/
/*
****************************************************************************************************
*                                         TIME MANAGEMENT
****************************************************************************************************
*/

void          OSTimeDly             (INT32U           ticks);

#if (OS_TIME_DLY_HMSM_EN > 0u)
INT8U         OSTimeDlyHMSM         (INT8U            hours,
                                     INT8U            minutes,
                                     INT8U            seconds,
                                     INT16U           ms);
#endif

#if (OS_TIME_DLY_RESUME_EN > 0u)
INT8U         OSTimeDlyResume       (INT8U            prio);
#endif

#if (OS_TIME_GET_SET_EN > 0u)
INT32U        OSTimeGet             (void);
void          OSTimeSet             (INT32U           ticks);
#endif

/*
****************************************************************************************************
*                                         TIMER MANAGEMENT
****************************************************************************************************
*/

#if (OS_TMR_EN > 0u)
OS_TMR      *OSTmrCreate            (INT32U           dly,
                                     INT32U           period,
                                     INT8U            opt,
                                     OS_TMR_CALLBACK  callback,
                                     void            *callback_arg,
                                     INT8U           *pname,
                                     INT8U           *perr);

BOOLEAN      OSTmrDel               (OS_TMR          *ptmr,
                                     INT8U           *perr);

#if (OS_TMR_CFG_NAME_EN > 0u)
INT8U        OSTmrNameGet           (OS_TMR          *ptmr,
                                     INT8U          **pdest,
                                     INT8U           *perr);
#endif

INT32U       OSTmrRemainGet         (OS_TMR          *ptmr,
                                     INT8U           *perr);

INT8U        OSTmrStateGet          (OS_TMR          *ptmr,
                                     INT8U           *perr);

BOOLEAN      OSTmrStart             (OS_TMR          *ptmr,
                                     INT8U           *perr);

BOOLEAN      OSTmrStop              (OS_TMR          *ptmr,
                                     INT8U            opt,
                                     void            *callback_arg,
                                     INT8U           *perr);

INT8U        OSTmrSignal            (void);
#endif

/*
****************************************************************************************************
*                                          MISCELLANEOUS
****************************************************************************************************
*/

#ifdef OS_SAFETY_CRITICAL_IEC61508
void          OSSafetyCriticalStart (void);
#endif

#if (OS_SCHED_LOCK_EN > 0u)
void          OSSchedLock           (void);
void          OSSchedUnlock         (void);
#endif

INT16U        OSVersion             (void);


/*
****************************************************************************************************
*                                          ERROR SECTION
****************************************************************************************************
*/

#if (OS_VERSION != 292u)
#error "sp_osapi.h, Only uC/OS-II version 2.92 is supported from uC/OS-MPU"
#endif

#if (OS_CPU_HOOKS_EN == 0u)
#error "OS_CFG.H, OS_CPU_HOOKS_EN must be enabled for uC/OS-MPU"
#endif

#if (OS_TASK_SW_HOOK_EN == 0u)
#error "OS_CFG.H, OS_TASK_SW_HOOK_EN must be enabled for uC/OS-MPU"
#endif

                                                      /* OS functions need for SPProcessDelete()  */
#if (OS_SCHED_LOCK_EN == 0u)
#error "OS_CFG.H, OS_SCHED_LOCK_EN must be enabled for uC/OS-MPU"
#endif

#if (OS_TASK_DEL_EN == 0u)
#error "OS_CFG.H, OS_TASK_DEL_EN must be enabled for uC/OS-MPU"
#endif


#ifdef __cplusplus                                    /* for compatibility with C++ environment   */
}
#endif

#endif /* #ifndef _SP_OSAPI_H_ */

