/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     August-Braun-Str. 1                 Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file     sp_type.h
* \brief    C/OS-MPU - DATA TYPE DEFINITIONS
* \ingroup  OS_SP
*
* <table class="mdTable" cellpadding="5" cellspacing="0" border="0"><tr><td>
* <h2> Perforce Depot: </h2>
*     $File: //prod_safety/prod_ucos-mpu/_root/env_com/test/source/ucsp/source/sp_type.h $
*   $Author: baur $
* $DateTime: 2014/04/09 09:28:55 $
* $Revision: #3 $
*   $Change: 58638 $
* </td></tr></table>
*
*           This file contains the data type definitions and global symbolic constants for the
*           uC/SO-II memory protection extension.
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

#ifndef _SP_TYPE_H_                                   /*lint -esym(960,20.2) Re-use of identifier */
#define _SP_TYPE_H_

#ifdef __cplusplus                                    /* for compatibility with C++ environments  */
extern "C" {
#endif

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/

#include "os_cpu.h"                                   /* basic data types                         */
#include "sp_mon.h"                                   /* monitoring types                         */

/*
****************************************************************************************************
*                                               UUID
****************************************************************************************************
*/

#if !defined(UUID_REMOVE)
#if defined(UUID_HEADER_ALLOC_EN)
/*UUID-S*/
const CHAR UUID_sp_type_h[] = "{1eb4350b-b444-4cd6-8f20-d1c657a29991}";
/*UUID-E*/
#endif
#endif

/*
****************************************************************************************************
*                                           DEFINES
****************************************************************************************************
*/

#define SP_SIZE_1          (INT32U)0x00000001u
#define SP_SIZE_2          (INT32U)0x00000002u
#define SP_SIZE_4          (INT32U)0x00000004u
#define SP_SIZE_8          (INT32U)0x00000008u
#define SP_SIZE_16         (INT32U)0x00000010u
#define SP_SIZE_32         (INT32U)0x00000020u
#define SP_SIZE_64         (INT32U)0x00000040u
#define SP_SIZE_128        (INT32U)0x00000080u
#define SP_SIZE_256        (INT32U)0x00000100u
#define SP_SIZE_512        (INT32U)0x00000200u
#define SP_SIZE_1KB        (INT32U)0x00000400u
#define SP_SIZE_2KB        (INT32U)0x00000800u
#define SP_SIZE_4KB        (INT32U)0x00001000u
#define SP_SIZE_8KB        (INT32U)0x00002000u
#define SP_SIZE_16KB       (INT32U)0x00004000u
#define SP_SIZE_32KB       (INT32U)0x00008000u
#define SP_SIZE_64KB       (INT32U)0x00010000u
#define SP_SIZE_128KB      (INT32U)0x00020000u
#define SP_SIZE_256KB      (INT32U)0x00040000u
#define SP_SIZE_512KB      (INT32U)0x00080000u
#define SP_SIZE_1MB        (INT32U)0x00100000u
#define SP_SIZE_2MB        (INT32U)0x00200000u
#define SP_SIZE_4MB        (INT32U)0x00400000u
#define SP_SIZE_8MB        (INT32U)0x00800000u
#define SP_SIZE_16MB       (INT32U)0x01000000u
#define SP_SIZE_32MB       (INT32U)0x02000000u
#define SP_SIZE_64MB       (INT32U)0x04000000u
#define SP_SIZE_128MB      (INT32U)0x08000000u
#define SP_SIZE_256MB      (INT32U)0x10000000u
#define SP_SIZE_512MB      (INT32U)0x20000000u
#define SP_SIZE_1GB        (INT32U)0x40000000u
#define SP_SIZE_2GB        (INT32U)0x80000000u

/*
****************************************************************************************************
*                                            DATA TYPES
****************************************************************************************************
*/

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    SPACE PROTECTION ERROR CODES
* \ingroup  OS_SP
*
*           This enumeration holds the error codes of the uC/OS-II space protection extension.
*
* \note     The uC/OS-II uses internaly 8-Bit (INT8U) for error codes. Therefore we must reserve
*           all values within the range 0x01..0xFF are reserved for uC/OS-II. The value 0x00 is
*           globaly usable to indicate 'no error'.
*/
/*------------------------------------------------------------------------------------------------*/
typedef enum SP_ERR_TAG {
    SP_ERR_NONE = 0,

    SP_ERR_INVALID_PROCESS = 0x100,                   /*!< invalid process handle                 */
    SP_ERR_INVALID_SHM,                               /*!< invalid shared memory handle           */
    SP_ERR_CALL_AT_ILLEGAL_TIME,                      /*!< create or assign at illegal run time   */
    SP_ERR_INVALID_THREAD,                            /*!< invalid thread priority                */
    SP_ERR_DELETE_THREAD,                             /*!< not all threads are deleted in process */
    SP_ERR_INVALID_MEM,                               /*!< invalid memory configuration           */
    SP_ERR_MEM_STARTADDR,                             /*!< wrong alignment of start address       */
    SP_ERR_MEM_ENDADDR,                               /*!< wrong alignment or size of region      */
    SP_ERR_MEM_NUM_DESC,                              /*!< no memory description block available  */
    SP_ERR_INVALID_CFG                                /*!< memory protection configuration invalid*/
} SP_ERR_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    PROCESS HANDLE
* \ingroup  OS_SP
*
*           This struct contains the abstract description of a process.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_PROCESS_TAG {
    INT16U  ProcID;                                   /*!< unique process identifier              */
    void   *RegCfg;                                   /*!< hardware register configuration        */
    INT32U  Start;                                    /*!< start address of process space (incl.) */
    INT32U  End;                                      /*!< end address of process space (incl.)   */
} SP_PROCESS_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    SHARED MEMORY HANDLE
* \ingroup  OS_SP
*
*           This struct contains the abstract description of a shared memory.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_SHM_TAG {
    INT16U  ShmID;                                    /*!< unique shared memory identifier        */
    void   *ShmCfg;                                   /*!< hardware register configuration        */
    INT32U  Start;                                    /*!< start address of shared memory (incl.) */
    INT32U  End;                                      /*!< end address of shared memory (incl.)   */
} SP_SHM_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    MEMORY PROTECTION HW DESCRIPTION
* \ingroup  OS_SP
*
*           This struct contains the description of a hardware memory protection unit
*           granularity.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_HW_DESC_TAG {
    INT32U PageSize;                                  /*!< Page Size in bytes                     */
    INT32U NumSubPages;                               /*!< Number of possible Sub-Pages           */
} SP_HW_DESC_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    MEMORY BLOCK DESCRIPTION
* \ingroup  OS_SP
*
*           This struct contains the description of a consecutive memory page, which
*           is used to describe the process memory regions.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_MEM_BLOCK_TAG {
    INT32U Start;                                     /*!< Effective start address                */
    INT32U Size;                                      /*!< Memory page size in bytes              */
    INT32U SubPage;                                   /*!< Enabled Sub-Pages                      */
} SP_MEM_BLOCK_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    THREAD DATA HANDLE
* \ingroup  OS_SP
*
*           This struct contains the data of a thread.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_THREAD_TAG {
    struct SP_THREAD_TAG *Next;                       /*!< Link to next free thread data          */
    SP_PROCESS_T         *Process;                    /*!< process configuration                  */
    SP_MON_STK_T          StkMon;                     /*!< stack monitoring configuration & data  */
} SP_THREAD_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    ACCESS ERROR INFORMATION
* \ingroup  OS_SP
*
*           This struct contains the collected information, which may be helpful to specify the
*           reaction on a errornous access.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_ACCESS_FAULT_TAG {
    INT32U IAddress;                                  /*!< Instruction which cause the error      */
    INT32U DAddress;                                  /*!< Wrote protected memory location        */
    INT16U CurPrio;                                   /*!< Current active thread priority         */
} SP_ACCESS_FAULT_T;


#ifdef __cplusplus                                    /* for compatibility with C++ environment   */
}
#endif

#endif    /* #ifndef _SP_TYPE_H_ */
