/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     Friedrich-Ebert-Str. 20/1           Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file     sp_env.h
* \brief    C/OS-MPU - ENVIRONMENT DEFINITIONS
* \ingroup  OS_SP
*
* $Id: //stream_cert-mpu/_root/core/hw_cortex-m4f/env_gcc/source/ucsp/port/sp_env.h#2 $
*
*           This file contains the compiler dependend definitions for the
*           space protection extension uC/OS-MPU.
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

#ifndef SP_ENV_H_
#define SP_ENV_H_

#ifdef __cplusplus                                    /* for compatibility with C++ environments  */
extern "C" {
#endif

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/

#include "sp_type.h"                                  /* basic uC/OS-MPU type definitions         */
#include "sp_cfg.h"                                   /* configuration of uC/OS-MPU extension     */

/*
****************************************************************************************************
*                                               UUID
****************************************************************************************************
*/

#if !defined(UUID_REMOVE)
#if defined(UUID_HEADER_ALLOC_EN)
/*UUID-S*/
const CHAR UUID_sp_env_h[] = "{893c263e-58b1-432d-9abe-516ecca733fa}";
/*UUID-E*/
#endif
#endif

/*
****************************************************************************************************
*                                              MACROS
****************************************************************************************************
*/

/*lint -esym(960, 19.12) Multiple use of '#/##' operators */
/*lint -esym(961, 19.13) '#/##' operator used in macro    */

#define SP_STR(s)           #s

#define SP_MEM_START(x)     ((INT32U)&__sec##x##_start)
#define SP_MEM_END(x)       (((((INT32U)&__sec##x##_end)+(SP_SIZE_1KB-1u))&(~(SP_SIZE_1KB-1u)))-1u)
#define SP_MEM_DECLARE(x)   extern INT32U __sec##x##_start; extern INT32U __sec##x##_end

#define SP_MEM_X(x,y)       __attribute__((section(SP_STR(.sec##x##y))))

#define SP_MEM_DATA(x)      SP_MEM_X(x,_init)
#define SP_MEM_BSS(x)       SP_MEM_X(x,)
#define SP_MEM(x)           SP_MEM_BSS(x)

#define SP_INIT_START(x)    ((INT32U)&__sec##x##_start)
#define SP_INIT_LOAD(x)     ((INT32U)&__sec##x##_load)
#define SP_INIT_BSS(x)      ((INT32U)&__sec##x##_bss)
#define SP_INIT_END(x)      ((INT32U)&__sec##x##_end)
#define SP_INIT_DECLARE(x)  extern INT32U __sec##x##_start; \
                            extern INT32U __sec##x##_end;   \
                            extern INT32U __sec##x##_bss;   \
                            extern INT32U __sec##x##_load


#ifdef __cplusplus                                    /* for compatibility with C++ environment   */
}
#endif
#endif  /* #ifndef SP_ENV_H_ */

