/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     Friedrich-Ebert-Str. 20/1           Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file     sp_cpu.h
* \brief    C/OS-MPU - CPU PORT DEFINITIONS
* \ingroup  OS_SP
*
* $Id: //stream_cert-mpu/_root/core/hw_cortex-m4f/env_keil/source/ucsp/port/sp_cpu.h#2 $
*
*           This file contains the definitions and function prototypes for the hardware
*           specific memory protection unit handling functions.
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

#ifndef SP_CPU_H_
#define SP_CPU_H_

#ifdef __cplusplus                                    /* for compatibility with C++ environments  */
extern "C" {
#endif

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/

#include "sp_env.h"                                   /* environment specific definitions         */

/*
****************************************************************************************************
*                                               UUID
****************************************************************************************************
*/

#if !defined(UUID_REMOVE)
#if defined(UUID_HEADER_ALLOC_EN)
/*UUID-S*/
const CHAR UUID_sp_cpu_h[] = "{71c37f92-6633-439c-bb20-2e1e55d0696d}";
/*UUID-E*/
#endif
#endif

/*
****************************************************************************************************
*                                  CPU SPECIFIC CONFIGURATION DEFINES
****************************************************************************************************
*/

#define SP_MPU_FIRST_DATA_REGION       1u             /*!< Index of first dyn. MPU region register*/

#define SP_MPU_MAX_DATA_REGIONS        (8u-SP_MPU_FIRST_DATA_REGION)

#define SP_MPU_DEFAULT_BASE_ADDR       (INT32U)0x00000000u

#define SP_MPU_DEFAULT_ATTR            (MPU_ATTR_SIZE_4GB   | \
                                        MPU_ATTR_TEX_0      | \
                                        MPU_ATTR_AP_PRW_URO)

/*
****************************************************************************************************
*                                        HW SPECIFIC DEFINES
****************************************************************************************************
*/

#define MPU_TYPE_DREGION_MASK         (INT32U)0x0000FF00u
#define MPU_TYPE_DREGION_8            (INT32U)0x00000800u

#define MPU_CONTROL_ENABLE            (INT32U)0x00000001u
#define MPU_CONTROL_HFNMIENA          (INT32U)0x00000002u
#define MPU_CONTROL_PRIVDEFENA        (INT32U)0x00000004u

#define MPU_BASE_REGION_0             (INT32U)0x00000000u
#define MPU_BASE_REGION_1             (INT32U)0x00000001u
#define MPU_BASE_REGION_2             (INT32U)0x00000002u
#define MPU_BASE_REGION_3             (INT32U)0x00000003u
#define MPU_BASE_REGION_4             (INT32U)0x00000004u
#define MPU_BASE_REGION_5             (INT32U)0x00000005u
#define MPU_BASE_REGION_6             (INT32U)0x00000006u
#define MPU_BASE_REGION_7             (INT32U)0x00000007u
#define MPU_BASE_VALID                (INT32U)0x00000010u
#define MPU_BASE_ADDR_MASK            (INT32U)0xFFFFFFE0u

#define MPU_ATTR_ENABLE               (INT32U)0x00000001u
#define MPU_ATTR_SIZE_32B             (INT32U)0x00000008u
#define MPU_ATTR_SIZE_64B             (INT32U)0x0000000Au
#define MPU_ATTR_SIZE_128B            (INT32U)0x0000000Cu
#define MPU_ATTR_SIZE_256B            (INT32U)0x0000000Eu
#define MPU_ATTR_SIZE_512B            (INT32U)0x00000010u
#define MPU_ATTR_SIZE_1KB             (INT32U)0x00000012u
#define MPU_ATTR_SIZE_2KB             (INT32U)0x00000014u
#define MPU_ATTR_SIZE_4KB             (INT32U)0x00000016u
#define MPU_ATTR_SIZE_8KB             (INT32U)0x00000018u
#define MPU_ATTR_SIZE_16KB            (INT32U)0x0000001Au
#define MPU_ATTR_SIZE_32KB            (INT32U)0x0000001Cu
#define MPU_ATTR_SIZE_64KB            (INT32U)0x0000001Eu
#define MPU_ATTR_SIZE_128KB           (INT32U)0x00000020u
#define MPU_ATTR_SIZE_256KB           (INT32U)0x00000022u
#define MPU_ATTR_SIZE_512KB           (INT32U)0x00000024u
#define MPU_ATTR_SIZE_1MB             (INT32U)0x00000026u
#define MPU_ATTR_SIZE_2MB             (INT32U)0x00000028u
#define MPU_ATTR_SIZE_4MB             (INT32U)0x0000002Au
#define MPU_ATTR_SIZE_8MB             (INT32U)0x0000002Cu
#define MPU_ATTR_SIZE_16MB            (INT32U)0x0000002Eu
#define MPU_ATTR_SIZE_32MB            (INT32U)0x00000030u
#define MPU_ATTR_SIZE_64MB            (INT32U)0x00000032u
#define MPU_ATTR_SIZE_128MB           (INT32U)0x00000034u
#define MPU_ATTR_SIZE_256MB           (INT32U)0x00000036u
#define MPU_ATTR_SIZE_512MB           (INT32U)0x00000038u
#define MPU_ATTR_SIZE_1GB             (INT32U)0x0000003Au
#define MPU_ATTR_SIZE_2GB             (INT32U)0x0000003Cu
#define MPU_ATTR_SIZE_4GB             (INT32U)0x0000003Eu
#define MPU_ATTR_SIZE_MASK            (INT32U)0x0000003Eu
#define MPU_ATTR_SRD_0                (INT32U)0x00000100u
#define MPU_ATTR_SRD_1                (INT32U)0x00000200u
#define MPU_ATTR_SRD_2                (INT32U)0x00000400u
#define MPU_ATTR_SRD_3                (INT32U)0x00000800u
#define MPU_ATTR_SRD_4                (INT32U)0x00001000u
#define MPU_ATTR_SRD_5                (INT32U)0x00002000u
#define MPU_ATTR_SRD_6                (INT32U)0x00004000u
#define MPU_ATTR_SRD_7                (INT32U)0x00008000u
#define MPU_ATTR_SRD_MASK             (INT32U)0x0000FF00u
#define MPU_ATTR_BUFFERABLE           (INT32U)0x00010000u
#define MPU_ATTR_CACHEABLE            (INT32U)0x00020000u
#define MPU_ATTR_SHAREABLE            (INT32U)0x00040000u
#define MPU_ATTR_TEX_0                (INT32U)0x00000000u
#define MPU_ATTR_TEX_1                (INT32U)0x00080000u
#define MPU_ATTR_TEX_2                (INT32U)0x00100000u
#define MPU_ATTR_AP_NOACCESS          (INT32U)0x00000000u
#define MPU_ATTR_AP_PRW_UNOACCESS     (INT32U)0x01000000u
#define MPU_ATTR_AP_PRW_URO           (INT32U)0x02000000u
#define MPU_ATTR_AP_PRW_URW           (INT32U)0x03000000u
#define MPU_ATTR_AP_PRO_UNOACCESS     (INT32U)0x05000000u
#define MPU_ATTR_AP_PRO_URO           (INT32U)0x06000000u
#define MPU_ATTR_INSTR_DISABLE        (INT32U)0x10000000u /* Instruction access disable           */

#define MPU_REG_BASE_ADDR             0xE000ED90ul    /* MPU Base Register Address                */

/*
****************************************************************************************************
*                                              MACROS
****************************************************************************************************
*/
/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    HW ENTER PRIVILEGED MODE
* \ingroup  OS_SP_CPU
*
*           This macro stores the current execution mode on the stack and initiates a SVC
*           to get the priviledged execution (SYS) mode.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_ENTER_PRIVIL_MODE() /*lint -esym(960, 14.3)*/ OS_CPU_SR ctrl_reg;                \
                                                         ctrl_reg = SP_CONTROL_GET();       \
                                                         if((ctrl_reg&(OS_CPU_SR)3)==3u) {  \
                                                             __asm(" SVC  0\n\t");          \
                                                         }

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    HW EXIT PRIVILEGED MODE
* \ingroup  OS_SP_CPU
*
*           This macro restores the previously stored execution mode.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_EXIT_PRIVIL_MODE() /*lint -esym(960, 14.3)*/ SP_CONTROL_SET(ctrl_reg);

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    HW ENTER USER MODE
* \ingroup  OS_SP_CPU
*
*           This macro sets the user execution (USR) mode.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_SET_USR_MODE()      SP_CONTROL_SET_USRMODE();

/*
****************************************************************************************************
*                                            DATA TYPES
****************************************************************************************************
*/
/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    PROCESS MEMORY DESCRIPTION
* \ingroup  OS_SP_CPU
*
*           This struct contains members for the MPU Region Base Address register
*           and the MPU Region Attribute and size register.
*
* \see      SP_ProcRegCfgTbl
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_PROC_REG_CFG_TAG {
    INT32U MpuRegBaseAddr;                            /*!< Base address with valid region         */
    INT32U MpuRegAttrib;                              /*!< Region Attribute and Size              */

    INT32U MirrRegBaseAddr;                           /*!< Bit inverted value of MpuRegBaseAddr   */
    INT32U MirrRegAttrib;                             /*!< Bit inverted value of MpuRegAttrib     */
} SP_PROC_REG_CFG_T;


/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    MPU REGISTER DESCRIPTION
* \ingroup  OS_SP_CPU
*
*           This struct contains the definition of the CPU MPU registers.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct MPU_REGISTER_TAG {
    volatile INT32U TYPE;                             /* MPU Type Register                        */
    volatile INT32U CONTROL;                          /* MPU Control Register                     */
    volatile INT32U NUMBER;                           /* MPU Region Number Register               */
    volatile INT32U BASE;                             /* MPU Region Base Address Register         */
    volatile INT32U ATTR;                             /* MPU Region Attribute & Size Register     */

} MPU_REGISTER_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    CACHED MEMORY REGION
* \ingroup  OS_SP_CPU
*
*           This struct contains the configuration for a cached memory region.
*           Because cache is not supported for the Cortex-M4F, this structure is defined for
*           compatibility reasons.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_CACHE_CFG_TAG {
    INT32U Dummy;                                     /*!< Dummy member                           */
} SP_CACHE_CFG_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    CACHE CONFIGURATION TABLE
* \ingroup  OS_SP_CPU
*
*           This structure contains the reference to the table with the cached memory regions.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_CACHE_CFG_TBL_TAG {
    SP_CACHE_CFG_T *RegionTbl;                        /*!< Table with cached memory regions       */
    INT32U          MirrRegionTbl;                    /*!< Bit inverted value of RegionTbl        */
} SP_CACHE_CFG_TBL_T;

/*
****************************************************************************************************
*                                       FUNCTION PROTOTYPES
****************************************************************************************************
*/

void       SP_MPUEnable           (void);
SP_ERR_T   SP_MemAdd              (SP_MEM_BLOCK_T *mem, SP_PROCESS_T *phdl);

void       SVC_Handler            (void);
OS_CPU_SR  SP_CONTROL_GET         (void);
void       SP_CONTROL_SET         (OS_CPU_SR ctrl_reg);
void       SP_CONTROL_SET_USRMODE (void);
INT32U     SP_ExcGetInstrAddr     (void);
INT32U     SP_ExcGetDataAddr      (void);

SP_ERR_T   SPCacheCfg             (SP_CACHE_CFG_T *tbl);

/*
****************************************************************************************************
*                                          ERROR SECTION
****************************************************************************************************
*/

#ifdef __cplusplus                                    /* for compatibility with C++ environment   */
}
#endif
#endif  /* #ifndef SP_CPU_H_ */

