/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     Friedrich-Ebert-Str. 20/1           Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file      sp_mon_cfg.h
*
* \brief     MONITORING CONFIGURATION DEFINITIONS
*
* \ingroup   SP_MON
*
* $Id: //stream_demos/_root/demo_cert-mpu/core/hw_cortex-m4f/env_keil/lib/sp_mon_cfg.h#1 $
*
*            This header file contains configuration defines for the uC/OS-MPU
*            monitoring functions.
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

#ifndef SP_MON_CFG_H_
#define SP_MON_CFG_H_

/*
****************************************************************************************************
*                                             DEFINES
****************************************************************************************************
*/
/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     UPPER STACK LIMIT
*
* \ingroup   SP_MON_STK
*
*            This define sets the upper limit of the allowed stack usage. The limit shall
*            be configured in percent (max value is 100).
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_UPP_LIMIT            67u

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     STACK PATTERN ENABLE
*
* \ingroup   SP_MON_STK
*
*            This define enables (1) or disables (0) the stack pattern option. The code for the
*            function \ref SPMonStkPatternChk() is only included if this option is enabled.
*
* \note      See \SP_MON_STK_PATTERN_NUM for further configuration of \ref SPMonStkPatternChk().
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_PATTERN_EN           1

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     STACK PATTERN NUMBER
*
* \ingroup   SP_MON_STK
*
*            This define sets the number of stack patterns of the size \ref OS_STK used to mark
*            the start of the stack and the limit of the stack.
*
*            The default value is 4.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_PATTERN_NUM          4u

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     STACK PROFILE ENABLE
*
* \ingroup   SP_MON_STK
*
*            This define enables (1) or disables (0) the stack profiling option. The code for the
*            function \ref SPMonStkUsgChk() is only included if this option is enabled.
*
* \note      \SP_MON_STK_CLR_EN must be enabled also if \ref SPMonStkUsgChk() shall be used.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_PROFILE_EN           1

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief     STACK CLEAR ENABLE
*
* \ingroup   SP_MON_STK
*
*            This define enables (1) or disables (0) the stack clear option. The code for the
*            stack initialization in \ref SPMonStkCreate() is only included if this option is
*            enabled.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_MON_STK_CLR_EN               1


#endif  /* #ifndef SP_MON_CFG_H_ */

