/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     Friedrich-Ebert-Str. 20/1           Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file     os_cpu.h
*
* \brief    ANSI-C Part of the uC/OS-II Port
*
* $Id: //stream_cert-mpu/_root/core/hw_kinetis-m4f/env_keil/source/ucos/port/os_cpu.h#1 $
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

#ifndef OS_CPU_H_
#define OS_CPU_H_

#ifdef __cplusplus                                    /* for compatibility with C++ environments  */
extern "C" {
#endif

/*
****************************************************************************************************
*                                        TYPE DEFINITIONS
****************************************************************************************************
*/

typedef unsigned char  BOOLEAN;
typedef char           CHAR;
typedef unsigned char  INT8U;                         /* Unsigned  8 bit quantity                 */
typedef signed   char  INT8S;                         /* Signed    8 bit quantity                 */
typedef unsigned short INT16U;                        /* Unsigned 16 bit quantity                 */
typedef signed   short INT16S;                        /* Signed   16 bit quantity                 */
typedef unsigned long  INT32U;                        /* Unsigned 32 bit quantity                 */
typedef signed   long  INT32S;                        /* Signed   32 bit quantity                 */
typedef unsigned long long INT64U;                    /* Unsigned 64-bit integer                  */
typedef float          FP32;                          /* Single precision floating point          */
typedef double         FP64;                          /* Double precision floating point          */

typedef INT32U         OS_STK;                        /* Each stack entry is 32-bit wide          */
typedef INT32U         OS_CPU_SR;                     /* Define size of CPU status register       */

/*
****************************************************************************************************
*                                               UUID
****************************************************************************************************
*/

#if !defined(UUID_REMOVE)
#if defined(UUID_HEADER_ALLOC_EN)
/*UUID-S*/
const CHAR UUID_os_cpu_h[] = "{da59bad4-3715-48ea-a81e-ceeb84fbf68d}";
/*UUID-E*/
#endif
#endif

/*
****************************************************************************************************
*                                     CRITICAL SECTION MANAGEMENT
****************************************************************************************************
*/

#define  OS_CRITICAL_METHOD   3u                      /* method #3: cpu_sr in local variable      */

/*lint -emacro( {838}, OS_ENTER_CRITICAL ) : initializing with 0 is ok */
#define  OS_ENTER_CRITICAL()  /*lint -esym(960, 14.3)*/ {cpu_sr = IrqSaveState();}

#define  OS_EXIT_CRITICAL()   /*lint -esym(960, 14.3)*/ {IrqRestoreState(cpu_sr);}

/*
****************************************************************************************************
*                                            MISCELLANEOUS
****************************************************************************************************
*/

#define  OS_STK_GROWTH_HI_TO_LO   1u

#define  OS_STK_GROWTH        OS_STK_GROWTH_HI_TO_LO  /* Stack grows from HIGH to LOW memory      */

#define  OS_TASK_SW()         OSCtxSw()

#define  OS_PTR_ALIGN         4u                      /* Defines alignment of a pointer instance  */

/*
*********************************************************************************************************
*                                         FUNCTION PROTOTYPES
*********************************************************************************************************
*/

#if OS_CRITICAL_METHOD == 3
OS_CPU_SR IrqSaveState    (void);
void      IrqRestoreState (OS_CPU_SR cpu_sr);
#endif

void      OSCtxSw         (void);
void      OSIntCtxSw      (void);
void      OSStartHighRdy  (void);

void      PendSV_Handler  (void);

#ifdef __cplusplus                                    /* for compatibility with C++ environment   */
}
#endif
#endif  /* #ifndef OS_CPU_H_ */

