/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     Friedrich-Ebert-Str. 20/1           Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file     sp_cpu.h
* \brief    C/OS-MPU - CPU PORT DEFINITIONS
* \ingroup  OS_SP
*
* $Id: //stream_cert-mpu/_root/core/hw_kinetis-m4f/env_keil/source/ucsp/port/sp_cpu.h#1 $
*
*           This file contains the definitions and function prototypes for the hardware
*           specific memory protection unit handling functions.
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

#ifndef SP_CPU_H_
#define SP_CPU_H_

#ifdef __cplusplus                                    /* for compatibility with C++ environments  */
extern "C" {
#endif

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/

#include "sp_env.h"                                   /* environment specific definitions         */

/*
****************************************************************************************************
*                                               UUID
****************************************************************************************************
*/

#if !defined(UUID_REMOVE)
#if defined(UUID_HEADER_ALLOC_EN)
/*UUID-S*/
const CHAR UUID_sp_cpu_h[] = "{d87f49ac-c36d-49b0-8fde-1c7ab0f615dd}";
/*UUID-E*/
#endif
#endif

/*
****************************************************************************************************
*                                  CPU SPECIFIC CONFIGURATION DEFINES
****************************************************************************************************
*/

#define SP_MPU_FIRST_DATA_REGION    1u                /*!< Idx of 1st Data Region avail. to Proces*/
                                                      /* Max No of Data Regions per Process       */
#define SP_MPU_MAX_DATA_REGIONS     (16u-SP_MPU_FIRST_DATA_REGION)

/*
****************************************************************************************************
*                                        HW SPECIFIC DEFINES
****************************************************************************************************
*/

#define SP_SIM_SCGC7                                *((volatile INT32U*)0x40048040)
#define SP_SIM_SCGC7_MPU_MASK                       0x4u

#define SP_MPU_CESR_REG(base)                       ((base)->CESR)
#define SP_MPU_EAR_REG(base,index)                  ((base)->SP[index].EAR)
#define SP_MPU_EDR_REG(base,index)                  ((base)->SP[index].EDR)
#define SP_MPU_WORD_REG(base,index,index2)          ((base)->WORD[index][index2])
#define SP_MPU_RGDAAC_REG(base,index)               ((base)->RGDAAC[index])

#define SP_MPU_CESR                                 SP_MPU_CESR_REG(SP_MPU_BASE_PTR)
#define SP_MPU_EAR(index)                           SP_MPU_EAR_REG(SP_MPU_BASE_PTR,index)
#define SP_MPU_EDR(index)                           SP_MPU_EDR_REG(SP_MPU_BASE_PTR,index)
#define SP_MPU_WORD(index,index2)                   SP_MPU_WORD_REG(SP_MPU_BASE_PTR,index,index2)
#define SP_MPU_RGDAAC(index)                        SP_MPU_RGDAAC_REG(SP_MPU_BASE_PTR,index)

#define SP_MPU_BASE_PTR                             ((SP_MPU_MemMapPtr)0x4000D000u)

#define SP_MPU_CESR_VLD_MASK                        0x1u
#define SP_MPU_CESR_SPERR_MASK                      0xFF000000u
#define SP_MPU_CESR_SPERR_SHIFT                     24u
#define SP_MPU_CESR_SPERR(x)                        (((INT32U)(((INT32U)(x))<<SP_MPU_CESR_SPERR_SHIFT))&SP_MPU_CESR_SPERR_MASK)
#define SP_MPU_CESR_NRGD_MASK                       0xF00u
#define SP_MPU_CESR_NRGD_SHIFT                      8u
#define SP_MPU_CESR_NRGD(x)                         (((uint32_t)(((uint32_t)(x))<<MPU_CESR_NRGD_SHIFT))&MPU_CESR_NRGD_MASK)
#define SP_MPU_WORD_VLD_MASK                        0x1u
#define SP_MPU_WORD_M0UM_MASK                       0x7u
#define SP_MPU_WORD_M0UM_SHIFT                      0u
#define SP_MPU_WORD_M0UM(x)                         (((INT32U)(((INT32U)(x))<<SP_MPU_WORD_M0UM_SHIFT))&SP_MPU_WORD_M0UM_MASK)
#define SP_MPU_WORD_M0SM_MASK                       0x18u
#define SP_MPU_WORD_M0SM_SHIFT                      3u
#define SP_MPU_WORD_M0SM(x)                         (((INT32U)(((INT32U)(x))<<SP_MPU_WORD_M0SM_SHIFT))&SP_MPU_WORD_M0SM_MASK)
#define SP_MPU_WORD_M1UM_MASK                       0x1C0u
#define SP_MPU_WORD_M1UM_SHIFT                      6u
#define SP_MPU_WORD_M1UM(x)                         (((INT32U)(((INT32U)(x))<<SP_MPU_WORD_M1UM_SHIFT))&SP_MPU_WORD_M1UM_MASK)
#define SP_MPU_WORD_M1SM_MASK                       0x600u
#define SP_MPU_WORD_M1SM_SHIFT                      9u
#define SP_MPU_WORD_M1SM(x)                         (((INT32U)(((INT32U)(x))<<SP_MPU_WORD_M1SM_SHIFT))&SP_MPU_WORD_M1SM_MASK)
#define SP_MPU_WORD_M2UM_MASK                       0x7000u
#define SP_MPU_WORD_M2UM_SHIFT                      12u
#define SP_MPU_WORD_M2UM(x)                         (((INT32U)(((INT32U)(x))<<SP_MPU_WORD_M2UM_SHIFT))&SP_MPU_WORD_M2UM_MASK)
#define SP_MPU_WORD_M2SM_MASK                       0x18000u
#define SP_MPU_WORD_M2SM_SHIFT                      15u
#define SP_MPU_WORD_M2SM(x)                         (((INT32U)(((INT32U)(x))<<SP_MPU_WORD_M2SM_SHIFT))&SP_MPU_WORD_M2SM_MASK)
#define SP_MPU_WORD_M3UM_MASK                       0x1C0000u
#define SP_MPU_WORD_M3UM_SHIFT                      18u
#define SP_MPU_WORD_M3UM(x)                         (((INT32U)(((INT32U)(x))<<SP_MPU_WORD_M3UM_SHIFT))&SP_MPU_WORD_M3UM_MASK)
#define SP_MPU_WORD_M3SM_MASK                       0x600000u
#define SP_MPU_WORD_M3SM_SHIFT                      21u
#define SP_MPU_WORD_M3SM(x)                         (((INT32U)(((INT32U)(x))<<SP_MPU_WORD_M3SM_SHIFT))&SP_MPU_WORD_M3SM_MASK)
#define SP_MPU_WORD_M4RE_MASK                       0x2000000u
#define SP_MPU_WORD_M5RE_MASK                       0x8000000u
#define SP_MPU_WORD_M6RE_MASK                       0x20000000u
#define SP_MPU_WORD_M7RE_MASK                       0x80000000u

#define SP_MPU_NUM_OF_SUB_PAGES                     32u

/*
****************************************************************************************************
*                                            DEFINES
****************************************************************************************************
*/

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief  Get Number of MPU Hardware Regions
*
* \ingroup  OS_SP_CPU
*
*           Get the Number of Memory Regions that the Hardware MPU Provides
*           Formula:
*               (NGRD << 2) + 8
* \returns [8,12,16]
*/

#define SP_HW_MPU_REGIONS  \
            (((SP_MPU_CESR & SP_MPU_CESR_NRGD_MASK) >> (SP_MPU_CESR_NRGD_SHIFT - 2u)) + 8u)

/*
****************************************************************************************************
*                                              MACROS
****************************************************************************************************
*/

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    HW ENTER PRIVILEGED MODE
* \ingroup  OS_SP_CPU
*
*           This macro stores the current execution mode on the stack and initiates a SWI
*           to get the privileged execution (SYS) mode.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_ENTER_PRIVIL_MODE() /*lint -esym(960, 14.3)*/ OS_CPU_SR ctrl_reg;                \
                                                         ctrl_reg = SP_CONTROL_GET();       \
                                                         if((ctrl_reg&(OS_CPU_SR)3)==3u) {  \
                                                             __asm(" SVC  0\n\t");          \
                                                         }

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    HW EXIT PRIVILEGED MODE
* \ingroup  OS_SP_CPU
*
*           This initiates a SWI to set the previously stored execution mode.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_EXIT_PRIVIL_MODE() /*lint -esym(960, 14.3)*/ SP_CONTROL_SET(ctrl_reg);

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    HW ENTER USER MODE
* \ingroup  OS_SP_CPU
*
*           This initiates a SWI to get the user execution (USR) mode.
*/
/*------------------------------------------------------------------------------------------------*/
#define SP_SET_USR_MODE()      SP_CONTROL_SET_USRMODE();

/*
****************************************************************************************************
*                                            DATA TYPES
****************************************************************************************************
*/

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    HW REGISTER CONFIGURATION
* \ingroup  OS_SP_CPU
*
*           This struct contains the hardware dependent register configuration for a process.
*           The informations must be sufficient to perform a context switch between the
*           process memory spaces.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_PROC_REG_CFG_TAG {
    INT32U MpuRegWord0;                               /* see MPU_RGDn_WORD0 for description       */
    INT32U MpuRegWord1;                               /* see MPU_RGDn_WORD1 for description       */
    INT32U MpuRegWord2;                               /* see MPU_RGDn_WORD2 for description       */
    INT32U MpuRegWord3;                               /* see MPU_RGDn_WORD3 for description       */

    INT32U MirrMpuRegWord0;                           /* Mirror of WORD0                          */
    INT32U MirrMpuRegWord1;                           /* Mirror of WORD1                          */
    INT32U MirrMpuRegWord2;                           /* Mirror of WORD2                          */
    INT32U MirrMpuRegWord3;                           /* Mirror of WORD3                          */

} SP_PROC_REG_CFG_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    MPU REGISTER DESCRIPTION
* \ingroup  OS_SP_CPU
*
*           This struct contains the definition of the CPU MPU registers.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_MPU_MemMap {
  INT32U CESR;                                       /**< Control/Error Status Register, offset: 0x0 */
  INT8U  RESERVED_0[12];
  struct {                                           /* offset: 0x10, array step: 0x8 */
    INT32U EAR;                                      /**< Error Address Register, Slave Port n, array offset: 0x10, array step: 0x8 */
    INT32U EDR;                                      /**< Error Detail Register, Slave Port n, array offset: 0x14, array step: 0x8 */
  } SP[5];
  INT8U  RESERVED_1[968];
  INT32U WORD[16][4];                                /**< Region Descriptor n, Word 0..Region Descriptor n, Word 3, array offset: 0x400, array step: index*0x10, index2*0x4 */
  INT8U  RESERVED_2[768];
  INT32U RGDAAC[16];                                 /**< Region Descriptor Alternate Access Control n, array offset: 0x800, array step: 0x4 */
} volatile *SP_MPU_MemMapPtr;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    CACHED MEMORY REGION
* \ingroup  OS_SP_CPU
*
*           This struct contains the configuration for a cached memory region.
*           Because cache is not supported for the Kinetis-M4F, this structure is defined for
*           compatibility reasons.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_CACHE_CFG_TAG {
    INT32U Dummy;                                     /*!< Dummy member                           */
} SP_CACHE_CFG_T;

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief    CACHE CONFIGURATION TABLE
* \ingroup  OS_SP_CPU
*
*           This structure contains the reference to the table with the cached memory regions.
*/
/*------------------------------------------------------------------------------------------------*/
typedef struct SP_CACHE_CFG_TBL_TAG {
    SP_CACHE_CFG_T *RegionTbl;                        /*!< Table with cached memory regions       */
    INT32U          MirrRegionTbl;                    /*!< Bit inverted value of RegionTbl        */
} SP_CACHE_CFG_TBL_T;

/*
****************************************************************************************************
*                                       FUNCTION PROTOTYPES
****************************************************************************************************
*/

void       SP_MPUEnable           (void);
SP_ERR_T   SP_MemAdd              (SP_MEM_BLOCK_T *mem, SP_PROCESS_T *phdl);

void       SVC_Handler            (void);
OS_CPU_SR  SP_CONTROL_GET         (void);
void       SP_CONTROL_SET         (OS_CPU_SR ctrl_reg);
void       SP_CONTROL_SET_USRMODE (void);
INT32U     SP_ExcGetInstrAddr     (void);
INT32U     SP_ExcGetSlavePort     (void);

SP_ERR_T   SPCacheCfg             (SP_CACHE_CFG_T *tbl);

/*
****************************************************************************************************
*                                          ERROR SECTION
****************************************************************************************************
*/

#ifdef __cplusplus                                    /* for compatibility with C++ environment   */
}
#endif
#endif  /* #ifndef SP_CPU_H_ */

