/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     Friedrich-Ebert-Str. 20/1           Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file     sp_env.h
* \brief    C/OS-MPU - ENVIRONMENT DEFINITIONS
* \ingroup  OS_SP
*
* $Id: //stream_cert-mpu/_root/core/hw_kinetis-m4f/env_keil/source/ucsp/port/sp_env.h#1 $
*
*           This file contains the compiler dependend definitions for the
*           space protection extension uC/OS-MPU.
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

#ifndef SP_ENV_H_
#define SP_ENV_H_

#ifdef __cplusplus                                    /* for compatibility with C++ environments  */
extern "C" {
#endif

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/

#include "sp_type.h"                                  /* basic uC/OS-MPU type definitions         */
#include "sp_cfg.h"                                   /* configuration of uC/OS-MPU extension     */

/*
****************************************************************************************************
*                                               UUID
****************************************************************************************************
*/

#if !defined(UUID_REMOVE)
#if defined(UUID_HEADER_ALLOC_EN)
/*UUID-S*/
const CHAR UUID_sp_env_h[] = "{e90ffcff-313e-4dbb-921c-1208e6e88366}";
/*UUID-E*/
#endif
#endif

/*
****************************************************************************************************
*                                              MACROS
****************************************************************************************************
*/

#define SP_STR(s)  #s
#define SP_XSTR(s) SP_STR(s)

#define SP_MEM_START(x)   (INT32U)&Image$$sec##x##$$Base
                                                      /* Suppress Warning "#170-D: pointer points */
                                                      /* outside of underlying object" because    */
                                                      /* scatter file is implemented to generate  */
                                                      /* memory sections with sizes in a multiple */
                                                      /* of 1kB.                                  */
#define SP_MEM_END(x)     _Pragma("diag_suppress 170")  \
                          (INT32U)(((((INT32U)&Image$$sec##x##$$ZI$$Limit)+(SP_SIZE_1KB-1u))&(~(SP_SIZE_1KB-1u)))-1u) \
                          _Pragma("diag_default 170")

#define SP_MEM_DECLARE(x) extern INT32U Image$$sec##x##$$ZI$$Limit; extern INT32U Image$$sec##x##$$Base

#define SP_MEM_DATA(x)    __attribute__((section(".sec" SP_XSTR(x) ".data")))
#define SP_MEM_BSS(x)     __attribute__((section(".sec" SP_XSTR(x) ".data"), zero_init))
#define SP_MEM(x)         SP_MEM_BSS(x)



#ifdef __cplusplus                                    /* for compatibility with C++ environment   */
}
#endif
#endif  /* #ifndef SP_ENV_H_ */

