/*
****************************************************************************************************
* (c) copyright by
*     Embedded Office GmbH & Co. KG       Tel : (07522) 97 00 08-0
*     Friedrich-Ebert-Str. 20/1           Fax : (07522) 97 00 08-99
*     D-88239 Wangen                      Mail: info@embedded-office.de
*                                         Web : http://www.embedded-office.de
*
* All rights reserved. Confidential and Proprietary. Protected by international copyright laws.
* Knowledge of the source code may not be used to write a similar product.
* This file may only be used in accordance with a license and should not be
* redistributed in any way.
****************************************************************************************************
*/
/*!
****************************************************************************************************
* \file      rtos_excep.c
*
* \brief     Flexible Safety RTOS exception handler functions
*
* $Id: //stream_demos/demo_cmsis_pack/demo_cmsis/Files/UserCodeTemplates/rtos_excep.c#1 $
*
****************************************************************************************************
*/
/*----------------------------------------END OF HEADER-------------------------------------------*/

/*
****************************************************************************************************
*                                             INCLUDES
****************************************************************************************************
*/

#include "rtos_excep.h"

/*
****************************************************************************************************
*                                      APPLICATION FUNCTIONS
****************************************************************************************************
*/
/*------------------------------------------------------------------------------------------------*/
/*!
* \brief This function initialize the SysTick timer using the STM32CubeMX HAL functions.
*
* \note  Here user can implement their own timer, when user is not using the SysTick timer then user 
*        need to also initialize OSTimeTick() using that timer handler function
* \see   SysTick_Handler() as an example for implementation of the OSTimeTick()
*/
/*------------------------------------------------------------------------------------------------*/
#if RTOS_OSSYSTICK_EN
void RTOS_Tick_Init (void)
{
                                                      /*Configure the Systick interrupt time      */
    HAL_SYSTICK_Config(HAL_RCC_GetHCLKFreq()/OS_TICKS_PER_SEC); 

    HAL_SYSTICK_CLKSourceConfig(SYSTICK_CLKSOURCE_HCLK); /* Configure the Systick                 */

    HAL_NVIC_SetPriority(SysTick_IRQn, 6, 0);         /* SysTick_IRQn interrupt configuration     */
}
#endif

/*
****************************************************************************************************
*                                      EXCEPTION HANDLER FUNCTIONS
****************************************************************************************************
*/

/*------------------------------------------------------------------------------------------------*/
/*!
* \brief This function handles the OSTimeTick using installed SysTick Timer.
*/
/*------------------------------------------------------------------------------------------------*/
#if RTOS_OSSYSTICK_EN
void SysTick_Handler(void)
{
    OS_CPU_SR cpu_sr; 
 
    OS_ENTER_CRITICAL(); 
    OSIntEnter(); 
    OS_EXIT_CRITICAL(); 
 
    OSTimeTick(); 
 
    OSIntExit(); 
}
#endif

#if RTOS_CORTEXM4_EXCEPTION_EN
/*------------------------------------------------------------------------------------------------*/
/*!
* \brief This function handles the memory access fault management for Cortex-M4F.
*/
/*------------------------------------------------------------------------------------------------*/
void MemManage_Handler(void)
{
    __disable_irq();                                  /* Disable all interrupts                   */

    OSIntEnter();

    SP_IsrHandler();

    while (1) {

    }
}
#else
/*------------------------------------------------------------------------------------------------*/
/*!
* \brief This function handles the memory access fault management for Kinetis-M4F.
*/
/*------------------------------------------------------------------------------------------------*/
void BusFault_Handler(void)
{
    __disable_irq();                                  /* Disable all interrupts                   */

    OSIntEnter();

    SP_IsrHandler();
  while (1)
  {
  }
}
#endif

